@@ -49,9 +49,17 @@
 
 #define CLAMP(x, low, high)  (((x) > (high)) ? (high) : (((x) < (low)) ? (low) : (x)))
 
-static ssize_t current_size, total_size;
+enum
+{
+  ABORT,
+  BLANK,
+  SKIP
+};
 
-#if DVDREAD_VERSION < 905
+static ssize_t current_size, total_size;
+static unsigned int strategy = ABORT;
+
+#ifndef HAVE_DVD_FILE_STAT
 uint32_t UDFFindFile (dvd_reader_t *, const char *, uint32_t *);
 
 typedef struct
@@ -126,7 +134,7 @@ DVDFileStat (dvd_reader_t *reader, int vts, dvd_read_domain_t domain, dvd_stat_t
 
   return 0;
 }
-#endif /* DVDREAD_VERSION */
+#endif /* HAVE_DVD_FILE_STAT */
 
 static ssize_t
 dvd_file_size (dvd_reader_t *reader, unsigned int vts, dvd_read_domain_t domain)
@@ -153,13 +161,15 @@ usage (const char *name)
   fprintf (stdout, "  %s [OPTION...] <DVD DEVICE>\n", name);
   fprintf (stdout, "\n");
   fprintf (stdout, "Help Options:\n");
-  fprintf (stdout, "  -h, --help              Show help options\n");
+  fprintf (stdout, "  -h, --help                Show help options\n");
   fprintf (stdout, "\n");
   fprintf (stdout, "Application Options:\n");
-  fprintf (stdout, "  -o, --output output     Specify the output directory\n");
-  fprintf (stdout, "  -t, --title title       Select the title to copy. This option may be\n");
-  fprintf (stdout, "                          specified multiple times (default: all titles)\n");
-  fprintf (stdout, "  -m, --menu              Copy the DVD menu\n");
+  fprintf (stdout, "  -o, --output output       Specify the output directory\n");
+  fprintf (stdout, "  -t, --title title         Select the title to copy. This option may be\n");
+  fprintf (stdout, "                            specified multiple times (default: all titles)\n");
+  fprintf (stdout, "  -s, --strategy strategy   Select the strategy to use on error: skip, blank or\n");
+  fprintf (stdout, "                            abort (default: abort)\n");
+  fprintf (stdout, "  -m, --menu                Copy the DVD menu\n");
   fprintf (stdout, "\n");
 }
 
@@ -277,6 +287,31 @@ get_space_left (const char *path)
   return (long long) buf.f_bsize * (long long) buf.f_bavail / DVD_VIDEO_LB_LEN;
 }
 
+static ssize_t
+read_blocks (dvd_file_t *file, size_t offset, size_t size, unsigned char *buffer)
+{
+  ssize_t count, skip;
+
+  for (skip = 0; skip < size; skip ++)
+  {
+    count = DVDReadBlocks (file, offset + skip, size - skip, buffer);
+    if (count > 0)
+      break;
+
+    if (strategy == ABORT)
+      return count;
+
+    if (strategy == BLANK)
+      memset (buffer + skip, 0, DVD_VIDEO_LB_LEN);
+  }
+
+  if (skip)
+    fprintf (stderr, "Warning: %s %zd blocks at offset %zd\n",
+        strategy == SKIP ? "Skipped" : "Blanked", skip, offset);
+
+  return count + skip;
+}
+
 static ssize_t
 write_blocks (int fd, const void *buffer, size_t nblocks)
 {
@@ -310,7 +345,7 @@ dvd_copy_blocks (dvd_file_t *file, size_t offset, size_t size, int fd)
       count = start + size - offset;
     len = count;
 
-    count = DVDReadBlocks (file, offset, len, buffer);
+    count = read_blocks (file, offset, len, buffer);
     if (count < 0)
     {
       fprintf (stderr, "Error: Cannot read data\n");
@@ -664,13 +699,13 @@ dvd_copy_vob (dvd_reader_t *reader, unsigned int vts, const char *output)
     offset += size;
   }
 
-      DVDCloseFile (dvd_file);
+  DVDCloseFile (dvd_file);
 
   if (offset != dvd_stat.size / (uint32_t) DVD_VIDEO_LB_LEN)
   {
     fprintf (stderr, "Error: Failed to copy VOB for VTS %u\n", vts);
-      return -1;
-    }
+    return -1;
+  }
 
   return offset;
 }
@@ -741,12 +776,13 @@ dvd_copy (dvd_reader_t *reader, ifo_handle_t *vmg_file, unsigned int vmg, unsign
   return fullsize;
 }
 
-static const char *shortopts = "hmo:t:";
+static const char *shortopts = "hmo:s:t:";
 static const struct option longopts[] =
 {
   { "help",     no_argument,       NULL, 'h' },
   { "menu",     no_argument,       NULL, 'm' },
   { "output",   required_argument, NULL, 'o' },
+  { "strategy", required_argument, NULL, 's' },
   { "title",    required_argument, NULL, 't' },
   { NULL,       0,                 NULL,  0  }
 };
@@ -786,6 +822,19 @@ main (int argc, char *argv[])
       case 'o':
         output = optarg;
         break;
+      case 's':
+        if (strcmp (optarg, "blank") == 0)
+          strategy = BLANK;
+        else if (strcmp (optarg, "skip") == 0)
+          strategy = SKIP;
+        else if (strcmp (optarg, "abort") == 0)
+          strategy = ABORT;
+        else
+        {
+          fprintf (stderr, "Error: unknown strategy: %s\n", optarg);
+          return EXIT_FAILURE; 
+        }
+        break;
       case 't':
         title = atoi (optarg);
         if (title < 1 || title > 99)
