@@ -30,8 +30,6 @@
 #include "ogmdvd-chapter-list.h"
 
 #include <glib/gi18n-lib.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkliststore.h>
 
 enum
 {
@@ -66,7 +64,7 @@ static void ogmdvd_chapter_list_set_property (GObject      *gobject,
                                               const GValue *value,
                                               GParamSpec   *pspec);
 
-G_DEFINE_TYPE (OGMDvdChapterList, ogmdvd_chapter_list, GTK_TYPE_TREE_VIEW);
+G_DEFINE_TYPE (OGMDvdChapterList, ogmdvd_chapter_list, GTK_TYPE_TREE_VIEW)
 
 static void
 ogmdvd_chapter_list_class_init (OGMDvdChapterListClass *klass)
@@ -136,20 +134,7 @@ ogmdvd_chapter_list_dispose (GObject *object)
 
   (*G_OBJECT_CLASS (ogmdvd_chapter_list_parent_class)->dispose) (object);
 }
-/*
-static void
-ogmdvd_chapter_list_finalize (GObject *object)
-{
-  OGMDvdChapterList *list;
 
-  list = OGMDVD_CHAPTER_LIST (object);
-
-  if (list->priv->title)
-    ogmdvd_title_unref (list->priv->title);
-
-  (*G_OBJECT_CLASS (ogmdvd_chapter_list_parent_class)->finalize) (object);
-}
-*/
 static void
 ogmdvd_chapter_list_get_property (GObject *gobject, guint property_id, GValue *value, GParamSpec *pspec)
 {
