@@ -19,9 +19,9 @@
 #ifndef __OGMDVD_CHAPTER_LIST_H__
 #define __OGMDVD_CHAPTER_LIST_H__
 
-#include <ogmdvd.h>
+#include <gtk/gtk.h>
 
-#include <gtk/gtkcombobox.h>
+#include <ogmdvd.h>
 
 G_BEGIN_DECLS
 
