@@ -30,13 +30,8 @@
 #include "ogmdvd-drive-chooser-dialog.h"
 #include "ogmdvd-drive-chooser-widget.h"
 
+#include <ogmdvd.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkalignment.h>
 
 #define OGMDVD_DRIVE_CHOOSER_DIALOG_GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), OGMDVD_TYPE_DRIVE_CHOOSER_DIALOG, OGMDvdDriveChooserDialogPriv))
@@ -65,7 +60,8 @@ static void ogmdvd_drive_chooser_init (OGMDvdDriveChooserIface  *iface);
  * OGMDvdDriveChooser vfuncs
  */
 
-static NautilusBurnDrive * ogmdvd_drive_chooser_dialog_get_drive (OGMDvdDriveChooser *chooser);
+static gchar * ogmdvd_drive_chooser_dialog_get_device (OGMDvdDriveChooser *chooser,
+                                                       OGMDvdDeviceType   *type);
 
 /*
  * Internal fucntions
@@ -74,6 +70,7 @@ static NautilusBurnDrive * ogmdvd_drive_chooser_dialog_get_drive (OGMDvdDriveCho
 static void ogmdvd_drive_chooser_dialog_eject_clicked  (GtkDialog                *dialog);
 static void ogmdvd_drive_chooser_dialog_device_changed (OGMDvdDriveChooserDialog *dialog,
                                                         const gchar              *device,
+                                                        OGMDvdDeviceType         type,
                                                         GtkWidget                *chooser);
 
 static int signals[LAST_SIGNAL] = { 0 };
@@ -105,20 +102,21 @@ ogmdvd_drive_chooser_dialog_class_init (OGMDvdDriveChooserDialogClass *klass)
 static void
 ogmdvd_drive_chooser_init (OGMDvdDriveChooserIface  *iface)
 {
-  iface->get_drive = ogmdvd_drive_chooser_dialog_get_drive;
+  iface->get_device = ogmdvd_drive_chooser_dialog_get_device;
 }
 
 static void
 ogmdvd_drive_chooser_dialog_init (OGMDvdDriveChooserDialog *dialog)
 {
-  NautilusBurnDrive *drive;
-
   GtkWidget *alignment;
   GtkWidget *image;
   GtkWidget *label;
   GtkWidget *hbox;
   GtkWidget *vbox;
 
+  OGMDvdDeviceType type;
+  gchar *device;
+
   dialog->priv = OGMDVD_DRIVE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Open DVD Disk"));
@@ -190,21 +188,20 @@ ogmdvd_drive_chooser_dialog_init (OGMDvdDriveChooserDialog *dialog)
   g_signal_connect_swapped (dialog->priv->chooser, "device-changed", 
       G_CALLBACK (ogmdvd_drive_chooser_dialog_device_changed), dialog);
 
-  drive = ogmdvd_drive_chooser_get_drive (OGMDVD_DRIVE_CHOOSER (dialog->priv->chooser));
+  device = ogmdvd_drive_chooser_get_device (OGMDVD_DRIVE_CHOOSER (dialog->priv->chooser), &type);
 
-  gtk_widget_set_sensitive (dialog->priv->eject_button, drive != NULL);
-  gtk_widget_set_sensitive (dialog->priv->load_button, drive != NULL);
+  gtk_widget_set_sensitive (dialog->priv->eject_button, device != NULL && type == OGMDVD_DEVICE_BLOCK);
+  gtk_widget_set_sensitive (dialog->priv->load_button, device != NULL && type != OGMDVD_DEVICE_NONE);
 
-  if (drive)
-    g_object_unref (drive);
+  g_free (device);
 }
 
 /*
  * OGMDvdDriveChooser vfuncs
  */
 
-static NautilusBurnDrive *
-ogmdvd_drive_chooser_dialog_get_drive (OGMDvdDriveChooser *chooser)
+static gchar *
+ogmdvd_drive_chooser_dialog_get_device (OGMDvdDriveChooser *chooser, OGMDvdDeviceType *type)
 {
   OGMDvdDriveChooserDialog *dialog;
 
@@ -212,7 +209,7 @@ ogmdvd_drive_chooser_dialog_get_drive (OGMDvdDriveChooser *chooser)
 
   dialog = OGMDVD_DRIVE_CHOOSER_DIALOG (chooser);
 
-  return ogmdvd_drive_chooser_get_drive (OGMDVD_DRIVE_CHOOSER (dialog->priv->chooser));
+  return ogmdvd_drive_chooser_get_device (OGMDVD_DRIVE_CHOOSER (dialog->priv->chooser), type);
 }
 
 /*
@@ -222,22 +219,36 @@ ogmdvd_drive_chooser_dialog_get_drive (OGMDvdDriveChooser *chooser)
 static void
 ogmdvd_drive_chooser_dialog_eject_clicked (GtkDialog *dialog)
 {
-  NautilusBurnDrive *drive;
-    
-  drive = ogmdvd_drive_chooser_get_drive (OGMDVD_DRIVE_CHOOSER (OGMDVD_DRIVE_CHOOSER_DIALOG (dialog)->priv->chooser));
-  if (drive)
+  OGMDvdDeviceType type;
+  gchar *device;
+
+  device = ogmdvd_drive_chooser_get_device (OGMDVD_DRIVE_CHOOSER (OGMDVD_DRIVE_CHOOSER_DIALOG (dialog)->priv->chooser), &type);
+  if (device != NULL && type == OGMDVD_DEVICE_BLOCK)
   {
-    g_signal_emit (dialog, signals[EJECT], 0, NULL);
-    nautilus_burn_drive_eject ((NautilusBurnDrive *) drive);
-    g_object_unref (drive);
+    OGMDvdMonitor *monitor;
+    OGMDvdDrive *drive;
+
+    monitor = ogmdvd_monitor_get_default ();
+    drive = ogmdvd_monitor_get_drive (monitor, device);
+    g_object_unref (monitor);
+
+    if (drive)
+    {
+      g_signal_emit (dialog, signals[EJECT], 0, NULL);
+      ogmdvd_drive_eject (OGMDVD_DRIVE (drive));
+      g_object_unref (drive);
+    }
   }
+
+  if (device)
+    g_free (device);
 }
 
 static void
-ogmdvd_drive_chooser_dialog_device_changed (OGMDvdDriveChooserDialog *dialog, const gchar *device, GtkWidget *chooser)
+ogmdvd_drive_chooser_dialog_device_changed (OGMDvdDriveChooserDialog *dialog, const gchar *device, OGMDvdDeviceType type, GtkWidget *chooser)
 {
   gtk_widget_set_sensitive (dialog->priv->load_button, device != NULL);
-  gtk_widget_set_sensitive (dialog->priv->eject_button, device != NULL);
+  gtk_widget_set_sensitive (dialog->priv->eject_button, device != NULL && type == OGMDVD_DEVICE_BLOCK);
 }
 
 /**
