@@ -29,6 +29,7 @@
  */
 
 #include "ogmdvd-drive-chooser.h"
+#include "ogmdvd-marshal.h"
 
 static void ogmdvd_drive_chooser_class_init (gpointer g_iface);
 
@@ -66,22 +67,23 @@ ogmdvd_drive_chooser_class_init (gpointer g_iface)
   g_signal_new ("device-changed", iface_type,
       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
       G_STRUCT_OFFSET (OGMDvdDriveChooserIface, device_changed), NULL, NULL,
-      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
+      ogmdvd_cclosure_marshal_VOID__STRING_UINT, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_UINT);
 }
 
 /**
- * ogmdvd_drive_chooser_get_drive:
+ * ogmdvd_drive_chooser_get_device:
  * @chooser: An #OGMDvdDriveChooser
+ * @type: Location to store the type of the device, or NULL
  *
- * Returns the selected #NautilusBurnDrive.
+ * Returns the selected device.
  *
- * Returns: A #NautilusBurnDrive
+ * Returns: A device or NULL
  */
-NautilusBurnDrive *
-ogmdvd_drive_chooser_get_drive (OGMDvdDriveChooser *chooser)
+gchar *
+ogmdvd_drive_chooser_get_device (OGMDvdDriveChooser *chooser, OGMDvdDeviceType *type)
 {
   g_return_val_if_fail (OGMDVD_IS_DRIVE_CHOOSER (chooser), NULL);
 
-  return OGMDVD_DRIVE_CHOOSER_GET_IFACE (chooser)->get_drive (chooser);
+  return OGMDVD_DRIVE_CHOOSER_GET_IFACE (chooser)->get_device (chooser, type);
 }
 
