@@ -19,11 +19,20 @@
 #ifndef __OGMDVD_DRIVE_CHOOSER_H__
 #define __OGMDVD_DRIVE_CHOOSER_H__
 
-#include <gtk/gtkwidget.h>
-#include <nautilus-burn-drive.h>
+#include <gtk/gtk.h>
+
+#include <ogmdvd-drive.h>
 
 G_BEGIN_DECLS
 
+typedef enum
+{
+  OGMDVD_DEVICE_NONE,
+  OGMDVD_DEVICE_BLOCK,
+  OGMDVD_DEVICE_FILE,
+  OGMDVD_DEVICE_DIR
+} OGMDvdDeviceType;
+
 #define OGMDVD_TYPE_DRIVE_CHOOSER            (ogmdvd_drive_chooser_get_type ())
 #define OGMDVD_DRIVE_CHOOSER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMDVD_TYPE_DRIVE_CHOOSER, OGMDvdDriveChooser))
 #define OGMDVD_IS_DRIVE_CHOOSER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMDVD_TYPE_DRIVE_CHOOSER))
@@ -39,19 +48,22 @@ struct _OGMDvdDriveChooserIface
   /*
    * Methods
    */
-  NautilusBurnDrive * (*get_drive) (OGMDvdDriveChooser *chooser);
+  gchar * (*get_device) (OGMDvdDriveChooser *chooser,
+                         OGMDvdDeviceType   *type);
 
   /*
    * Signals
    */
   void (* device_changed) (OGMDvdDriveChooser *chooser, 
-                           const char         *device_path);
+                           const char         *device_path,
+                           OGMDvdDeviceType   type);
 };
 
 
-GType ogmdvd_drive_chooser_get_type (void) G_GNUC_CONST;
+GType   ogmdvd_drive_chooser_get_type   (void) G_GNUC_CONST;
 
-NautilusBurnDrive * ogmdvd_drive_chooser_get_drive (OGMDvdDriveChooser *chooser);
+gchar * ogmdvd_drive_chooser_get_device (OGMDvdDriveChooser *chooser,
+                                         OGMDvdDeviceType   *type);
 
 G_END_DECLS
 
