@@ -19,7 +19,8 @@
 #ifndef __OGMDVD_TITLE_CHOOSER_H__
 #define __OGMDVD_TITLE_CHOOSER_H__
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
+
 #include <ogmdvd.h>
 
 G_BEGIN_DECLS
