@@ -351,36 +351,30 @@ ogmdvd_subp_stream_new (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr, gu
 static gulong
 ogmdvd_title_get_chapter_length (OGMDvdTitle *title, ifo_handle_t *vts_file, guint nr)
 {
-  pgc_t *pgc;
+  glong total = 0;
+  guint8 first_cell, last_cell;
   guint16 pgcn, pgn;
-  guint8 cell, last;
-  glong total;
+  pgc_t *pgc;
 
   pgcn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[nr].pgcn;
-  g_return_val_if_fail (pgcn > 0 && pgcn < 1000, 0);
-
+  pgn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[nr].pgn;
   pgc = vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc;
 
-  if (nr == 0 && nr + 1 == pgc->nr_of_programs)
-    return ogmdvd_time_to_msec (&pgc->playback_time);
-
-  pgn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[nr].pgn;
-  g_return_val_if_fail (pgn > 0 && pgn < 100, 0);
-
-  cell = pgc->program_map[pgn - 1] - 1;
-
-  if (nr + 1 == pgc->nr_of_programs)
-    last = pgc->nr_of_cells;
+  first_cell = pgc->program_map[pgn - 1];
+  if (pgn < pgc->nr_of_programs)
+    last_cell = pgc->program_map[pgn];
   else
+    last_cell = 0;
+
+  do
   {
-    pgn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[nr + 1].pgn;
-    g_return_val_if_fail (pgn > 0 && pgn < 100, 0);
+    if (pgc->cell_playback[first_cell - 1].block_type != BLOCK_TYPE_ANGLE_BLOCK ||
+        pgc->cell_playback[first_cell - 1].block_type == BLOCK_MODE_FIRST_CELL)
+      total += ogmdvd_time_to_msec (&pgc->cell_playback[first_cell - 1].playback_time);
 
-    last = pgc->program_map[pgn - 1] - 1;
+    first_cell ++;
   }
-
-  for (total = 0; cell < last; cell ++)
-    total += ogmdvd_time_to_msec (&pgc->cell_playback[cell].playback_time);
+  while (first_cell < last_cell);
 
   return total;
 }
@@ -395,32 +389,24 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
   pgc_t *pgc;
 
   guint16 pgcn;
-  guint8 ttn, i;
-
-  ttn = vmg_file->tt_srpt->title[nr].vts_ttn;
-  g_return_val_if_fail (ttn > 0 && ttn < 100, NULL);
+  guint8 i;
 
   vts_file = ifoOpen (reader, vmg_file->tt_srpt->title[nr].title_set_nr);
   if (!vts_file)
     return NULL;
 
-  pgcn = vts_file->vts_ptt_srpt->title[ttn - 1].ptt[0].pgcn;
-  if (pgcn <= 0 || pgcn >= 1000)
-    ifoClose (vts_file);
-  g_return_val_if_fail (pgcn > 0 && pgcn < 1000, NULL);
-
   title = g_new0 (OGMDvdTitle, 1);
   title->disc = disc;
-  title->pgcn = pgcn;
-  title->ttn = ttn;
+  title->ttn = vmg_file->tt_srpt->title[nr].vts_ttn;
   title->nr = nr;
 
+  pgcn = vts_file->vts_ptt_srpt->title[title->ttn - 1].ptt[0].pgcn;
   pgc = vts_file->vts_pgcit->pgci_srp[pgcn - 1].pgc;
 
   memcpy (title->palette, pgc->palette, 16 * sizeof (uint32_t));
+  title->playback_time = pgc->playback_time;
 
-  title->nr_of_cells = pgc->nr_of_cells;
-  title->nr_of_programs = pgc->nr_of_programs;
+  title->nr_of_chapters = vts_file->vts_ptt_srpt->title[title->ttn - 1].nr_of_ptts;
   title->nr_of_angles = vmg_file->tt_srpt->title[nr].nr_of_angles;
   title->title_set_nr = vmg_file->tt_srpt->title[nr].title_set_nr;
 
@@ -433,7 +419,7 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
 
   for (i = 0; i < vts_file->vtsi_mat->nr_of_vts_audio_streams; i++)
   {
-    if (vts_file->vts_pgcit->pgci_srp[ttn - 1].pgc->audio_control[i] & 0x8000)
+    if (vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->audio_control[i] & 0x8000)
     {
       stream = ogmdvd_audio_stream_new (title, vts_file, title->nr_of_audio_streams, i);
       if (stream)
@@ -444,7 +430,7 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
 
   for (i = 0; i < vts_file->vtsi_mat->nr_of_vts_subp_streams; i++)
   {
-    if (vts_file->vts_pgcit->pgci_srp[ttn - 1].pgc->subp_control[i] & 0x80000000)
+    if (vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[i] & 0x80000000)
     {
       stream = ogmdvd_subp_stream_new (title, vts_file, title->nr_of_subp_streams, i);
       if (stream)
@@ -453,11 +439,9 @@ ogmdvd_title_new (OGMDvdDisc *disc, dvd_reader_t *reader, ifo_handle_t *vmg_file
     }
   }
 
-  title->length_of_programs = g_new0 (gulong, title->nr_of_programs);
-  for (i = 0; i < title->nr_of_programs; i ++)
-    title->length_of_programs[i] = ogmdvd_title_get_chapter_length (title, vts_file, i);
-
-  title->playback_time = pgc->playback_time;
+  title->length_of_chapters = g_new0 (gulong, title->nr_of_chapters);
+  for (i = 0; i < title->nr_of_chapters; i ++)
+    title->length_of_chapters[i] = ogmdvd_title_get_chapter_length (title, vts_file, i);
 
   ifoClose (vts_file);
 
@@ -489,10 +473,10 @@ ogmdvd_title_free (OGMDvdTitle *title)
     title->subp_streams = NULL;
   }
 
-  if (title->length_of_programs)
+  if (title->length_of_chapters)
   {
-    g_free (title->length_of_programs);
-    title->length_of_programs = NULL;
+    g_free (title->length_of_chapters);
+    title->length_of_chapters = NULL;
   }
 
   title->disc = NULL;
