@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,11 +29,13 @@ G_BEGIN_DECLS
  * OGMDvdDiscError:
  * @OGMDVD_DISC_ERROR_EXIST: No such file or directory
  * @OGMDVD_DISC_ERROR_PERM: Permission denied to access device
- * @OGMDVD_DISC_ERROR_TRAY: Tray seems to be opened
+ * @OGMDVD_DISC_ERROR_TRAY: Tray seems to be open
  * @OGMDVD_DISC_ERROR_DEV: Device does not contain a valid DVD video
  * @OGMDVD_DISC_ERROR_PATH: Path does not contain a valid DVD structure
  * @OGMDVD_DISC_ERROR_ACCESS: No such directory, block device or iso file
  * @OGMDVD_DISC_ERROR_VMG: Cannot open video manager
+ * @OGMDVD_DISC_ERROR_VTS: Cannot open video titleset
+ * @OGMDVD_DISC_ERROR_ID: The DVD identifiers differ
  * @OGMDVD_DISC_ERROR_UNKNOWN: Unknown error
  *
  * Error codes returned by ogmdvd_disc_open()
@@ -42,21 +44,32 @@ typedef enum
 {
   OGMDVD_DISC_ERROR_EXIST,  /* No such file or directory */
   OGMDVD_DISC_ERROR_PERM,   /* Permission denied to access device */
-  OGMDVD_DISC_ERROR_TRAY,   /* Tray seems to be opened */
+  OGMDVD_DISC_ERROR_TRAY,   /* Tray seems to be open */
   OGMDVD_DISC_ERROR_DEV,    /* Device does not contain a valid DVD video */
   OGMDVD_DISC_ERROR_PATH,   /* Path does not contain a valid DVD structure */
   OGMDVD_DISC_ERROR_ACCESS, /* No such directory, block device or iso file */
   OGMDVD_DISC_ERROR_VMG,    /* Cannot open video manager */
+  OGMDVD_DISC_ERROR_VTS,    /* Cannot open video titleset */
+  OGMDVD_DISC_ERROR_ID,     /* The DVD IDs differ */
   OGMDVD_DISC_ERROR_UNKNOWN /* Unknown error */
 } OGMDvdDiscError;
 
-GQuark        ogmdvd_disc_error_quark   (void);
+GQuark        ogmdvd_error_quark        (void);
 
-OGMDvdDisc *  ogmdvd_disc_open          (const gchar *device,
+OGMDvdDisc *  ogmdvd_disc_new           (const gchar *device,
                                          GError      **error);
+
+gboolean      ogmdvd_disc_open          (OGMDvdDisc  *disc,
+                                         GError      **error);
+void          ogmdvd_disc_close         (OGMDvdDisc  *disc);
+
+gboolean      ogmdvd_disc_is_open       (OGMDvdDisc  *disc);
+
 void          ogmdvd_disc_ref           (OGMDvdDisc  *disc);
 void          ogmdvd_disc_unref         (OGMDvdDisc  *disc);
+G_CONST_RETURN
 gchar *       ogmdvd_disc_get_label     (OGMDvdDisc  *disc);
+G_CONST_RETURN
 gchar *       ogmdvd_disc_get_id        (OGMDvdDisc  *disc);
 G_CONST_RETURN
 gchar *       ogmdvd_disc_get_device    (OGMDvdDisc  *disc);
@@ -64,7 +77,7 @@ gint64        ogmdvd_disc_get_vmg_size  (OGMDvdDisc  *disc);
 gint          ogmdvd_disc_get_n_titles  (OGMDvdDisc  *disc);
 OGMDvdTitle * ogmdvd_disc_get_nth_title (OGMDvdDisc  *disc,
                                          guint       nr);
-GList *       ogmdvd_disc_get_titles    (OGMDvdDisc  *disc);
+GSList *      ogmdvd_disc_get_titles    (OGMDvdDisc  *disc);
 
 G_END_DECLS
 
