@@ -238,7 +238,7 @@ const gchar *ogmdvd_languages[][3] =
   { NULL, NULL,  NULL },
 };
 
-guint ogmdvd_nlanguages = sizeof (ogmdvd_languages) / sizeof (ogmdvd_languages[0]) - 1;
+const guint ogmdvd_nlanguages = G_N_ELEMENTS (ogmdvd_languages) - 1;
 
 /**
  * ogmdvd_get_video_format_label:
@@ -339,7 +339,7 @@ ogmdvd_get_audio_channels_label (gint channels)
     "7.1"
   };
 
-  g_return_val_if_fail (channels >= 0 && channels && channels <= 7, NULL);
+  g_return_val_if_fail (channels >= 0 && channels <= 7, NULL);
 
   return audio_channels[channels];
 }
