@@ -63,7 +63,6 @@ struct _OGMDvdTitle
   guint nr;
 
   guint8 nr_of_angles;
-  guint8 nr_of_cells;
 
   guint8 nr_of_audio_streams;
   GSList *audio_streams;
@@ -71,8 +70,8 @@ struct _OGMDvdTitle
   guint8 nr_of_subp_streams;
   GSList *subp_streams;
 
-  gulong *length_of_programs;
-  guint8 nr_of_programs;
+  gulong *length_of_chapters;
+  guint8 nr_of_chapters;
 
   guint64 vts_size;
 
@@ -89,7 +88,6 @@ struct _OGMDvdTitle
   gboolean close_disc;
 
   guint8 ttn;
-  guint16 pgcn;
 
   guint8 title_set_nr;
   ifo_handle_t *vts_file;
