@@ -242,13 +242,13 @@ ogmdvd_reader_get_next_cell (OGMDvdReader *reader)
 
   next_cell ++;
   if (next_cell >= reader->last_cell)
-    return 0; // EOF
+    return 0; /* EOF */
 
   if (reader->pgc->cell_playback[next_cell].block_type == BLOCK_TYPE_ANGLE_BLOCK )
   {
     next_cell += reader->angle;
     if (next_cell >= reader->last_cell)
-      return 0; // EOF
+      return 0; /* EOF */
   }
 
   reader->cur_cell = next_cell;
