@@ -250,17 +250,17 @@ ogmdvd_title_get_chapters_length (OGMDvdTitle *title, guint start, gint end, OGM
   gulong total;
 
   g_return_val_if_fail (title != NULL, -1.0);
-  g_return_val_if_fail (start < title->nr_of_programs, -1.0);
+  g_return_val_if_fail (start < title->nr_of_chapters, -1.0);
   g_return_val_if_fail (end < 0 || start <= end, -1.0);
 
   if (end < 0)
-    end = title->nr_of_programs - 1;
+    end = title->nr_of_chapters - 1;
 
-  if (start == 0 && end + 1 == title->nr_of_programs)
+  if (start == 0 && end + 1 == title->nr_of_chapters)
     return ogmdvd_title_get_length (title, length);
 
   for (total = 0; start <= end; start ++)
-    total += title->length_of_programs[start];
+    total += title->length_of_chapters[start];
 
   if (length)
     ogmdvd_msec_to_time (total, length);
@@ -474,7 +474,7 @@ ogmdvd_title_get_n_chapters (OGMDvdTitle *title)
 {
   g_return_val_if_fail (title != NULL, -1);
 
-  return title->nr_of_programs;
+  return title->nr_of_chapters;
 }
 
 /**
