@@ -21,8 +21,10 @@
 
 #include <ogmdvd-audio.h>
 #include <ogmdvd-disc.h>
+#include <ogmdvd-drive.h>
 #include <ogmdvd-enums.h>
 #include <ogmdvd-labels.h>
+#include <ogmdvd-monitor.h>
 #include <ogmdvd-parser.h>
 #include <ogmdvd-reader.h>
 #include <ogmdvd-stream.h>
