@@ -87,7 +87,7 @@ ogmjob_bin_run (OGMJobSpawn *spawn)
     return result;
   }
 
-  return OGMJOB_RESULT_COMPLETED;
+  return OGMJOB_RESULT_SUCCESS;
 }
 
 static void
