@@ -190,12 +190,11 @@ ogmjob_exec_stderr_notify (OGMJobExec *exec)
 }
 
 static gboolean
-ogmjob_exec_watch (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec, gboolean do_log)
+ogmjob_exec_watch (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec, gboolean do_watch, gboolean do_log)
 {
   GIOStatus status;
-  gchar **vline, *buffer;
   gsize size, bytes_read;
-  guint i;
+  gchar *buffer;
 
   if (exec->priv->error)
     return FALSE;
@@ -219,34 +218,41 @@ ogmjob_exec_watch (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec
     g_print ("%s", buffer);
 #endif
 
-  vline = g_strsplit_set (buffer, "\r\n", -1);
-  g_free (buffer);
-
-  if (vline)
+  if (do_watch)
   {
-    for (i = 0; vline[i]; i++)
+    gchar **vline;
+
+    vline = g_strsplit_set (buffer, "\r\n", -1);
+    g_free (buffer);
+
+    if (vline)
     {
-      if (strlen (vline[i]) > 0)
+      guint i;
+
+      for (i = 0; vline[i]; i++)
       {
-        if (exec->priv->watch_func)
+        if (strlen (vline[i]) > 0)
         {
-          gdouble fraction;
-
-          fraction = exec->priv->watch_func (exec, vline[i], exec->priv->watch_data);
-          fraction = MIN (fraction, 1.0);
-
-          if (fraction > 0.0 && fraction > exec->priv->fraction + 0.001)
+          if (exec->priv->watch_func)
           {
-            exec->priv->fraction = fraction;
-            if (exec->priv->swapped)
-              g_signal_emit_by_name (exec->priv->watch_data, "progress", fraction);
-            else
-              g_signal_emit_by_name (exec, "progress", fraction);
+            gdouble fraction;
+
+            fraction = exec->priv->watch_func (exec, vline[i], exec->priv->watch_data);
+            fraction = MIN (fraction, 1.0);
+
+            if (fraction > 0.0 && fraction > exec->priv->fraction + 0.001)
+            {
+              exec->priv->fraction = fraction;
+              if (exec->priv->swapped)
+                g_signal_emit_by_name (exec->priv->watch_data, "progress", fraction);
+              else
+                g_signal_emit_by_name (exec, "progress", fraction);
+            }
           }
         }
       }
+      g_strfreev (vline);
     }
-    g_strfreev (vline);
   }
 
   return TRUE;
@@ -255,13 +261,13 @@ ogmjob_exec_watch (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec
 static gboolean
 ogmjob_exec_watch_stdout (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec)
 {
-  return ogmjob_exec_watch (channel, condition, exec, FALSE);
+  return ogmjob_exec_watch (channel, condition, exec, exec->priv->watch_out, FALSE);
 }
 
 static gboolean
 ogmjob_exec_watch_stderr (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec)
 {
-  return ogmjob_exec_watch (channel, condition, exec, TRUE);
+  return ogmjob_exec_watch (channel, condition, exec, exec->priv->watch_err, TRUE);
 }
 
 static gint
@@ -270,7 +276,6 @@ ogmjob_exec_run (OGMJobSpawn *spawn)
   OGMJobExec *exec;
   GSpawnFlags flags;
   GIOChannel *channel;
-  gint *ptrout, *ptrerr;
   gint fdout, fderr;
   guint i;
 
@@ -286,48 +291,30 @@ ogmjob_exec_run (OGMJobSpawn *spawn)
 
   flags = G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD;
 
-  ptrout = NULL;
-  if (exec->priv->watch_out)
-    ptrout = &fdout;
-  else
-    flags |= G_SPAWN_STDOUT_TO_DEV_NULL;
-
-  ptrerr = NULL;
-  if (exec->priv->watch_err)
-    ptrerr = &fderr;
-  else
-    flags |= G_SPAWN_STDERR_TO_DEV_NULL;
-
   if (!g_spawn_async_with_pipes (NULL, exec->priv->argv, NULL, flags, NULL, NULL, 
-        &exec->priv->pid, NULL, ptrout, ptrerr, &exec->priv->error))
+        &exec->priv->pid, NULL, &fdout, &fderr, &exec->priv->error))
     return OGMJOB_RESULT_ERROR;
 
   exec->priv->src_pid = g_child_watch_add_full (G_PRIORITY_DEFAULT_IDLE, exec->priv->pid, 
       (GChildWatchFunc) ogmjob_exec_pid_watch, exec, (GDestroyNotify) ogmjob_exec_pid_notify);
 
-  if (ptrout)
-  {
-    fcntl (fdout, F_SETFL, O_NONBLOCK);
-    channel = g_io_channel_unix_new (fdout);
-    g_io_channel_set_close_on_unref (channel, TRUE);
-    g_io_channel_set_encoding (channel, NULL, NULL);
-    exec->priv->src_out = g_io_add_watch_full (channel, G_PRIORITY_DEFAULT_IDLE,
-        G_IO_IN | G_IO_HUP | G_IO_ERR, (GIOFunc) ogmjob_exec_watch_stdout, exec, 
-        (GDestroyNotify) ogmjob_exec_stdout_notify);
-    g_io_channel_unref (channel);
-  }
+  fcntl (fdout, F_SETFL, O_NONBLOCK);
+  channel = g_io_channel_unix_new (fdout);
+  g_io_channel_set_close_on_unref (channel, TRUE);
+  g_io_channel_set_encoding (channel, NULL, NULL);
+  exec->priv->src_out = g_io_add_watch_full (channel, G_PRIORITY_DEFAULT_IDLE,
+      G_IO_IN | G_IO_HUP | G_IO_ERR, (GIOFunc) ogmjob_exec_watch_stdout, exec, 
+      (GDestroyNotify) ogmjob_exec_stdout_notify);
+  g_io_channel_unref (channel);
 
-  if (ptrerr)
-  {
-    fcntl (fderr, F_SETFL, O_NONBLOCK);
-    channel = g_io_channel_unix_new (fderr);
-    g_io_channel_set_close_on_unref (channel, TRUE);
-    g_io_channel_set_encoding (channel, NULL, NULL);
-    exec->priv->src_err = g_io_add_watch_full (channel, G_PRIORITY_DEFAULT_IDLE,
-        G_IO_IN | G_IO_HUP | G_IO_ERR, (GIOFunc) ogmjob_exec_watch_stderr, exec, 
-        (GDestroyNotify) ogmjob_exec_stderr_notify);
-    g_io_channel_unref (channel);
-  }
+  fcntl (fderr, F_SETFL, O_NONBLOCK);
+  channel = g_io_channel_unix_new (fderr);
+  g_io_channel_set_close_on_unref (channel, TRUE);
+  g_io_channel_set_encoding (channel, NULL, NULL);
+  exec->priv->src_err = g_io_add_watch_full (channel, G_PRIORITY_DEFAULT_IDLE,
+      G_IO_IN | G_IO_HUP | G_IO_ERR, (GIOFunc) ogmjob_exec_watch_stderr, exec, 
+      (GDestroyNotify) ogmjob_exec_stderr_notify);
+  g_io_channel_unref (channel);
 
   if (!ogmjob_spawn_get_async (OGMJOB_SPAWN (exec)))
   {
