@@ -70,7 +70,7 @@ ogmjob_pipeline_run (OGMJobSpawn *spawn)
   GList *children, *child;
 
   GError *tmp_error = NULL;
-  gint result = OGMJOB_RESULT_COMPLETED;
+  gint result = OGMJOB_RESULT_SUCCESS;
 
   pipeline = OGMJOB_PIPELINE (spawn);
 
@@ -79,7 +79,7 @@ ogmjob_pipeline_run (OGMJobSpawn *spawn)
 
   for (child = children; child; child = child->next)
   {
-    if (result != OGMJOB_RESULT_COMPLETED)
+    if (result != OGMJOB_RESULT_SUCCESS)
       break;
 
     ogmjob_spawn_set_async (OGMJOB_SPAWN (child->data), child->next != NULL);
