@@ -75,7 +75,7 @@ ogmjob_queue_run (OGMJobSpawn *spawn)
   GList *child, *children;
 
   GError *tmp_error = NULL;
-  gint result = OGMJOB_RESULT_COMPLETED;
+  gint result = OGMJOB_RESULT_SUCCESS;
 
   queue = OGMJOB_QUEUE (spawn);
 
@@ -85,7 +85,7 @@ ogmjob_queue_run (OGMJobSpawn *spawn)
 
   for (child = children; child; child = child->next)
   {
-    if (result != OGMJOB_RESULT_COMPLETED)
+    if (result != OGMJOB_RESULT_SUCCESS)
       break;
 
     ogmjob_spawn_set_async (OGMJOB_SPAWN (child->data), FALSE);
