@@ -40,9 +40,9 @@ G_BEGIN_DECLS
  */
 typedef enum
 {
-  OGMJOB_RESULT_ERROR,
-  OGMJOB_RESULT_CANCEL,
-  OGMJOB_RESULT_COMPLETED
+  OGMJOB_RESULT_ERROR   = -1,
+  OGMJOB_RESULT_CANCEL  =  0,
+  OGMJOB_RESULT_SUCCESS =  1
 } OGMJobResultType;
 
 typedef struct _OGMJobSpawn      OGMJobSpawn;
