@@ -20,7 +20,8 @@
 #define __OGMRIP_GTK_H__
 
 #include <ogmrip-helper.h>
-#include <ogmrip-preferences.h>
+
+#include <ogmrip-gconf-settings.h>
 
 #include <ogmrip-options-plugin.h>
 
