@@ -533,7 +533,11 @@ ogmrip_source_chooser_widget_changed (GtkComboBox *combo_box)
 
     if (type == ROW_TYPE_OTHER)
     {
+#if GTK_CHECK_VERSION(2,18,0)
+      if (!gtk_widget_get_visible (chooser->priv->dialog))
+#else
       if (!GTK_WIDGET_VISIBLE (chooser->priv->dialog))
+#endif
       {
         GtkWidget *toplevel;
 
