@@ -38,6 +38,9 @@
 #define OGMRIP_IS_X264_DIALOG(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_X264_DIALOG))
 #define OGMRIP_IS_X264_DIALOG_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_X264_DIALOG))
 
+#define OGMRIP_X264_PROP_PROFILE      "profile"
+#define OGMRIP_X264_DEFAULT_PROFILE   OGMRIP_X264_PROFILE_HIGH
+
 #define OGMRIP_X264_KEY_8X8DCT        OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_8X8DCT
 #define OGMRIP_X264_KEY_AUD           OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_AUD
 #define OGMRIP_X264_KEY_BFRAMES       OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_BFRAMES
@@ -45,13 +48,17 @@
 #define OGMRIP_X264_KEY_B_PYRAMID     OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_B_PYRAMID
 #define OGMRIP_X264_KEY_BRDO          OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_BRDO
 #define OGMRIP_X264_KEY_CABAC         OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_CABAC
+#define OGMRIP_X264_KEY_CQM           OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_CQM
 #define OGMRIP_X264_KEY_DIRECT        OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_DIRECT
 #define OGMRIP_X264_KEY_FRAMEREF      OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_FRAMEREF
 #define OGMRIP_X264_KEY_GLOBAL_HEADER OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_GLOBAL_HEADER
+#define OGMRIP_X264_KEY_KEYINT        OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_KEYINT
 #define OGMRIP_X264_KEY_LEVEL_IDC     OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_LEVEL_IDC
 #define OGMRIP_X264_KEY_ME            OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_ME
 #define OGMRIP_X264_KEY_MERANGE       OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_MERANGE
 #define OGMRIP_X264_KEY_MIXED_REFS    OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_MIXED_REFS
+#define OGMRIP_X264_KEY_PARTITIONS    OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_PARTITIONS
+#define OGMRIP_X264_KEY_PROFILE       OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_PROFILE
 #define OGMRIP_X264_KEY_PSY_RD        OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_PSY_RD
 #define OGMRIP_X264_KEY_PSY_TRELLIS   OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_PSY_TRELLIS
 #define OGMRIP_X264_KEY_RC_LOOKAHEAD  OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_RC_LOOKAHEAD
@@ -59,6 +66,7 @@
 #define OGMRIP_X264_KEY_VBV_BUFSIZE   OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_VBV_BUFSIZE
 #define OGMRIP_X264_KEY_VBV_MAXRATE   OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_VBV_MAXRATE
 #define OGMRIP_X264_KEY_WEIGHT_B      OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_WEIGHT_B
+#define OGMRIP_X264_KEY_WEIGHT_P      OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_WEIGHT_P
 
 typedef struct _OGMRipX264Dialog      OGMRipX264Dialog;
 typedef struct _OGMRipX264DialogClass OGMRipX264DialogClass;
@@ -73,12 +81,14 @@ struct _OGMRipX264Dialog
   GtkWidget *cabac_check;
   GtkWidget *global_header_check;
   GtkWidget *mixed_refs_check;
+  GtkWidget *partitions_check;
   GtkWidget *weight_b_check;
   GtkWidget *x88dct_check;
 
   GtkWidget *b_adapt_spin;
   GtkWidget *bframes_spin;
   GtkWidget *frameref_spin;
+  GtkWidget *keyint_spin;
   GtkWidget *level_idc_spin;
   GtkWidget *merange_spin;
   GtkWidget *psy_rd_spin;
@@ -88,8 +98,12 @@ struct _OGMRipX264Dialog
   GtkWidget *vbv_bufsize_spin;
   GtkWidget *vbv_maxrate_spin;
 
+  GtkWidget *b_pyramid_combo;
+  GtkWidget *cqm_combo;
   GtkWidget *direct_combo;
   GtkWidget *me_combo;
+  GtkWidget *profile_combo;
+  GtkWidget *weight_p_combo;
 };
 
 struct _OGMRipX264DialogClass
@@ -97,16 +111,56 @@ struct _OGMRipX264DialogClass
   OGMRipPluginDialogClass parent_class;
 };
 
+enum
+{
+  OGMRIP_X264_PROFILE_BASELINE,
+  OGMRIP_X264_PROFILE_MAIN,
+  OGMRIP_X264_PROFILE_HIGH
+};
+
 GType ogmrip_x264_get_type ();
 
 static void ogmrip_x264_dialog_set_section   (OGMRipPluginDialog *dialog,
                                               const gchar        *section);
 
-static gboolean x264_have_brdo      = FALSE;
-static gboolean x264_have_psy       = FALSE;
-static gboolean x264_have_aud       = FALSE;
-static gboolean x264_have_lookahead = FALSE;
-static gboolean x264_have_me_tesa   = FALSE;
+static gboolean x264_have_8x8dct     = FALSE;
+static gboolean x264_have_aud        = FALSE;
+static gboolean x264_have_b_pyramid  = FALSE;
+static gboolean x264_have_brdo       = FALSE;
+static gboolean x264_have_lookahead  = FALSE;
+static gboolean x264_have_me         = FALSE;
+static gboolean x264_have_me_tesa    = FALSE;
+static gboolean x264_have_mixed_refs = FALSE;
+static gboolean x264_have_psy        = FALSE;
+static gboolean x264_have_weight_p   = FALSE;
+
+static void
+ogmrip_x264_dialog_profile_changed (OGMRipX264Dialog *dialog)
+{
+  gint profile;
+
+  profile = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->profile_combo));
+
+  if (profile != OGMRIP_X264_PROFILE_HIGH)
+  {
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->x88dct_check), FALSE);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->cqm_combo), 0);
+  }
+
+  gtk_widget_set_sensitive (dialog->x88dct_check, x264_have_8x8dct && profile == OGMRIP_X264_PROFILE_HIGH);
+  gtk_widget_set_sensitive (dialog->cqm_combo, profile == OGMRIP_X264_PROFILE_HIGH);
+
+  if (profile == OGMRIP_X264_PROFILE_BASELINE)
+  {
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->cabac_check), FALSE);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->weight_p_combo), 0);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->bframes_spin), 0);
+  }
+
+  gtk_widget_set_sensitive (dialog->cabac_check, profile != OGMRIP_X264_PROFILE_BASELINE);
+  gtk_widget_set_sensitive (dialog->weight_p_combo, x264_have_weight_p && profile != OGMRIP_X264_PROFILE_BASELINE);
+  gtk_widget_set_sensitive (dialog->bframes_spin, profile != OGMRIP_X264_PROFILE_BASELINE);
+}
 
 static void
 ogmrip_x264_dialog_bframes_changed (OGMRipX264Dialog *dialog)
@@ -116,10 +170,12 @@ ogmrip_x264_dialog_bframes_changed (OGMRipX264Dialog *dialog)
   bframes = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->bframes_spin));
 
   gtk_widget_set_sensitive (dialog->b_pyramid_check, bframes > 1);
+  gtk_widget_set_sensitive (dialog->b_pyramid_combo, bframes > 1);
   gtk_widget_set_sensitive (dialog->weight_b_check, bframes > 1);
 
   if (bframes <= 1)
   {
+    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->b_pyramid_combo), 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->b_pyramid_check), FALSE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->weight_b_check), FALSE);
   }
@@ -149,7 +205,7 @@ ogmrip_x264_dialog_frameref_changed (OGMRipX264Dialog *dialog)
 
   frameref = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->frameref_spin));
 
-  gtk_widget_set_sensitive (dialog->mixed_refs_check, frameref > 1);
+  gtk_widget_set_sensitive (dialog->mixed_refs_check, x264_have_mixed_refs && frameref > 1);
   if (frameref <= 1)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->mixed_refs_check), FALSE);
 }
@@ -199,31 +255,57 @@ ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
   gtk_widget_show (widget);
 
+  dialog->profile_combo = glade_xml_get_widget (xml, "profile-combo");
+  g_signal_connect_swapped (dialog->profile_combo, "changed",
+      G_CALLBACK (ogmrip_x264_dialog_profile_changed), dialog);
+
   dialog->bframes_spin = glade_xml_get_widget (xml, "bframes-spin");
   g_signal_connect_swapped (dialog->bframes_spin, "value-changed",
       G_CALLBACK (ogmrip_x264_dialog_bframes_changed), dialog);
 
   dialog->cabac_check = glade_xml_get_widget (xml, "cabac-check");
+  dialog->cqm_combo = glade_xml_get_widget (xml, "cqm-combo");
 
   dialog->subq_spin = glade_xml_get_widget (xml, "subq-spin");
   g_signal_connect_swapped (dialog->subq_spin, "value-changed",
       G_CALLBACK (ogmrip_x264_dialog_subq_changed), dialog);
   
   dialog->global_header_check = glade_xml_get_widget (xml, "global_header-check");
-  dialog->b_pyramid_check = glade_xml_get_widget (xml, "b_pyramid-check");
   dialog->weight_b_check = glade_xml_get_widget (xml, "weight_b-check");
+  dialog->partitions_check = glade_xml_get_widget (xml, "partitions-check");
+
+  dialog->weight_p_combo = glade_xml_get_widget (xml, "weight_p-combo");
+  gtk_widget_set_sensitive (dialog->weight_p_combo, x264_have_weight_p);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->weight_p_combo), 0);
   
+  dialog->b_pyramid_check = glade_xml_get_widget (xml, "b_pyramid-check");
+  g_object_set (dialog->b_pyramid_check, "visible", !x264_have_b_pyramid, NULL);
+
+  dialog->b_pyramid_combo = glade_xml_get_widget (xml, "b_pyramid-combo");
+  g_object_set (dialog->b_pyramid_combo, "visible", x264_have_b_pyramid, NULL);
+
+  widget = glade_xml_get_widget (xml, "b_pyramid-label");
+  g_object_set (widget, "visible", x264_have_b_pyramid, NULL);
+
   dialog->frameref_spin = glade_xml_get_widget (xml, "frameref-spin");
   g_signal_connect_swapped (dialog->frameref_spin, "value-changed",
       G_CALLBACK (ogmrip_x264_dialog_frameref_changed), dialog);
   
   dialog->me_combo = glade_xml_get_widget (xml, "me-combo");
+  gtk_widget_set_sensitive (dialog->me_combo, x264_have_me);
+
   if (x264_have_me_tesa)
     gtk_combo_box_append_text (GTK_COMBO_BOX (dialog->me_combo),
         _("Transformed Exhaustive search (tesa - even slower)"));
 
+  dialog->merange_spin = glade_xml_get_widget (xml, "merange-spin");
+  gtk_widget_set_sensitive (dialog->merange_spin, x264_have_me);
+
   dialog->x88dct_check = glade_xml_get_widget (xml, "dct8x8-check");
+  gtk_widget_set_sensitive (dialog->x88dct_check, x264_have_8x8dct);
+
   dialog->mixed_refs_check = glade_xml_get_widget (xml, "mixed_refs-check");
+  gtk_widget_set_sensitive (dialog->mixed_refs_check, x264_have_mixed_refs);
   
   dialog->brdo_check = glade_xml_get_widget (xml, "brdo-check");
   gtk_widget_set_sensitive (dialog->brdo_check, x264_have_brdo);
@@ -236,7 +318,7 @@ ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
   dialog->level_idc_spin = glade_xml_get_widget (xml, "level_idc-spin");
   dialog->direct_combo = glade_xml_get_widget (xml, "direct-combo");
   dialog->b_adapt_spin = glade_xml_get_widget (xml, "b_adapt-spin");
-  dialog->merange_spin = glade_xml_get_widget (xml, "merange-spin");
+  dialog->keyint_spin = glade_xml_get_widget (xml, "keyint-spin");
 
   dialog->psy_rd_spin = glade_xml_get_widget (xml, "psy_rd-spin");
   gtk_widget_set_sensitive (dialog->psy_rd_spin, x264_have_psy);
@@ -303,11 +385,17 @@ ogmrip_x264_dialog_set_section (OGMRipPluginDialog *plugin_dialog, const gchar *
         OGMRIP_X264_KEY_LEVEL_IDC, G_OBJECT (dialog->level_idc_spin), "value");
     ogmrip_settings_bind (settings, section,
         OGMRIP_X264_KEY_B_ADAPT, G_OBJECT (dialog->b_adapt_spin), "value");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_KEYINT, G_OBJECT (dialog->keyint_spin), "value");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_PSY_RD, G_OBJECT (dialog->psy_rd_spin), "value");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_PSY_TRELLIS, G_OBJECT (dialog->psy_trellis_spin), "value");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_RC_LOOKAHEAD, G_OBJECT (dialog->rc_lookahead_spin), "value");
 
     ogmrip_settings_bind (settings, section,
         OGMRIP_X264_KEY_CABAC, G_OBJECT (dialog->cabac_check), "active");
-    ogmrip_settings_bind (settings, section,
-        OGMRIP_X264_KEY_B_PYRAMID, G_OBJECT (dialog->b_pyramid_check), "active");
     ogmrip_settings_bind (settings, section,
         OGMRIP_X264_KEY_WEIGHT_B, G_OBJECT (dialog->weight_b_check), "active");
     ogmrip_settings_bind (settings, section,
@@ -316,32 +404,31 @@ ogmrip_x264_dialog_set_section (OGMRipPluginDialog *plugin_dialog, const gchar *
         OGMRIP_X264_KEY_MIXED_REFS, G_OBJECT (dialog->mixed_refs_check), "active");
     ogmrip_settings_bind (settings, section,
         OGMRIP_X264_KEY_GLOBAL_HEADER, G_OBJECT (dialog->global_header_check), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_PARTITIONS, G_OBJECT (dialog->partitions_check), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_BRDO, G_OBJECT (dialog->brdo_check), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_AUD, G_OBJECT (dialog->aud_check), "active");
 
     ogmrip_settings_bind_custom (settings, section,
         OGMRIP_X264_KEY_ME, G_OBJECT (dialog->me_combo), "active",
         ogmrip_x264_get_me, ogmrip_x264_set_me, NULL);
     ogmrip_settings_bind (settings, section,
         OGMRIP_X264_KEY_DIRECT, G_OBJECT (dialog->direct_combo), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_CQM, G_OBJECT (dialog->cqm_combo), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_WEIGHT_P, G_OBJECT (dialog->weight_p_combo), "active");
+    ogmrip_settings_bind (settings, section,
+        OGMRIP_X264_KEY_PROFILE, G_OBJECT (dialog->profile_combo), "active");
 
-    if (x264_have_brdo)
+    if (x264_have_b_pyramid)
       ogmrip_settings_bind (settings, section,
-          OGMRIP_X264_KEY_BRDO, G_OBJECT (dialog->brdo_check), "active");
-
-    if (x264_have_psy)
-    {
+          OGMRIP_X264_KEY_B_PYRAMID, G_OBJECT (dialog->b_pyramid_combo), "active");
+    else
       ogmrip_settings_bind (settings, section,
-          OGMRIP_X264_KEY_PSY_RD, G_OBJECT (dialog->psy_rd_spin), "value");
-      ogmrip_settings_bind (settings, section,
-          OGMRIP_X264_KEY_PSY_TRELLIS, G_OBJECT (dialog->psy_trellis_spin), "value");
-    }
-
-    if (x264_have_aud)
-      ogmrip_settings_bind (settings, section,
-          OGMRIP_X264_KEY_AUD, G_OBJECT (dialog->aud_check), "active");
-
-    if (x264_have_lookahead)
-      ogmrip_settings_bind (settings, section,
-          OGMRIP_X264_KEY_RC_LOOKAHEAD, G_OBJECT (dialog->rc_lookahead_spin), "value");
+          OGMRIP_X264_KEY_B_PYRAMID, G_OBJECT (dialog->b_pyramid_check), "active");
   }
 }
 
@@ -355,6 +442,7 @@ static OGMRipVideoOptionsPlugin x264_options_plugin =
 OGMRipVideoOptionsPlugin *
 ogmrip_init_options_plugin (void)
 {
+  OGMRipSettings *settings;
   GModule *module;
 
   x264_options_plugin.type = ogmrip_plugin_get_video_codec_by_name ("x264");
@@ -366,6 +454,9 @@ ogmrip_init_options_plugin (void)
   {
     gboolean *symbol;
 
+    if (g_module_symbol (module, "x264_have_8x8dct", (gpointer *) &symbol))
+      x264_have_8x8dct = *symbol;
+
     if (g_module_symbol (module, "x264_have_brdo", (gpointer *) &symbol))
       x264_have_brdo = *symbol;
 
@@ -378,8 +469,28 @@ ogmrip_init_options_plugin (void)
     if (g_module_symbol (module, "x264_have_lookahead", (gpointer *) &symbol))
       x264_have_lookahead = *symbol;
 
-    if (g_module_symbol (module, "x264_have_me_tesa", (gpointer *) &symbol))
+    if (g_module_symbol (module, "x264_have_me", (gpointer *) &symbol))
+      x264_have_me = *symbol;
+
+    if (x264_have_me && g_module_symbol (module, "x264_have_me_tesa", (gpointer *) &symbol))
       x264_have_me_tesa = *symbol;
+
+    if (g_module_symbol (module, "x264_have_mixed_refs", (gpointer *) &symbol))
+      x264_have_mixed_refs = *symbol;
+
+    if (g_module_symbol (module, "x264_have_b_pyramid", (gpointer *) &symbol))
+      x264_have_b_pyramid = *symbol;
+
+    if (g_module_symbol (module, "x264_have_weight_p", (gpointer *) &symbol))
+      x264_have_weight_p = *symbol;
+  }
+
+  settings = ogmrip_settings_get_default ();
+  if (settings)
+  {
+    ogmrip_settings_install_key (settings,
+        g_param_spec_uint (OGMRIP_X264_SECTION "/" OGMRIP_X264_PROP_PROFILE, "Profile property", "Set profile",
+          OGMRIP_X264_PROFILE_BASELINE, OGMRIP_X264_PROFILE_HIGH, OGMRIP_X264_DEFAULT_PROFILE, G_PARAM_READWRITE));
   }
 
   x264_options_plugin.dialog = OGMRIP_TYPE_X264_DIALOG;
