@@ -20,7 +20,7 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-aac.h"
+#include "ogmrip-audio-codec.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-fs.h"
@@ -35,6 +35,25 @@
 
 #define PROGRAM "faac"
 
+#define OGMRIP_TYPE_AAC          (ogmrip_aac_get_type ())
+#define OGMRIP_AAC(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_AAC, OGMRipAac))
+#define OGMRIP_AAC_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_AAC, OGMRipAacClass))
+#define OGMRIP_IS_AAC(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_AAC))
+#define OGMRIP_IS_AAC_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_AAC))
+
+typedef struct _OGMRipAac      OGMRipAac;
+typedef struct _OGMRipAacClass OGMRipAacClass;
+
+struct _OGMRipAac
+{
+  OGMRipAudioCodec parent_instance;
+};
+
+struct _OGMRipAacClass
+{
+  OGMRipAudioCodecClass parent_class;
+};
+
 static gint ogmrip_aac_run (OGMJobSpawn *spawn);
 
 static gchar **
@@ -156,24 +175,6 @@ ogmrip_aac_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_aac_new:
- * @audio: An #OGMDvdAudioStream
- * @output: The output file
- *
- * Creates a new #OGMRipAac.
- *
- * Returns: The new #OGMRipAac
- */
-OGMJobSpawn *
-ogmrip_aac_new (OGMDvdAudioStream *audio, const gchar *output)
-{
-  g_return_val_if_fail (audio != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_AAC, "stream", audio, "output", output, NULL);
-}
-
 static OGMRipAudioPlugin aac_plugin =
 {
   NULL,
@@ -184,20 +185,31 @@ static OGMRipAudioPlugin aac_plugin =
 };
 
 OGMRipAudioPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  gboolean have_mplayer, have_faac;
   gchar *fullname;
 
-  if (!ogmrip_check_mplayer ())
-    return NULL;
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  have_mplayer = ogmrip_check_mplayer ();
 
   fullname = g_find_program_in_path (PROGRAM);
-  if (!fullname)
-    return NULL;
+  have_faac = fullname != NULL;
   g_free (fullname);
 
   aac_plugin.type = OGMRIP_TYPE_AAC;
 
-  return &aac_plugin;
+  if (have_mplayer && have_faac)
+    return &aac_plugin;
+
+  if (!have_mplayer && !have_faac)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer and FAAC are missing"));
+  else if (!have_mplayer)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer is missing"));
+  else if (!have_faac)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("FAAC is missing"));
+
+  return NULL;
 }
 
