@@ -58,9 +58,6 @@ gchar **
 ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gchar *output)
 {
   OGMDvdTitle *title;
-/*
-  OGMDvdAudioStream *astream;
-*/
   GPtrArray *argv;
   gint vid;
 
@@ -72,11 +69,8 @@ ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gc
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
   g_return_val_if_fail (title != NULL, NULL);
-/*
-  astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
-  g_return_val_if_fail (astream != NULL, NULL);
-*/
-  argv = ogmrip_mencoder_audio_command (audio, /*title, astream,*/ output);
+
+  argv = ogmrip_mencoder_audio_command (audio, output);
 
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   if (MPLAYER_CHECK_VERSION (1,0,0,8))
