@@ -39,6 +39,8 @@ struct _OGMRipAudioCodecPriv
   gboolean fast;
   gboolean normalize;
 
+  gchar *label;
+
   OGMDvdAudioChannels channels;
   OGMDvdAudioStream *stream;
 };
@@ -55,6 +57,7 @@ enum
 };
 
 static void ogmrip_audio_codec_dispose      (GObject      *gobject);
+static void ogmrip_audio_codec_finalize     (GObject      *gobject);
 static void ogmrip_audio_codec_set_property (GObject      *gobject,
                                              guint        property_id,
                                              const GValue *value,
@@ -74,6 +77,7 @@ ogmrip_audio_codec_class_init (OGMRipAudioCodecClass *klass)
   gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->dispose = ogmrip_audio_codec_dispose;
+  gobject_class->finalize = ogmrip_audio_codec_finalize;
   gobject_class->set_property = ogmrip_audio_codec_set_property;
   gobject_class->get_property = ogmrip_audio_codec_get_property;
 
@@ -121,12 +125,29 @@ ogmrip_audio_codec_dispose (GObject *gobject)
 
   audio = OGMRIP_AUDIO_CODEC (gobject);
   if (audio->priv->stream)
+  {
     ogmdvd_stream_unref (OGMDVD_STREAM (audio->priv->stream));
-  audio->priv->stream = NULL;
+    audio->priv->stream = NULL;
+  }
 
   G_OBJECT_CLASS (ogmrip_audio_codec_parent_class)->dispose (gobject);
 }
 
+static void
+ogmrip_audio_codec_finalize (GObject *gobject)
+{
+  OGMRipAudioCodec *audio;
+
+  audio = OGMRIP_AUDIO_CODEC (gobject);
+  if (audio->priv->label)
+  {
+    g_free (audio->priv->label);
+    audio->priv->label = NULL;
+  }
+
+  G_OBJECT_CLASS (ogmrip_audio_codec_parent_class)->finalize (gobject);
+}
+
 static void
 ogmrip_audio_codec_set_property (GObject *gobject, guint property_id, const GValue *value, GParamSpec *pspec)
 {
@@ -414,3 +435,41 @@ ogmrip_audio_codec_get_sample_rate (OGMRipAudioCodec *audio)
   return audio->priv->srate;
 }
 
+/**
+ * ogmrip_audio_codec_set_label:
+ * @audio: an #OGMRipAudioCodec
+ * @label: the track name
+ *
+ * Sets the name of the track.
+ */
+void
+ogmrip_audio_codec_set_label (OGMRipAudioCodec *audio, const gchar *label)
+{
+  g_return_if_fail (OGMRIP_IS_AUDIO_CODEC (audio));
+
+  if (audio->priv->label)
+  {
+    g_free (audio->priv->label);
+    audio->priv->label = NULL;
+  }
+
+  if (label)
+    audio->priv->label = g_strdup (label);
+}
+
+/**
+ * ogmrip_audio_codec_get_label:
+ * @audio: an #OGMRipAudioCodec
+ *
+ * Gets the name of the track.
+ *
+ * Returns: the track name
+ */
+G_CONST_RETURN gchar *
+ogmrip_audio_codec_get_label (OGMRipAudioCodec *audio)
+{
+  g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
+
+  return audio->priv->label;
+}
+
