@@ -69,6 +69,10 @@ gint                ogmrip_audio_codec_get_channels          (OGMRipAudioCodec
 void                ogmrip_audio_codec_set_sample_rate       (OGMRipAudioCodec    *audio,
                                                               guint               srate);
 gint                ogmrip_audio_codec_get_sample_rate       (OGMRipAudioCodec    *audio);
+void                ogmrip_audio_codec_set_label             (OGMRipAudioCodec    *audio,
+                                                              const gchar         *label);
+G_CONST_RETURN
+gchar *             ogmrip_audio_codec_get_label             (OGMRipAudioCodec    *audio);
 gint                ogmrip_audio_codec_get_samples_per_frame (OGMRipAudioCodec    *audio);
 
 G_END_DECLS
