@@ -20,8 +20,7 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-avi.h"
-#include "ogmrip-mplayer.h"
+#include "ogmrip-container.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-fs.h"
 #include "ogmrip-version.h"
@@ -36,32 +35,128 @@
 
 #define AVI_OVERHEAD 24
 
-static gint ogmrip_avi_run          (OGMJobSpawn     *spawn);
+#define OGMRIP_TYPE_AVI          (ogmrip_avi_get_type ())
+#define OGMRIP_AVI(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_AVI, OGMRipAvi))
+#define OGMRIP_AVI_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_AVI, OGMRipAviClass))
+#define OGMRIP_IS_AVI(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_AVI))
+#define OGMRIP_IS_AVI_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_AVI))
+
+typedef struct _OGMRipAvi      OGMRipAvi;
+typedef struct _OGMRipAviClass OGMRipAviClass;
+
+struct _OGMRipAvi
+{
+  OGMRipContainer parent_instance;
+};
+
+struct _OGMRipAviClass
+{
+  OGMRipContainerClass parent_class;
+};
+
+GType ogmrip_avi_get_type (void);
+static gint ogmrip_avi_run (OGMJobSpawn *spawn);
 static gint ogmrip_avi_get_overhead (OGMRipContainer *container);
 
+static void
+ogmrip_avi_append_audio_file (OGMRipContainer *avi, const gchar *filename, GPtrArray *argv)
+{
+  struct stat buf;
+
+  if (g_stat (filename, &buf) == 0 && buf.st_size > 0)
+    g_ptr_array_add (argv, g_strdup (filename));
+}
+
+static void
+ogmrip_avi_foreach_audio (OGMRipContainer *avi, 
+    OGMRipCodec *codec, guint demuxer, gint language, GPtrArray *argv)
+{
+  const gchar *input;
+
+  input = ogmrip_codec_get_output (codec);
+  ogmrip_avi_append_audio_file (avi, input, argv);
+}
+
+static void
+ogmrip_avi_foreach_file (OGMRipContainer *avi, OGMRipFile *file, GPtrArray *argv)
+{
+  if (ogmrip_file_get_type (file) == OGMRIP_FILE_TYPE_AUDIO)
+  {
+    gchar *filename;
+
+    filename = ogmrip_file_get_filename (file);
+    if (filename)
+    {
+      ogmrip_avi_append_audio_file (avi, filename, argv);
+      g_free (filename);
+    }
+  }
+}
+
 static gchar **
-ogmrip_avi_command (OGMRipContainer *avi)
+ogmrip_avi_command (OGMRipContainer *avi, GError **error)
 {
   GPtrArray *argv;
   OGMRipVideoCodec *video;
-  const gchar *output, *filename;
+  const gchar *output, *filename, *fourcc;
+  guint tsize, tnumber;
 
   g_return_val_if_fail (OGMRIP_IS_AVI (avi), NULL);
 
-  argv = ogmrip_mencoder_container_command (avi);
+  argv = g_ptr_array_new ();
+  g_ptr_array_add (argv, g_strdup ("avibox"));
+
   output = ogmrip_container_get_output (avi);
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup (output));
 
-  video = ogmrip_container_get_video (avi);
-  filename = ogmrip_codec_get_output (OGMRIP_CODEC (video));
-  g_ptr_array_add (argv, g_strdup (filename));
+  if ((video = ogmrip_container_get_video (avi)))
+  {
+    filename = ogmrip_codec_get_output (OGMRIP_CODEC (video));
+
+    g_ptr_array_add (argv, g_strdup ("-n"));
+    g_ptr_array_add (argv, g_strdup ("-i"));
+    g_ptr_array_add (argv, g_strdup (filename));
+  }
+
+  ogmrip_container_foreach_audio (avi, 
+      (OGMRipContainerCodecFunc) ogmrip_avi_foreach_audio, argv);
+  ogmrip_container_foreach_file (avi, 
+      (OGMRipContainerFileFunc) ogmrip_avi_foreach_file, argv);
+
+  ogmrip_container_get_split (avi, &tnumber, &tsize);
+  if (tnumber > 1)
+  {
+    g_ptr_array_add (argv, g_strdup ("-s"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", tsize));
+  }
+
+  fourcc = ogmrip_container_get_fourcc (avi);
+  if (fourcc)
+  {
+    g_ptr_array_add (argv, g_strdup ("-f"));
+    g_ptr_array_add (argv, g_strdup (fourcc));
+  }
 
   g_ptr_array_add (argv, NULL);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
+static gdouble
+ogmrip_avi_watch (OGMJobExec *exec, const gchar *buffer, OGMRipContainer *matroska)
+{
+  gulong frames, total;
+  guint percent;
+  gchar *str;
+
+  str = strrchr (buffer, ':');
+  if (str && sscanf (str, ": %06lu-%06lu frames written (%u%%)", &frames, &total, &percent) == 3)
+    return percent / 100.0;
+
+  return -1.0;
+}
+
 static gchar **
 ogmrip_copy_command (OGMRipContainer *container, const gchar *input, const gchar *ext)
 {
@@ -158,6 +253,7 @@ ogmrip_avi_foreach_subp (OGMRipContainer *avi,
 static gint
 ogmrip_avi_run (OGMJobSpawn *spawn)
 {
+  GError *error = NULL;
   OGMJobSpawn *queue, *child;
   gchar **argv;
   gint result;
@@ -168,20 +264,23 @@ ogmrip_avi_run (OGMJobSpawn *spawn)
   ogmjob_container_add (OGMJOB_CONTAINER (spawn), queue);
   g_object_unref (queue);
 
-  argv = ogmrip_avi_command (OGMRIP_CONTAINER (spawn));
-  if (argv)
+  argv = ogmrip_avi_command (OGMRIP_CONTAINER (spawn), &error);
+  if (!argv)
   {
-    child = ogmjob_exec_newv (argv);
-    ogmjob_exec_add_watch_full (OGMJOB_EXEC (child), (OGMJobWatch) ogmrip_mencoder_container_watch, spawn, TRUE, FALSE, FALSE);
-    ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
-    g_object_unref (child);
-
-    ogmrip_container_foreach_subp (OGMRIP_CONTAINER (spawn), 
-        (OGMRipContainerCodecFunc) ogmrip_avi_foreach_subp, queue);
-
-    result = OGMJOB_SPAWN_CLASS (ogmrip_avi_parent_class)->run (spawn);
+    ogmjob_spawn_propagate_error (spawn, error);
+    return OGMJOB_RESULT_ERROR;
   }
 
+  child = ogmjob_exec_newv (argv);
+  ogmjob_exec_add_watch_full (OGMJOB_EXEC (child), (OGMJobWatch) ogmrip_avi_watch, spawn, TRUE, FALSE, FALSE);
+  ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
+  g_object_unref (child);
+
+  ogmrip_container_foreach_subp (OGMRIP_CONTAINER (spawn), 
+      (OGMRipContainerCodecFunc) ogmrip_avi_foreach_subp, queue);
+
+  result = OGMJOB_SPAWN_CLASS (ogmrip_avi_parent_class)->run (spawn);
+
   ogmjob_container_remove (OGMJOB_CONTAINER (spawn), queue);
 
   return result;
@@ -193,22 +292,6 @@ ogmrip_avi_get_overhead (OGMRipContainer *container)
   return AVI_OVERHEAD;
 }
 
-/**
- * ogmrip_avi_new:
- * @output: The output file
- *
- * Creates a new #OGMRipAvi.
- *
- * Returns: The new #OGMRipAvi
- */
-OGMJobSpawn *
-ogmrip_avi_new (const gchar *output)
-{
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_AVI, "output", output, NULL);
-}
-
 static OGMRipContainerPlugin avi_plugin =
 {
   NULL,
@@ -216,7 +299,8 @@ static OGMRipContainerPlugin avi_plugin =
   "avi",
   N_("Audio-Video Interlace (AVI)"),
   TRUE,
-  1,
+  TRUE,
+  8,
   1,
   NULL
 };
@@ -227,22 +311,28 @@ static gint formats[] =
   OGMRIP_FORMAT_MPEG2,
   OGMRIP_FORMAT_MPEG4,
   OGMRIP_FORMAT_H264,
-  OGMRIP_FORMAT_THEORA,
-  OGMRIP_FORMAT_AAC,
+  OGMRIP_FORMAT_DIRAC,
   OGMRIP_FORMAT_AC3,
-  OGMRIP_FORMAT_DTS,
   OGMRIP_FORMAT_COPY,
   OGMRIP_FORMAT_MP3,
-  OGMRIP_FORMAT_PCM,
   OGMRIP_FORMAT_SRT,
   OGMRIP_FORMAT_VOBSUB,
   -1
 };
 
 OGMRipContainerPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
-  if (!ogmrip_check_mencoder ())
+  gboolean have_avibox = FALSE;
+  gchar *fullname;
+
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  fullname = g_find_program_in_path ("avibox");
+  have_avibox = fullname != NULL;
+  g_free (fullname);
+
+  if (!have_avibox)
     return NULL;
 
   avi_plugin.type = OGMRIP_TYPE_AVI;
