@@ -136,7 +136,7 @@ ogmrip_chapters_run (OGMJobSpawn *spawn)
   g_io_channel_shutdown (channel, TRUE, NULL);
   g_io_channel_unref (channel);
 
-  return OGMJOB_RESULT_COMPLETED;
+  return OGMJOB_RESULT_SUCCESS;
 }
 
 /**
