@@ -50,8 +50,11 @@ struct _OGMRipCodecPriv
 
   gdouble length;
 
-  guint start;
-  gint end;
+  guint start_chap;
+  gint end_chap;
+
+  gdouble start_second;
+  gdouble play_length;
 };
 
 enum 
@@ -62,10 +65,6 @@ enum
   PROP_LENGTH,
   PROP_START_CHAPTER,
   PROP_END_CHAPTER,
-/*
-  PROP_FRAMERATE_NUMERATOR,
-  PROP_FRAMERATE_DENOMINATOR,
-*/
   PROP_FRAMESTEP,
   PROP_PROGRESSIVE,
   PROP_TELECINE
@@ -81,6 +80,7 @@ static void ogmrip_codec_get_property (GObject      *gobject,
                                        guint        property_id,
                                        GValue       *value,
                                        GParamSpec   *pspec);
+static gint ogmrip_codec_run          (OGMJobSpawn  *spawn);
 
 G_DEFINE_ABSTRACT_TYPE (OGMRipCodec, ogmrip_codec, OGMJOB_TYPE_BIN)
 
@@ -88,14 +88,17 @@ static void
 ogmrip_codec_class_init (OGMRipCodecClass *klass)
 {
   GObjectClass *gobject_class;
+  OGMJobSpawnClass *spawn_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-
   gobject_class->dispose = ogmrip_codec_dispose;
   gobject_class->finalize = ogmrip_codec_finalize;
   gobject_class->set_property = ogmrip_codec_set_property;
   gobject_class->get_property = ogmrip_codec_get_property;
 
+  spawn_class = OGMJOB_SPAWN_CLASS (klass);
+  spawn_class->run = ogmrip_codec_run;
+
   g_object_class_install_property (gobject_class, PROP_INPUT, 
         g_param_spec_pointer ("input", "Input property", "Set input title", 
            G_PARAM_READWRITE));
@@ -115,15 +118,7 @@ ogmrip_codec_class_init (OGMRipCodecClass *klass)
   g_object_class_install_property (gobject_class, PROP_END_CHAPTER, 
         g_param_spec_int ("end-chapter", "End chapter property", "Set end chapter", 
            -1, G_MAXINT, -1, G_PARAM_READWRITE));
-/*
-  g_object_class_install_property (gobject_class, PROP_FRAMERATE_NUMERATOR, 
-        g_param_spec_uint ("framerate-numerator", "Framerate numerator property", "Set framerate numerator", 
-           0, G_MAXUINT, 25, G_PARAM_READWRITE));
 
-  g_object_class_install_property (gobject_class, PROP_FRAMERATE_DENOMINATOR, 
-        g_param_spec_uint ("framerate-denominator", "Framerate denominator property", "Set framerate denominator", 
-           0, G_MAXUINT, 1, G_PARAM_READWRITE));
-*/
   g_object_class_install_property (gobject_class, PROP_FRAMESTEP, 
         g_param_spec_uint ("framestep", "Framestep property", "Set framestep", 
            0, G_MAXUINT, 1, G_PARAM_READWRITE));
@@ -144,7 +139,10 @@ ogmrip_codec_init (OGMRipCodec *codec)
 {
   codec->priv = OGMRIP_CODEC_GET_PRIVATE (codec);
   codec->priv->framestep = 1;
-  codec->priv->end = -1;
+  codec->priv->end_chap = -1;
+
+  codec->priv->play_length = -1.0;
+  codec->priv->start_second = -1.0;
 }
 
 static void
@@ -200,19 +198,11 @@ ogmrip_codec_set_property (GObject *gobject, guint property_id, const GValue *va
       ogmrip_codec_set_output (codec, g_value_get_string (value));
       break;
     case PROP_START_CHAPTER: 
-      ogmrip_codec_set_chapters (codec, g_value_get_int (value), codec->priv->end);
+      ogmrip_codec_set_chapters (codec, g_value_get_int (value), codec->priv->end_chap);
       break;
     case PROP_END_CHAPTER: 
-      ogmrip_codec_set_chapters (codec, codec->priv->start, g_value_get_int (value));
+      ogmrip_codec_set_chapters (codec, codec->priv->start_chap, g_value_get_int (value));
       break;
-/*
-    case PROP_FRAMERATE_NUMERATOR: 
-      ogmrip_codec_set_framerate (codec, g_value_get_uint (value), codec->priv->framerate_numerator);
-      break;
-    case PROP_FRAMERATE_DENOMINATOR: 
-      ogmrip_codec_set_framerate (codec, codec->priv->framerate_denominator, g_value_get_uint (value));
-      break;
-*/
     case PROP_FRAMESTEP: 
       ogmrip_codec_set_framestep (codec, g_value_get_uint (value));
       break;
@@ -247,19 +237,11 @@ ogmrip_codec_get_property (GObject *gobject, guint property_id, GValue *value, G
       g_value_set_double (value, ogmrip_codec_get_length (codec, NULL));
       break;
     case PROP_START_CHAPTER: 
-      g_value_set_int (value, codec->priv->start);
+      g_value_set_int (value, codec->priv->start_chap);
       break;
     case PROP_END_CHAPTER: 
-      g_value_set_int (value, codec->priv->end);
+      g_value_set_int (value, codec->priv->end_chap);
       break;
-/*
-    case PROP_FRAMERATE_NUMERATOR: 
-      g_value_set_uint (value, codec->priv->framerate_numerator);
-      break;
-    case PROP_FRAMERATE_DENOMINATOR: 
-      g_value_set_uint (value, codec->priv->framerate_denominator);
-      break;
-*/
     case PROP_FRAMESTEP: 
       g_value_set_uint (value, codec->priv->framestep);
       break;
@@ -275,6 +257,19 @@ ogmrip_codec_get_property (GObject *gobject, guint property_id, GValue *value, G
   }
 }
 
+static gint
+ogmrip_codec_run (OGMJobSpawn *spawn)
+{
+  OGMDvdTitle *title;
+
+  title = OGMRIP_CODEC (spawn)->priv->title;
+
+  g_return_val_if_fail (title != NULL, OGMJOB_RESULT_ERROR);
+  g_return_val_if_fail (ogmdvd_title_is_open (title), OGMJOB_RESULT_ERROR);
+
+  return OGMJOB_SPAWN_CLASS (ogmrip_codec_parent_class)->run (spawn);
+}
+
 /**
  * ogmrip_codec_set_output:
  * @codec: an #OGMRipCodec
@@ -332,8 +327,8 @@ ogmrip_codec_set_input (OGMRipCodec *codec, OGMDvdTitle *title)
   codec->priv->title = title;
   codec->priv->dirty = TRUE;
 
-  codec->priv->start = 0;
-  codec->priv->end = -1;
+  codec->priv->start_chap = 0;
+  codec->priv->end_chap = -1;
 }
 
 /**
@@ -352,6 +347,26 @@ ogmrip_codec_get_input (OGMRipCodec *codec)
   return codec->priv->title;
 }
 
+/**
+ * ogmrip_codec_set_options:
+ * @codec: An #OGMRipCodec
+ * @section: A profile
+ *
+ * Sets codec specific options from the specified profile.
+ */
+void
+ogmrip_codec_set_options (OGMRipCodec *codec, const gchar *section)
+{
+  OGMRipCodecClass *klass;
+
+  g_return_if_fail (OGMRIP_IS_CODEC (codec));
+  g_return_if_fail (section != NULL);
+
+  klass = OGMRIP_CODEC_GET_CLASS (codec);
+  if (klass->set_options)
+    (* klass->set_options) (codec, section);
+}
+
 /**
  * ogmrip_codec_set_progressive:
  * @codec: an #OGMRipCodec
@@ -464,7 +479,7 @@ ogmrip_codec_set_chapters (OGMRipCodec *codec, guint start, gint end)
 {
   g_return_if_fail (OGMRIP_IS_CODEC (codec));
 
-  if (codec->priv->start != start || codec->priv->end != end)
+  if (codec->priv->start_chap != start || codec->priv->end_chap != end)
   {
     gint nchap;
 
@@ -473,8 +488,11 @@ ogmrip_codec_set_chapters (OGMRipCodec *codec, guint start, gint end)
     if (end < 0)
       end = nchap - 1;
 
-    codec->priv->start = MIN ((gint) start, nchap - 1);
-    codec->priv->end = CLAMP (end, (gint) start, nchap - 1);
+    codec->priv->start_chap = MIN ((gint) start, nchap - 1);
+    codec->priv->end_chap = CLAMP (end, (gint) start, nchap - 1);
+
+    codec->priv->start_second = -1.0;
+    codec->priv->play_length = -1.0;
 
     codec->priv->dirty = TRUE;
   }
@@ -495,38 +513,12 @@ ogmrip_codec_get_chapters (OGMRipCodec *codec, guint *start, guint *end)
   g_return_if_fail (start != NULL);
   g_return_if_fail (end != NULL);
 
-  *start = codec->priv->start;
+  *start = codec->priv->start_chap;
 
-  if (codec->priv->end < 0)
+  if (codec->priv->end_chap < 0)
     *end = ogmdvd_title_get_n_chapters (codec->priv->title) - 1;
   else
-    *end = codec->priv->end;
-}
-
-/**
- * ogmrip_codec_get_frames:
- * @codec: an #OGMRipCodec
- *
- * Returns the length of the encoding in frames.
- *
- * Returns: the length in frames, or -1
- */
-glong
-ogmrip_codec_get_frames (OGMRipCodec *codec)
-{
-  gdouble framerate;
-
-  g_return_val_if_fail (OGMRIP_IS_CODEC (codec), -1);
-
-  if (!codec->priv->title)
-    return -1;
-
-  if (codec->priv->dirty)
-    ogmrip_codec_get_length (codec, NULL);
-
-  framerate = codec->priv->framerate_numerator / (gdouble) codec->priv->framerate_denominator;
-
-  return codec->priv->length * framerate;
+    *end = codec->priv->end_chap;
 }
 
 static void
@@ -541,6 +533,18 @@ ogmrip_codec_foreach_edl_element (OGMRipEdlAction action, gdouble start, gdouble
   }
 }
 
+static void
+ogmrip_codec_sec_to_time (gdouble length, gdouble fps, OGMDvdTime *dtime)
+{
+  glong sec = (glong) length;
+
+  dtime->hour = sec / (60 * 60);
+  dtime->min = sec / 60 % 60;
+  dtime->sec = sec % 60;
+
+  dtime->frames = (length - sec) * fps;
+}
+
 /**
  * ogmrip_codec_get_length:
  * @codec: an #OGMRipCodec
@@ -562,11 +566,17 @@ ogmrip_codec_get_length (OGMRipCodec *codec, OGMDvdTime *length)
 
   if (codec->priv->dirty)
   {
-    if (codec->priv->start == 0 && codec->priv->end == -1)
+    if (codec->priv->play_length > 0.0)
+    {
+      codec->priv->length = codec->priv->play_length;
+      ogmrip_codec_sec_to_time (codec->priv->play_length,
+          codec->priv->framerate_numerator / (gdouble) codec->priv->framerate_denominator, &codec->priv->time_);
+    }
+    else if (codec->priv->start_chap == 0 && codec->priv->end_chap == -1)
       codec->priv->length = ogmdvd_title_get_length (codec->priv->title, &codec->priv->time_);
     else
       codec->priv->length = ogmdvd_title_get_chapters_length (codec->priv->title, 
-            codec->priv->start, codec->priv->end, &codec->priv->time_);
+            codec->priv->start_chap, codec->priv->end_chap, &codec->priv->time_);
 
     /*
      * TODO EDL can be dirty !!!!
@@ -639,15 +649,6 @@ ogmrip_codec_get_framerate (OGMRipCodec *codec, guint *numerator, guint *denomin
 
   *numerator = codec->priv->framerate_numerator;
   *denominator = codec->priv->framerate_denominator;
-/*
-  if (!numerator || !denominator)
-  {
-    OGMDvdTitle *title;
-
-    title = ogmrip_codec_get_input (OGMRIP_CODEC (codec));
-    ogmdvd_title_get_framerate (title, numerator, denominator);
-  }
-*/
 }
 
 /**
@@ -714,3 +715,75 @@ ogmrip_codec_get_unlink_on_unref (OGMRipCodec *codec)
   return codec->priv->do_unlink;
 }
 
+/**
+ * ogmrip_codec_set_play_length:
+ * @codec: an #OGMRipCodec
+ * @length: the length to encode in seconds
+ *
+ * Encodes only @length seconds.
+ */
+void
+ogmrip_codec_set_play_length (OGMRipCodec *codec, gdouble length)
+{
+  g_return_if_fail (OGMRIP_IS_CODEC (codec));
+  g_return_if_fail (length > 0.0);
+
+  codec->priv->start_chap = 0;
+  codec->priv->end_chap = -1;
+
+  codec->priv->play_length = length;
+
+  codec->priv->dirty = TRUE;
+}
+
+/**
+ * ogmrip_codec_get_play_length:
+ * @codec: an #OGMRipCodec
+ *
+ * Gets the length to encode in seconds.
+ *
+ * Returns: the length, or -1.0
+ */
+gdouble
+ogmrip_codec_get_play_length (OGMRipCodec *codec)
+{
+  g_return_val_if_fail (OGMRIP_IS_CODEC (codec), -1.0);
+
+  return codec->priv->play_length;
+}
+
+/**
+ * ogmrip_codec_set_start:
+ * @codec: an #OGMRipCodec
+ * @start: the position to seek in seconds
+ *
+ * Seeks to the given time position.
+ */
+void
+ogmrip_codec_set_start (OGMRipCodec *codec, gdouble start)
+{
+  g_return_if_fail (OGMRIP_IS_CODEC (codec));
+  g_return_if_fail (start >= 0.0);
+
+  codec->priv->start_chap = 0;
+  codec->priv->end_chap = -1;
+
+  codec->priv->start_second = start;
+}
+
+/**
+ * ogmrip_codec_get_start:
+ * @codec: an #OGMRipCodec
+ *
+ * Gets the position to seek in seconds.
+ *
+ * Returns: the position, or -1.0
+ */
+gdouble
+ogmrip_codec_get_start (OGMRipCodec *codec)
+{
+  g_return_val_if_fail (OGMRIP_IS_CODEC (codec), -1);
+
+  return codec->priv->start_second;
+}
+
