@@ -25,11 +25,12 @@
 
 G_BEGIN_DECLS
 
-#define OGMRIP_TYPE_CODEC          (ogmrip_codec_get_type ())
-#define OGMRIP_CODEC(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_CODEC, OGMRipCodec))
-#define OGMRIP_CODEC_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_CODEC, OGMRipCodecClass))
-#define OGMRIP_IS_CODEC(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_CODEC))
-#define OGMRIP_IS_CODEC_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_CODEC))
+#define OGMRIP_TYPE_CODEC           (ogmrip_codec_get_type ())
+#define OGMRIP_CODEC(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_CODEC, OGMRipCodec))
+#define OGMRIP_CODEC_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_CODEC, OGMRipCodecClass))
+#define OGMRIP_IS_CODEC(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_CODEC))
+#define OGMRIP_IS_CODEC_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_CODEC))
+#define OGMRIP_CODEC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OGMRIP_TYPE_CODEC, OGMRipCodecClass))
 
 typedef struct _OGMRipCodec      OGMRipCodec;
 typedef struct _OGMRipCodecPriv  OGMRipCodecPriv;
@@ -45,6 +46,10 @@ struct _OGMRipCodec
 struct _OGMRipCodecClass
 {
   OGMJobBinClass parent_class;
+
+  /* vtable */
+  void (* set_options) (OGMRipCodec *codec,
+                        const gchar *section);
 };
 
 GType         ogmrip_codec_get_type            (void);
@@ -55,9 +60,12 @@ void          ogmrip_codec_set_output          (OGMRipCodec *codec,
 OGMDvdTitle * ogmrip_codec_get_input           (OGMRipCodec *codec);
 void          ogmrip_codec_set_input           (OGMRipCodec *codec,
                                                 OGMDvdTitle *title);
+
+void          ogmrip_codec_set_options         (OGMRipCodec *codec,
+                                                const gchar *section);
+
 gdouble       ogmrip_codec_get_length          (OGMRipCodec *codec,
                                                 OGMDvdTime  *length);
-glong         ogmrip_codec_get_frames          (OGMRipCodec *codec);
 
 void          ogmrip_codec_set_telecine        (OGMRipCodec *codec,
                                                 gboolean    telecine);
@@ -89,6 +97,14 @@ void          ogmrip_codec_set_unlink_on_unref (OGMRipCodec *codec,
                                                 gboolean    do_unlink);
 gboolean      ogmrip_codec_get_unlink_on_unref (OGMRipCodec *codec);
 
+void          ogmrip_codec_set_play_length     (OGMRipCodec *codec,
+                                                gdouble     length);
+gdouble       ogmrip_codec_get_play_length     (OGMRipCodec *codec);
+
+gdouble       ogmrip_codec_get_start           (OGMRipCodec *codec);
+void          ogmrip_codec_set_start           (OGMRipCodec *codec,
+                                                gdouble     start);
+
 G_END_DECLS
 
 #endif /* __OGMRIP_CODEC_H__ */
