@@ -285,15 +285,38 @@ static void
 ogmrip_container_foreach_codec (OGMRipContainer *container, GSList *list, OGMRipContainerCodecFunc func, gpointer data)
 {
   OGMRipContainerChild *child;
+  GSList *next;
 
   while (list)
   {
-    child = (OGMRipContainerChild *) list->data;
-    func (container, child->codec, child->demuxer, child->language, data);
-    list = list->next;
+    next = list->next;
+
+    child = list->data;
+    (* func) (container, child->codec, child->demuxer, child->language, data);
+    list = next;
   }
 }
 
+/**
+ * ogmrip_container_set_options:
+ * @container: An #OGMRipContainer
+ * @section: A profile
+ *
+ * Sets container specific options from the specified profile.
+ */
+void
+ogmrip_container_set_options (OGMRipContainer *container, const gchar *section)
+{
+  OGMRipContainerClass *klass;
+
+  g_return_if_fail (OGMRIP_IS_CONTAINER (container));
+  g_return_if_fail (section != NULL);
+
+  klass = OGMRIP_CONTAINER_GET_CLASS (container);
+  if (klass->set_options)
+    (* klass->set_options) (container, section);
+}
+
 /**
  * ogmrip_container_get_output:
  * @container: An #OGMRipContainer
@@ -520,6 +543,38 @@ ogmrip_container_add_audio (OGMRipContainer *container, OGMRipAudioCodec *audio,
   container->priv->audio = g_slist_append (container->priv->audio, child);
 }
 
+/**
+ * ogmrip_container_remove_audio:
+ * @container: An #OGMRipContainer
+ * @audio: An #OGMRipAudioCodec
+ *
+ * Removes the audio codec from the rip.
+ */
+void
+ogmrip_container_remove_audio (OGMRipContainer *container, OGMRipAudioCodec *audio)
+{
+  OGMRipContainerChild *child;
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_CONTAINER (container));
+  g_return_if_fail (OGMRIP_IS_AUDIO_CODEC (audio));
+
+  for (link = container->priv->audio; link; link = link->next)
+  {
+    child = link->data;
+
+    if (child->codec == OGMRIP_CODEC (audio))
+      break;
+  }
+
+  if (link)
+  {
+    container->priv->audio = g_slist_remove_link (container->priv->audio, link);
+    ogmrip_stream_free (link->data);
+    g_slist_free (link);
+  }
+}
+
 /**
  * ogmrip_container_get_audio:
  * @container: An #OGMRipContainer
@@ -627,6 +682,38 @@ ogmrip_container_add_subp (OGMRipContainer *container, OGMRipSubpCodec *subp, OG
   container->priv->subp = g_slist_append (container->priv->subp, child);
 }
 
+/**
+ * ogmrip_container_remove_subp:
+ * @container: An #OGMRipContainer
+ * @subp: An #OGMRipSubpCodec
+ *
+ * Removes the subp codec from the rip.
+ */
+void
+ogmrip_container_remove_subp (OGMRipContainer *container, OGMRipSubpCodec *subp)
+{
+  OGMRipContainerChild *child;
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_CONTAINER (container));
+  g_return_if_fail (OGMRIP_IS_SUBP_CODEC (subp));
+
+  for (link = container->priv->subp; link; link = link->next)
+  {
+    child = link->data;
+
+    if (child->codec == OGMRIP_CODEC (subp))
+      break;
+  }
+
+  if (link)
+  {
+    container->priv->subp = g_slist_remove_link (container->priv->subp, link);
+    ogmrip_stream_free (link->data);
+    g_slist_free (link);
+  }
+}
+
 /**
  * ogmrip_container_get_subp:
  * @container: An #OGMRipContainer
@@ -731,6 +818,38 @@ ogmrip_container_add_chapters (OGMRipContainer *container, OGMRipChapters *chapt
   container->priv->chapters = g_slist_append (container->priv->chapters, child);
 }
 
+/**
+ * ogmrip_container_remove_chapters:
+ * @container: An #OGMRipContainer
+ * @chapters: An #OGMRipChaptersCodec
+ *
+ * Removes the chapters from the rip.
+ */
+void
+ogmrip_container_remove_chapters (OGMRipContainer *container, OGMRipChapters *chapters)
+{
+  OGMRipContainerChild *child;
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_CONTAINER (container));
+  g_return_if_fail (OGMRIP_IS_CHAPTERS (chapters));
+
+  for (link = container->priv->chapters; link; link = link->next)
+  {
+    child = link->data;
+
+    if (child->codec == OGMRIP_CODEC (chapters))
+      break;
+  }
+
+  if (link)
+  {
+    container->priv->chapters = g_slist_remove_link (container->priv->chapters, link);
+    ogmrip_stream_free (link->data);
+    g_slist_free (link);
+  }
+}
+
 /**
  * ogmrip_container_get_chapters:
  * @container: An #OGMRipContainer
@@ -828,6 +947,33 @@ ogmrip_container_add_file (OGMRipContainer *container, OGMRipFile *file)
   container->priv->files = g_slist_append (container->priv->files, file);
 }
 
+/**
+ * ogmrip_container_remove_file:
+ * @container: An #OGMRipContainer
+ * @file: An #OGMRipFile
+ *
+ * Removes the file from the rip.
+ */
+void
+ogmrip_container_remove_file (OGMRipContainer *container, OGMRipFile *file)
+{
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_CONTAINER (container));
+  g_return_if_fail (file != NULL);
+
+  for (link = container->priv->files; link; link = link->next)
+    if (OGMRIP_FILE (link->data) == file)
+      break;
+
+  if (link)
+  {
+    container->priv->files = g_slist_remove_link (container->priv->files, link);
+    ogmrip_file_unref (file);
+    g_slist_free (link);
+  }
+}
+
 /**
  * ogmrip_container_get_files:
  * @container: An #OGMRipContainer
@@ -893,13 +1039,18 @@ ogmrip_container_get_n_files (OGMRipContainer *container)
 void
 ogmrip_container_foreach_file (OGMRipContainer *container, OGMRipContainerFileFunc func, gpointer data)
 {
-  GSList *link;
+  GSList *link, *next;
 
   g_return_if_fail (OGMRIP_IS_CONTAINER (container));
   g_return_if_fail (func != NULL);
   
-  for (link = container->priv->files; link; link = link->next)
-    func (container, OGMRIP_FILE (link->data), data);
+  link = container->priv->files;
+  while (link)
+  {
+    next = link->next;
+    (* func) (container, OGMRIP_FILE (link->data), data);
+    link = next;
+  }
 }
 
 /**
