@@ -65,6 +65,8 @@ ogmrip_dvdcpy_command (OGMRipDvdCpy *dvdcpy, const gchar *input, const gchar *ou
 
   argv = g_ptr_array_new ();
   g_ptr_array_add (argv, g_strdup ("dvdcpy"));
+  g_ptr_array_add (argv, g_strdup ("-s"));
+  g_ptr_array_add (argv, g_strdup ("skip"));
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup (output));
   g_ptr_array_add (argv, g_strdup ("-m"));
