@@ -163,7 +163,10 @@ typedef enum
  * @OGMRIP_ENCODING_ERROR_SIZE: No enough disk space
  * @OGMRIP_ENCODING_ERROR_TEST: Cannot perform compressibility test
  * @OGMRIP_ENCODING_ERROR_IMPORT: Cannot import encoding file
+ * @OGMRIP_ENCODING_ERROR_AUDIO: Cannot contain multiple audio streams
+ * @OGMRIP_ENCODING_ERROR_SUBP: Cannot contain multiple subp streams
  * @OGMRIP_ENCODING_ERROR_UNKNOWN: Unknown error
+ * @OGMRIP_ENCODING_ERROR_FATAL: Fatal error
  *
  * Error codes returned by ogmdvd_disc_open()
  */
@@ -174,7 +177,10 @@ typedef enum
   OGMRIP_ENCODING_ERROR_SIZE,
   OGMRIP_ENCODING_ERROR_TEST,
   OGMRIP_ENCODING_ERROR_IMPORT,
-  OGMRIP_ENCODING_ERROR_UNKNOWN
+  OGMRIP_ENCODING_ERROR_AUDIO,
+  OGMRIP_ENCODING_ERROR_SUBP,
+  OGMRIP_ENCODING_ERROR_UNKNOWN,
+  OGMRIP_ENCODING_ERROR_FATAL
 } OGMRipEncodingError;
 
 /**
@@ -488,6 +494,13 @@ void                ogmrip_encoding_set_max_size           (OGMRipEncoding
                                                             guint                   height,
                                                             gboolean                expand);
 
+void                ogmrip_encoding_get_min_size           (OGMRipEncoding          *encoding,
+                                                            guint                   *width,
+                                                            guint                   *height);
+void                ogmrip_encoding_set_min_size           (OGMRipEncoding          *encoding,
+                                                            guint                   width,
+                                                            guint                   height);
+
 gint                ogmrip_encoding_get_passes             (OGMRipEncoding          *encoding);
 void                ogmrip_encoding_set_passes             (OGMRipEncoding          *encoding,
                                                             guint                   passes);
