@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,7 @@ G_BEGIN_DECLS
  * @OGMRIP_FORMAT_MPEG4: The Mpeg-4 video format
  * @OGMRIP_FORMAT_H264: The H264 video format
  * @OGMRIP_FORMAT_THEORA: The Ogg Theora video format
+ * @OGMRIP_FORMAT_DIRAC: The Dirac video format
  * @OGMRIP_FORMAT_PCM: The PCM audio format
  * @OGMRIP_FORMAT_MP3: The MP3 audio format
  * @OGMRIP_FORMAT_AC3: The AC3 audio format
@@ -62,6 +63,7 @@ typedef enum
   OGMRIP_FORMAT_MPEG4,
   OGMRIP_FORMAT_H264,
   OGMRIP_FORMAT_THEORA,
+  OGMRIP_FORMAT_DIRAC,
   OGMRIP_FORMAT_PCM,
   OGMRIP_FORMAT_MP3,
   OGMRIP_FORMAT_AC3,
@@ -149,6 +151,7 @@ typedef enum
  * @OGMRIP_QUALITY_EXTREME: Extreme quality
  * @OGMRIP_QUALITY_HIGH: High quality
  * @OGMRIP_QUALITY_NORMAL: Normal quality
+ * @OGMRIP_QUALITY_USER: User quality
  *
  * Available quality presets.
  */
@@ -156,7 +159,8 @@ typedef enum
 {
   OGMRIP_QUALITY_EXTREME,
   OGMRIP_QUALITY_HIGH,
-  OGMRIP_QUALITY_NORMAL
+  OGMRIP_QUALITY_NORMAL,
+  OGMRIP_QUALITY_USER
 } OGMRipQualityType;
 
 /**
@@ -175,17 +179,19 @@ typedef enum
 } OGMRipCharset;
 
 /**
- * OGMRipEolStyle:
- * @OGMRIP_EOL_CR: Carriage return only
- * @OGMRIP_EOL_CR_LF: Carriage return + line feed
+ * OGMRipNewline:
+ * @OGMRIP_NEWLINE_LF: Line feed only
+ * @OGMRIP_NEWLINE_CR_LF: Carriage return + line feed
+ * @OGMRIP_NEWLINE_CR: Carriage return only
  *
  * Available end-of-line styles.
  */
 typedef enum
 {
-  OGMRIP_EOL_CR,
-  OGMRIP_EOL_CR_LF
-} OGMRipEolStyle;
+  OGMRIP_NEWLINE_LF,
+  OGMRIP_NEWLINE_CR_LF,
+  OGMRIP_NEWLINE_CR
+} OGMRipNewline;
 
 /**
  * OGMRipAudioDemuxer:
@@ -215,6 +221,23 @@ typedef enum
   OGMRIP_SUBP_DEMUXER_VOBSUB
 } OGMRipSubpDemuxer;
 
+/**
+ * OGMRipVideoPreset:
+ * @OGMRIP_VIDEO_PRESET_EXTREME: Extreme preset
+ * @OGMRIP_VIDEO_PRESET_HIGH: High preset
+ * @OGMRIP_VIDEO_PRESET_NORMAL: Normal preset
+ * @OGMRIP_VIDEO_PRESET_USER: User defined preset
+ *
+ * Available video presets.
+ */
+typedef enum
+{
+  OGMRIP_VIDEO_PRESET_EXTREME,
+  OGMRIP_VIDEO_PRESET_HIGH,
+  OGMRIP_VIDEO_PRESET_NORMAL,
+  OGMRIP_VIDEO_PRESET_USER
+} OGMRipVideoPreset;
+
 G_END_DECLS
 
 #endif /* __OGMRIP_ENUMS_H__ */
