@@ -232,7 +232,7 @@ ogmrip_fs_mkftemp (const gchar *tmpl, GError **error)
   g_return_val_if_fail (tmpl && *tmpl, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-  fd = ogmrip_fs_open_tmp (tmpl, &name, &tmp_error);
+  fd = g_file_open_tmp (tmpl, &name, &tmp_error);
 
   if (fd < 0)
   {
@@ -492,6 +492,8 @@ ogmrip_fs_get_mount_point (const gchar *filename, GError **error)
   g_return_val_if_fail (filename && *filename, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
+  cwd = g_get_current_dir ();
+
   if (g_file_test (filename, G_FILE_TEST_IS_DIR))
     dirname = g_strdup (filename);
   else
@@ -514,8 +516,6 @@ ogmrip_fs_get_mount_point (const gchar *filename, GError **error)
     goto done;
   }
 
-  cwd = g_get_current_dir ();
-
   for (;;)
   {
     if (g_stat ("..", &cur_stat) < 0)
