@@ -20,11 +20,31 @@
 #include "config.h"
 #endif
 
+#include "ogmrip-lavc.h"
 #include "ogmrip-lavc-mpeg4.h"
 #include "ogmrip-plugin.h"
 
 #include <glib/gi18n-lib.h>
 
+#define OGMRIP_LAVC_MPEG4(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_LAVC_MPEG4, OGMRipLavcMpeg4))
+#define OGMRIP_LAVC_MPEG4_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_LAVC_MPEG4, OGMRipLavcMpeg4Class))
+#define OGMRIP_IS_LAVC_MPEG4(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_LAVC_MPEG4))
+#define OGMRIP_IS_LAVC_MPEG4_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_LAVC_MPEG4))
+#define OGMRIP_LAVC_MPEG4_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OGMRIP_TYPE_LAVC_MPEG4, OGMRipLavcMpeg4Class))
+
+typedef struct _OGMRipLavcMpeg4      OGMRipLavcMpeg4;
+typedef struct _OGMRipLavcMpeg4Class OGMRipLavcMpeg4Class;
+
+struct _OGMRipLavcMpeg4
+{
+  OGMRipLavc parent_instance;
+};
+
+struct _OGMRipLavcMpeg4Class
+{
+  OGMRipLavcClass parent_class;
+};
+
 G_DEFINE_TYPE (OGMRipLavcMpeg4, ogmrip_lavc_mpeg4, OGMRIP_TYPE_LAVC)
 
 static void
@@ -37,24 +57,6 @@ ogmrip_lavc_mpeg4_init (OGMRipLavcMpeg4 *lavc_mpeg4)
 {
 }
 
-/**
- * ogmrip_lavc_mpeg4_new:
- * @title: An #OGMDvdTitle
- * @output: The output file
- *
- * Creates a new #OGMRipLavcMpeg4.
- *
- * Returns: the new #OGMRipLavcMpeg4
- */
-OGMJobSpawn *
-ogmrip_lavc_mpeg4_new (OGMDvdTitle *title, const gchar *output)
-{
-  g_return_val_if_fail (title != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_LAVC_MPEG4, "input", title, "output", output, NULL);
-}
-
 static OGMRipVideoPlugin lavc_mpeg4_plugin =
 {
   NULL,
@@ -81,6 +83,8 @@ ogmrip_init_plugin (void)
   if (!match)
     return NULL;
 
+  ogmrip_init_lavc_plugin ();
+
   lavc_mpeg4_plugin.type = OGMRIP_TYPE_LAVC_MPEG4;
 
   return &lavc_mpeg4_plugin;
