@@ -16,14 +16,23 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+/**
+ * SECTION:ogmrip-lavc
+ * @title: OGMRipLavc
+ * @short_description: Base class for lavc video codecs
+ * @include: ogmrip-lavc.h
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "ogmrip-fs.h"
 #include "ogmrip-lavc.h"
+#include "ogmrip-settings.h"
 #include "ogmrip-version.h"
 #include "ogmrip-mplayer.h"
+#include "ogmrip-plugin.h"
 
 #include "ogmjob-exec.h"
 #include "ogmjob-queue.h"
@@ -89,16 +98,41 @@ static void ogmrip_lavc_set_property (GObject           *gobject,
 static gint ogmrip_lavc_run          (OGMJobSpawn       *spawn);
 static void ogmrip_lavc_set_quality  (OGMRipVideoCodec  *video,
                                       OGMRipQualityType quality);
+static void ogmrip_lavc_set_options  (OGMRipCodec       *codec,
+                                      const gchar       *section);
+
+static const gchar * const properties[] =
+{
+  OGMRIP_LAVC_PROP_CMP,
+  OGMRIP_LAVC_PROP_PRECMP,
+  OGMRIP_LAVC_PROP_SUBCMP,
+  OGMRIP_LAVC_PROP_DIA,
+  OGMRIP_LAVC_PROP_PREDIA,
+  OGMRIP_LAVC_PROP_KEYINT,
+  OGMRIP_LAVC_PROP_BUF_SIZE,
+  OGMRIP_LAVC_PROP_MIN_RATE,
+  OGMRIP_LAVC_PROP_MAX_RATE,
+  OGMRIP_LAVC_PROP_STRICT,
+  OGMRIP_LAVC_PROP_DC,
+  OGMRIP_LAVC_PROP_MBD,
+  OGMRIP_LAVC_PROP_QNS,
+  OGMRIP_LAVC_PROP_VB_STRATEGY,
+  OGMRIP_LAVC_PROP_LAST_PRED,
+  OGMRIP_LAVC_PROP_PREME,
+  OGMRIP_LAVC_PROP_VQCOMP,
+  OGMRIP_LAVC_PROP_MV0,
+  OGMRIP_LAVC_PROP_V4MV,
+  NULL
+};
+
 static gdouble
 ogmrip_lavc_get_quantizer (OGMRipVideoCodec *video)
 {
   gdouble quantizer;
 
   quantizer = ogmrip_video_codec_get_quantizer (video);
-  if (quantizer < 0.0)
-    return 2.0;
 
-  return quantizer;
+  return CLAMP (quantizer, 2, 31);
 }
 
 static G_CONST_RETURN gchar *
@@ -163,8 +197,10 @@ ogmrip_lavc_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
     g_string_append (options, ":mv0");
   if (ogmrip_video_codec_get_qpel (video))
     g_string_append (options, ":qpel");
-  if (ogmrip_video_codec_get_4mv (video))
+
+  if (ogmrip_plugin_get_video_codec_format (G_TYPE_FROM_INSTANCE (video)) == OGMRIP_FORMAT_MPEG4 && ogmrip_video_codec_get_4mv (video))
     g_string_append (options, ":v4mv");
+
   if (ogmrip_video_codec_get_trellis (video))
     g_string_append (options, ":trell:cbp");
   if (ogmrip_video_codec_get_grayscale (video))
@@ -245,6 +281,7 @@ ogmrip_lavc_class_init (OGMRipLavcClass *klass)
   GObjectClass *gobject_class;
   OGMJobSpawnClass *spawn_class;
   OGMRipVideoCodecClass *video_class;
+  OGMRipCodecClass *codec_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->get_property = ogmrip_lavc_get_property;
@@ -256,82 +293,85 @@ ogmrip_lavc_class_init (OGMRipLavcClass *klass)
   video_class = OGMRIP_VIDEO_CODEC_CLASS (klass);
   video_class->set_quality = ogmrip_lavc_set_quality;
 
+  codec_class = OGMRIP_CODEC_CLASS (klass);
+  codec_class->set_options = ogmrip_lavc_set_options;
+
   g_object_class_install_property (gobject_class, PROP_HEADER,
-        g_param_spec_uint ("header", "Header property", "Set header",
-           0, 3, 0, G_PARAM_READWRITE));
+      g_param_spec_uint (OGMRIP_LAVC_PROP_HEADER,
+        "Header property", "Set header", 0, 3, 0, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_CMP,
-        g_param_spec_uint ("cmp", "Cmp property", "Set cmp",
-           0, 2000, 0, G_PARAM_READWRITE));
+      g_param_spec_uint (OGMRIP_LAVC_PROP_CMP,
+        "Cmp property", "Set cmp", 0, 2000, 0, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_PRECMP,
-        g_param_spec_uint ("precmp", "Precmp property", "Set precmp",
-           0, 2000, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_PRECMP,
+        "Precmp property", "Set precmp", 0, 2000, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_SUBCMP,
-        g_param_spec_uint ("subcmp", "Subcmp property", "Set subcmp",
-           0, 2000, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_SUBCMP,
+        "Subcmp property", "Set subcmp", 0, 2000, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_DIA,
-        g_param_spec_int ("dia", "Dia property", "Set dia",
-           -99, 6, 1, G_PARAM_READWRITE));
-
+      g_param_spec_int (OGMRIP_LAVC_PROP_DIA,
+        "Dia property", "Set dia", -99, 6, 1, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_PREDIA,
-        g_param_spec_int ("predia", "Predia property", "Set predia",
-           -99, 6, 1, G_PARAM_READWRITE));
-
+      g_param_spec_int (OGMRIP_LAVC_PROP_PREDIA,
+        "Predia property", "Set predia", -99, 6, 1, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_MBD,
-        g_param_spec_uint ("mbd", "Mbd property", "Set mbd",
-           0, 2, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_MBD,
+        "Mbd property", "Set mbd", 0, 2, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_QNS,
-        g_param_spec_uint ("qns", "Qns property", "Set qns",
-           0, 3, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_QNS,
+        "Qns property", "Set qns", 0, 3, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_VB_STRATEGY,
-        g_param_spec_uint ("vb_strategy", "VB strategy property", "Set bv strategy",
-           0, 2, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_VB_STRATEGY,
+        "VB strategy property", "Set bv strategy", 0, 2, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_LAST_PRED,
-        g_param_spec_uint ("last_pred", "Last pref property", "Set last pred",
-           0, 99, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_LAST_PRED,
+        "Last pref property", "Set last pred", 0, 99, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_PREME,
-        g_param_spec_uint ("preme", "Preme property", "Set preme",
-           0, 2, 1, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_PREME,
+        "Preme property", "Set preme", 0, 2, 1, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_VQCOMP,
-        g_param_spec_double ("vqcomp", "Vqcomp property", "Set vqcomp",
-           0.0, 1.0, 0.5, G_PARAM_READWRITE));
-
+      g_param_spec_double (OGMRIP_LAVC_PROP_VQCOMP,
+        "Vqcomp property", "Set vqcomp", 0.0, 1.0, 0.5, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_MV0,
-        g_param_spec_boolean ("mv0", "Mv0 property", "Set mv0",
-           FALSE, G_PARAM_READWRITE));
-
+      g_param_spec_boolean (OGMRIP_LAVC_PROP_MV0,
+        "Mv0 property", "Set mv0", FALSE, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_DC,
-        g_param_spec_uint ("dc", "DC property", "Set dc",
-           1, G_MAXUINT, 8, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_DC,
+        "DC property", "Set dc", 1, G_MAXUINT, 8, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_KEYINT,
-        g_param_spec_uint ("keyint", "Keyint property", "Set keyint",
-           1, G_MAXUINT, 250, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_KEYINT,
+        "Keyint property", "Set keyint", 1, G_MAXUINT, 250, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_BUF_SIZE,
-        g_param_spec_uint ("buf_size", "Buffer size property", "Set buffer size",
-           0, G_MAXUINT, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_BUF_SIZE,
+        "Buffer size property", "Set buffer size", 0, G_MAXUINT, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_MIN_RATE,
-        g_param_spec_uint ("min_rate", "Min rate property", "Set min rate",
-           0, G_MAXUINT, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_MIN_RATE,
+        "Min rate property", "Set min rate", 0, G_MAXUINT, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_MAX_RATE,
-        g_param_spec_uint ("max_rate", "Max rate property", "Set max rate",
-           0, G_MAXUINT, 0, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_MAX_RATE,
+        "Max rate property", "Set max rate", 0, G_MAXUINT, 0, G_PARAM_READWRITE));
+  
   g_object_class_install_property (gobject_class, PROP_STRICT,
-        g_param_spec_uint ("strict", "Strict property", "Set strict",
-           0, 3, 2, G_PARAM_READWRITE));
-
+      g_param_spec_uint (OGMRIP_LAVC_PROP_STRICT,
+        "Strict property", "Set strict", 0, 3, 2, G_PARAM_READWRITE));
+ 
   g_type_class_add_private (klass, sizeof (OGMRipLavcPriv));
 }
 
@@ -566,6 +606,62 @@ ogmrip_lavc_set_quality (OGMRipVideoCodec *video, OGMRipQualityType quality)
       lavc->priv->vqcomp = 0.5;
       lavc->priv->mv0 = FALSE;
       break;
+    case OGMRIP_QUALITY_USER:
+      break;
+  }
+}
+
+static void
+ogmrip_lavc_set_options (OGMRipCodec *codec, const gchar *section)
+{
+  OGMRipSettings *settings;
+
+  settings = ogmrip_settings_get_default ();
+  if (settings)
+  {
+    gchar *key;
+    guint i;
+
+    for (i = 0; properties[i]; i++)
+    {
+      key = ogmrip_settings_build_section (settings, OGMRIP_LAVC_SECTION, properties[i], NULL);
+      ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), properties[i], section, key);
+      g_free (key);
+    }
+  }
+}
+
+/**
+ * ogmrip_init_lavc_plugin:
+ *
+ * Initialises the LAVC plugin. This function should be called
+ * when initialising a plugin of the LAVC family.
+ */
+void
+ogmrip_init_lavc_plugin (void)
+{
+  static gboolean initialized = FALSE;
+
+  if (!initialized)
+  {
+    OGMRipSettings *settings;
+
+    settings = ogmrip_settings_get_default ();
+    if (settings)
+    {
+      GObjectClass *klass;
+      guint i;
+
+      klass = g_type_class_ref (OGMRIP_TYPE_LAVC);
+
+      for (i = 0; properties[i]; i++)
+        ogmrip_settings_install_key_from_property (settings, klass,
+            OGMRIP_LAVC_SECTION, properties[i], properties[i]);
+
+      g_type_class_unref (klass);
+
+      initialized = TRUE;
+    }
   }
 }
 
