@@ -23,6 +23,29 @@
 
 G_BEGIN_DECLS
 
+#define OGMRIP_LAVC_SECTION          "lavc"
+
+#define OGMRIP_LAVC_PROP_HEADER      "header"
+#define OGMRIP_LAVC_PROP_CMP         "cmp"
+#define OGMRIP_LAVC_PROP_PRECMP      "precmp"
+#define OGMRIP_LAVC_PROP_SUBCMP      "subcmp"
+#define OGMRIP_LAVC_PROP_DIA         "dia"
+#define OGMRIP_LAVC_PROP_PREDIA      "predia"
+#define OGMRIP_LAVC_PROP_KEYINT      "keyint"
+#define OGMRIP_LAVC_PROP_BUF_SIZE    "buf_size"
+#define OGMRIP_LAVC_PROP_MIN_RATE    "min_rate"
+#define OGMRIP_LAVC_PROP_MAX_RATE    "max_rate"
+#define OGMRIP_LAVC_PROP_STRICT      "strict"
+#define OGMRIP_LAVC_PROP_DC          "dc"
+#define OGMRIP_LAVC_PROP_MBD         "mbd"
+#define OGMRIP_LAVC_PROP_QNS         "qns"
+#define OGMRIP_LAVC_PROP_VB_STRATEGY "vb_strategy"
+#define OGMRIP_LAVC_PROP_LAST_PRED   "last_pred"
+#define OGMRIP_LAVC_PROP_PREME       "preme"
+#define OGMRIP_LAVC_PROP_VQCOMP      "vqcomp"
+#define OGMRIP_LAVC_PROP_MV0         "mv0"
+#define OGMRIP_LAVC_PROP_V4MV        "v4mv"
+
 #define OGMRIP_TYPE_LAVC           (ogmrip_lavc_get_type ())
 #define OGMRIP_LAVC(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_LAVC, OGMRipLavc))
 #define OGMRIP_LAVC_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_LAVC, OGMRipLavcClass))
@@ -49,6 +72,15 @@ struct _OGMRipLavcClass
   G_CONST_RETURN gchar * (* get_codec) (void);
 };
 
+/**
+ * OGMRipLavcHeaderType:
+ * @OGMRIP_LAVC_HEADER_AUTO: Codec decides where to write global headers.
+ * @OGMRIP_LAVC_HEADER_EXTRADATA: Write global headers only in extradata.
+ * @OGMRIP_LAVC_HEADER_KEYFRAMES: Write global headers only in front of keyframes.
+ * @OGMRIP_LAVC_HEADER_COMBINE: Combine @OGMRIP_LAVC_HEADER_EXTRADATA and @OGMRIP_LAVC_HEADER_KEYFRAMES.
+ *
+ * Controls writing global video headers.
+ */
 typedef enum
 {
   OGMRIP_LAVC_HEADER_AUTO,
@@ -57,6 +89,8 @@ typedef enum
   OGMRIP_LAVC_HEADER_COMBINE
 } OGMRipLavcHeaderType;
 
+void          ogmrip_init_lavc_plugin     (void);
+
 GType         ogmrip_lavc_get_type        (void);
 
 void          ogmrip_lavc_set_cmp         (OGMRipLavc           *lavc,
