@@ -70,7 +70,7 @@ ogmrip_matroska_watch (OGMJobExec *exec, const gchar *buffer, OGMRipContainer *m
 
   if (sscanf (buffer, "progress: %lu/%lu frames (%u%%)", &frames, &total, &percent) == 3)
     return percent / 100.0;
-  else if (sscanf (buffer, "progress: %u%%", &percent) == 1)
+  else if (sscanf (buffer, "Progress: %u%%", &percent) == 1)
     return percent / 100.0;
 
   return -1.0;
@@ -511,6 +511,8 @@ ogmrip_init_plugin (GError **error)
       minor_version = strtoul (end + 1, NULL, 10);
   }
 
+  g_free (output);
+
   mkv_plugin.type = OGMRIP_TYPE_MATROSKA;
   mkv_plugin.formats = formats;
 
