@@ -20,7 +20,7 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-mp3.h"
+#include "ogmrip-audio-codec.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-fs.h"
@@ -36,6 +36,26 @@
 #define PROGRAM "lame"
 #define MP3_SPF 1152
 
+#define OGMRIP_TYPE_MP3          (ogmrip_mp3_get_type ())
+#define OGMRIP_MP3(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_MP3, OGMRipMp3))
+#define OGMRIP_MP3_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_MP3, OGMRipMp3Class))
+#define OGMRIP_IS_MP3(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_MP3))
+#define OGMRIP_IS_MP3_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_MP3))
+
+typedef struct _OGMRipMp3      OGMRipMp3;
+typedef struct _OGMRipMp3Class OGMRipMp3Class;
+
+struct _OGMRipMp3
+{
+  OGMRipAudioCodec parent_instance;
+};
+
+struct _OGMRipMp3Class
+{
+  OGMRipAudioCodecClass parent_class;
+};
+
+GType ogmrip_mp3_get_type (void);
 static gint ogmrip_mp3_run (OGMJobSpawn *spawn);
 static gint ogmrip_mp3_get_samples_per_frame (OGMRipAudioCodec *audio);
 
@@ -44,17 +64,17 @@ ogmrip_mp3_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input
 {
   static gchar *presets[][2] =
   {
-    { "96",       NULL },
-    { "112",      NULL },
-    { "128",      NULL },
-    { "fast",    "medium" },
-    { "medium",   NULL },
+    { "96",       NULL      },
+    { "112",      NULL      },
+    { "128",      NULL      },
+    { "fast",    "medium"   },
+    { "medium",   NULL      },
     { "fast",    "standard" },
-    { "standard", NULL },
-    { "fast",    "extreme" },
-    { "extreme",  NULL },
-    { "fast",    "insane" },
-    { "insane",   NULL }
+    { "standard", NULL      },
+    { "fast",    "extreme"  },
+    { "extreme",  NULL      },
+    { "320",      NULL      },
+    { "insane",   NULL      }
   };
 
   GPtrArray *argv;
@@ -181,24 +201,6 @@ ogmrip_mp3_get_samples_per_frame (OGMRipAudioCodec *audio)
   return MP3_SPF;
 }
 
-/**
- * ogmrip_mp3_new:
- * @audio: An #OGMDvdAudioStream
- * @output: The output file
- *
- * Creates a new #OGMRipMp3.
- *
- * Returns: The new #OGMRipMp3
- */
-OGMJobSpawn *
-ogmrip_mp3_new (OGMDvdAudioStream *audio, const gchar *output)
-{
-  g_return_val_if_fail (audio != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_MP3, "stream", audio, "output", output, NULL);
-}
-
 static OGMRipAudioPlugin mp3_plugin =
 {
   NULL,
@@ -209,20 +211,31 @@ static OGMRipAudioPlugin mp3_plugin =
 };
 
 OGMRipAudioPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  gboolean have_mplayer, have_lame;
   gchar *fullname;
 
-  if (!ogmrip_check_mplayer ())
-    return NULL;
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  have_mplayer = ogmrip_check_mplayer ();
 
   fullname = g_find_program_in_path (PROGRAM);
-  if (!fullname)
-    return NULL;
+  have_lame = fullname != NULL;
   g_free (fullname);
 
   mp3_plugin.type = OGMRIP_TYPE_MP3;
 
-  return &mp3_plugin;
+  if (have_mplayer && have_lame)
+    return &mp3_plugin;
+
+  if (!have_mplayer && !have_lame)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer and LAME are missing"));
+  else if (!have_mplayer)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer is missing"));
+  else if (!have_lame)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("LAME is missing"));
+
+  return NULL;
 }
 
