@@ -241,7 +241,7 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
 
   gdouble start, length;
   const gchar *device;
-  gchar *chap, *ofps;
+  gchar *chap;
   gint vid;
 
   g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
@@ -268,14 +268,6 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
-  if (!ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-mc"));
-    g_ptr_array_add (argv, g_strdup ("0"));
-  }
-  g_free (ofps);
-
   length = ogmrip_codec_get_play_length (OGMRIP_CODEC (audio));
 
   if (length <= 0.0)
@@ -322,6 +314,9 @@ ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gcha
     g_ptr_array_add (argv, g_strdup (output));
   }
 
+  g_ptr_array_add (argv, g_strdup ("-format"));
+  g_ptr_array_add (argv, g_strdup ("s16le"));
+
   options = g_string_new (NULL);
 
   if (ogmrip_audio_codec_get_normalize (audio))
@@ -458,7 +453,7 @@ ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
   GPtrArray *argv;
   const gchar *device;
   gdouble start, length;
-  gchar *ofps, *chap;
+  gchar *chap;
   gint vid;
 
   OGMDvdTitle *title;
@@ -479,18 +474,6 @@ ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
-  if (ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ofps"));
-    g_ptr_array_add (argv, ofps);
-  }
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-mc"));
-    g_ptr_array_add (argv, g_strdup ("0"));
-  }
-
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (audio), title);
   if (chap)
   {
@@ -549,22 +532,17 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
 {
   GPtrArray *argv;
   OGMDvdTitle *title;
-  OGMRipScalerType scaler;
-  OGMRipDeintType deint;
-  OGMDvdAudioStream *astream;
-  OGMDvdSubpStream *sstream;
-  GString *options, *pp;
 
+  gint format;
   const gchar *device;
-  guint max_width, max_height;
-  guint crop_x, crop_y, crop_width, crop_height;
-  guint scale_width, scale_height;
-  gboolean crop, scale, expand, forced;
   gdouble start, length;
   gchar *ofps, *chap;
+  gboolean scale;
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
 
+  format = ogmrip_plugin_get_video_codec_format (G_OBJECT_TYPE (video));
+
   argv = g_ptr_array_new ();
 
   g_ptr_array_add (argv, g_strdup ("mencoder"));
@@ -577,43 +555,155 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
-  astream = ogmrip_video_codec_get_ensure_sync (video);
-  if (astream)
-  {
-    g_ptr_array_add (argv, g_strdup ("-oac"));
-    g_ptr_array_add (argv, g_strdup ("pcm"));
-    g_ptr_array_add (argv, g_strdup ("-srate"));
-    g_ptr_array_add (argv, g_strdup ("8000"));
-    g_ptr_array_add (argv, g_strdup ("-af"));
-    g_ptr_array_add (argv, g_strdup ("channels=1,lavcresample=8000"));
-    g_ptr_array_add (argv, g_strdup ("-aid"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
-/*
-    g_ptr_array_add (argv, g_strdup ("-channels"));
-    g_ptr_array_add (argv, g_strdup ("1"));
-*/
-  }
-  else
+  scale = FALSE;
+
+  if (format == OGMRIP_FORMAT_COPY)
     g_ptr_array_add (argv, g_strdup ("-nosound"));
-
-  sstream = ogmrip_video_codec_get_hard_subp (video, &forced);
-  if (sstream)
+  else
   {
-    g_ptr_array_add (argv, g_strdup ("-spuaa"));
-    g_ptr_array_add (argv, g_strdup ("20"));
-    g_ptr_array_add (argv, g_strdup ("-sid"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d",
-          ogmdvd_stream_get_id (OGMDVD_STREAM (sstream))));
+    OGMDvdAudioStream *astream;
+    OGMDvdSubpStream *sstream;
+    OGMRipScalerType scaler;
+    OGMRipDeintType deint;
 
-    if (forced)
-      g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
+    GString *options, *pp;
+    guint max_width, max_height;
+    guint scale_width, scale_height;
+    guint crop_x, crop_y, crop_width, crop_height;
+    gboolean crop, expand, forced;
+
+    astream = ogmrip_video_codec_get_ensure_sync (video);
+    if (astream)
+    {
+      g_ptr_array_add (argv, g_strdup ("-oac"));
+      g_ptr_array_add (argv, g_strdup ("pcm"));
+      g_ptr_array_add (argv, g_strdup ("-srate"));
+      g_ptr_array_add (argv, g_strdup ("8000"));
+      g_ptr_array_add (argv, g_strdup ("-af"));
+      g_ptr_array_add (argv, g_strdup ("channels=1,lavcresample=8000"));
+      g_ptr_array_add (argv, g_strdup ("-aid"));
+      g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
+    }
+    else
+      g_ptr_array_add (argv, g_strdup ("-nosound"));
+
+    sstream = ogmrip_video_codec_get_hard_subp (video, &forced);
+    if (sstream)
+    {
+      g_ptr_array_add (argv, g_strdup ("-spuaa"));
+      g_ptr_array_add (argv, g_strdup ("20"));
+      g_ptr_array_add (argv, g_strdup ("-sid"));
+      g_ptr_array_add (argv, g_strdup_printf ("%d",
+            ogmdvd_stream_get_id (OGMDVD_STREAM (sstream))));
+
+      if (forced)
+        g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
+    }
+
+    scaler = ogmrip_video_codec_get_scaler (video);
+    g_ptr_array_add (argv, g_strdup ("-sws"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
+
+    scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
+
+    options = g_string_new (NULL);
+    pp = g_string_new (NULL);
+
+    if (ogmrip_video_codec_get_deblock (video))
+    {
+      if (pp->len > 0)
+        g_string_append_c (pp, '/');
+      g_string_append (pp, "ha/va");
+    }
+
+    if (ogmrip_video_codec_get_dering (video))
+    {
+      if (pp->len > 0)
+        g_string_append_c (pp, '/');
+      g_string_append (pp, "dr");
+    }
+
+    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append (options, "pullup,softskip");
+    }
+
+    crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
+    if (crop)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
+    }
+
+    deint = ogmrip_video_codec_get_deinterlacer (video);
+    if (deint != OGMRIP_DEINT_NONE)
+    {
+      if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
+      {
+        if (options->len > 0)
+          g_string_append_c (options, ',');
+        g_string_append (options, deinterlacer[deint - 1]);
+      }
+      else
+      {
+        if (pp->len > 0)
+          g_string_append_c (pp, '/');
+        g_string_append (pp, deinterlacer[deint - 1]);
+      }
+    }
+
+    if (pp->len > 0)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "pp=%s", pp->str);
+    }
+    g_string_free (pp, TRUE);
+
+    if (scale)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
+    }
+
+    if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
+    }
+
+    if (ogmrip_video_codec_get_denoise (video))
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append (options, "hqdn3d=2:1:2");
+    }
+
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append (options, "harddup");
+
+    if (options->len == 0)
+      g_string_free (options, TRUE);
+    else
+    {
+      g_ptr_array_add (argv, g_strdup ("-vf"));
+      g_ptr_array_add (argv, g_string_free (options, FALSE));
+    }
+
+    ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (video), title);
+    if (ofps)
+    {
+      g_ptr_array_add (argv, g_strdup ("-ofps"));
+      g_ptr_array_add (argv, ofps);
+    }
   }
 
-  scaler = ogmrip_video_codec_get_scaler (video);
-  g_ptr_array_add (argv, g_strdup ("-sws"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
-
-  scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
   g_ptr_array_add (argv, g_strdup (scale ? "-zoom": "-nozoom"));
 
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (video), title);
@@ -642,108 +732,6 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
 
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (video), argv, TRUE);
 
-  options = g_string_new (NULL);
-  pp = g_string_new (NULL);
-
-  if (ogmrip_video_codec_get_deblock (video))
-  {
-    if (pp->len > 0)
-      g_string_append_c (pp, '/');
-    g_string_append (pp, "ha/va");
-  }
-
-  if (ogmrip_video_codec_get_dering (video))
-  {
-    if (pp->len > 0)
-      g_string_append_c (pp, '/');
-    g_string_append (pp, "dr");
-  }
-
-  if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "pullup,softskip");
-  }
-
-  crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
-  if (crop)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
-  }
-
-  deint = ogmrip_video_codec_get_deinterlacer (video);
-  if (deint != OGMRIP_DEINT_NONE)
-  {
-    if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, deinterlacer[deint - 1]);
-    }
-    else
-    {
-      if (pp->len > 0)
-        g_string_append_c (pp, '/');
-      g_string_append (pp, deinterlacer[deint - 1]);
-    }
-  }
-
-  if (pp->len > 0)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "pp=%s", pp->str);
-  }
-  g_string_free (pp, TRUE);
-
-  if (scale)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
-  }
-
-  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
-  }
-
-  if (ogmrip_video_codec_get_denoise (video))
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "hqdn3d=2:1:2");
-  }
-
-  if (options->len > 0)
-    g_string_append_c (options, ',');
-  g_string_append (options, "harddup");
-
-  if (options->len == 0)
-    g_string_free (options, TRUE);
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-vf"));
-    g_ptr_array_add (argv, g_string_free (options, FALSE));
-  }
-
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (video), title);
-  if (ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ofps"));
-    g_ptr_array_add (argv, ofps);
-  }
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-mc"));
-    g_ptr_array_add (argv, g_strdup ("0"));
-  }
-
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
 
@@ -794,18 +782,13 @@ GPtrArray *
 ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 {
   OGMDvdTitle *title;
-  OGMRipScalerType scaler;
-  OGMRipDeintType deint;
-  GString *options, *pp;
   GPtrArray *argv;
 
+  gint format;
   const gchar *device;
   gdouble start, length;
-  guint max_width, max_height;
-  guint crop_x, crop_y, crop_width, crop_height;
-  guint scale_width, scale_height;
-  gboolean crop, scale, expand;
-  gchar *chap, *ofps;
+  gboolean scale;
+  gchar *chap;
 
   g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
 
@@ -815,6 +798,8 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
 
+  format = ogmrip_plugin_get_video_codec_format (G_OBJECT_TYPE (video));
+
   argv = g_ptr_array_new ();
 
   g_ptr_array_add (argv, g_strdup ("mplayer"));
@@ -830,110 +815,117 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
-  scaler = ogmrip_video_codec_get_scaler (video);
-  g_ptr_array_add (argv, g_strdup ("-sws"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
+  scale = FALSE;
 
-  scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
-  g_ptr_array_add (argv, g_strdup (scale ? "-zoom" : "-nozoom"));
-
-  options = g_string_new (NULL);
-  pp = g_string_new (NULL);
-
-  if (ogmrip_video_codec_get_deblock (video))
+  if (format != OGMRIP_FORMAT_COPY)
   {
-    if (pp->len > 0)
-      g_string_append_c (pp, '/');
-    g_string_append (pp, "ha/va");
-  }
+    OGMRipScalerType scaler;
+    OGMRipDeintType deint;
 
-  if (ogmrip_video_codec_get_dering (video))
-  {
-    if (pp->len > 0)
-      g_string_append_c (pp, '/');
-    g_string_append (pp, "dr");
-  }
+    GString *options, *pp;
+    guint max_width, max_height;
+    guint crop_x, crop_y, crop_width, crop_height;
+    guint scale_width, scale_height;
+    gboolean crop, expand;
 
-  if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "pullup,softskip");
-  }
+    scaler = ogmrip_video_codec_get_scaler (video);
+    g_ptr_array_add (argv, g_strdup ("-sws"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
 
-  crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
-  if (crop)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
-  }
+    scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
 
-  deint = ogmrip_video_codec_get_deinterlacer (video);
-  if (deint != OGMRIP_DEINT_NONE)
-  {
-    if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
-    {
-      if (options->len > 0)
-        g_string_append_c (options, ',');
-      g_string_append (options, deinterlacer[deint - 1]);
-    }
-    else
+    options = g_string_new (NULL);
+    pp = g_string_new (NULL);
+
+    if (ogmrip_video_codec_get_deblock (video))
     {
       if (pp->len > 0)
         g_string_append_c (pp, '/');
-      g_string_append (pp, deinterlacer[deint - 1]);
+      g_string_append (pp, "ha/va");
+    }
+
+    if (ogmrip_video_codec_get_dering (video))
+    {
+      if (pp->len > 0)
+        g_string_append_c (pp, '/');
+      g_string_append (pp, "dr");
+    }
+
+    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append (options, "pullup,softskip");
+    }
+
+    crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
+    if (crop)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
+    }
+
+    deint = ogmrip_video_codec_get_deinterlacer (video);
+    if (deint != OGMRIP_DEINT_NONE)
+    {
+      if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
+      {
+        if (options->len > 0)
+          g_string_append_c (options, ',');
+        g_string_append (options, deinterlacer[deint - 1]);
+      }
+      else
+      {
+        if (pp->len > 0)
+          g_string_append_c (pp, '/');
+        g_string_append (pp, deinterlacer[deint - 1]);
+      }
+    }
+
+    if (pp->len > 0)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "pp=%s", pp->str);
+    }
+    g_string_free (pp, TRUE);
+
+    if (scale)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
+    }
+
+    if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
+    }
+
+    if (ogmrip_video_codec_get_denoise (video))
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append (options, "hqdn3d=2:1:2");
+    }
+
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append (options, "harddup");
+
+    if (options->len == 0)
+      g_string_free (options, TRUE);
+    else
+    {
+      g_ptr_array_add (argv, g_strdup ("-vf"));
+      g_ptr_array_add (argv, g_string_free (options, FALSE));
     }
   }
 
-  if (pp->len > 0)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "pp=%s", pp->str);
-  }
-  g_string_free (pp, TRUE);
-
-  if (scale)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
-  }
-
-  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
-  }
-
-  if (ogmrip_video_codec_get_denoise (video))
-  {
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append (options, "hqdn3d=2:1:2");
-  }
-
-  if (options->len > 0)
-    g_string_append_c (options, ',');
-  g_string_append (options, "harddup");
-
-  if (options->len == 0)
-    g_string_free (options, TRUE);
-  else
-  {
-    g_ptr_array_add (argv, g_strdup ("-vf"));
-    g_ptr_array_add (argv, g_string_free (options, FALSE));
-  }
-
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (video), title);
-  if (!ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-mc"));
-    g_ptr_array_add (argv, g_strdup ("0"));
-  }
-  g_free (ofps);
+  g_ptr_array_add (argv, g_strdup (scale ? "-zoom" : "-nozoom"));
 
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
@@ -1017,8 +1009,8 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   GPtrArray *argv;
   gdouble start, length;
   const gchar *device;
-  gchar *ofps, *chap;
   gint vid, sid;
+  gchar *chap;
 
   g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
 
@@ -1052,13 +1044,6 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("copy"));
 
-  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (subp), title);
-  if (ofps)
-  {
-    g_ptr_array_add (argv, g_strdup ("-ofps"));
-    g_ptr_array_add (argv, ofps);
-  }
-
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup ("/dev/null"));
 
@@ -1069,10 +1054,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("0"));
   g_ptr_array_add (argv, g_strdup ("-sid"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", sid));
-/*
-  if (ogmrip_subp_codec_get_forced_only (subp))
-    g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
-*/
+
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (subp), title);
   if (chap)
   {
