@@ -20,7 +20,7 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-ogg.h"
+#include "ogmrip-container.h"
 #include "ogmrip-plugin.h"
 #include "ogmjob-exec.h"
 
@@ -29,6 +29,26 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define OGMRIP_TYPE_OGG          (ogmrip_ogg_get_type ())
+#define OGMRIP_OGG(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_OGG, OGMRipOgg))
+#define OGMRIP_OGG_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_OGG, OGMRipOggClass))
+#define OGMRIP_IS_OGG(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_OGG))
+#define OGMRIP_IS_OGG_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_OGG))
+
+typedef struct _OGMRipOgg      OGMRipOgg;
+typedef struct _OGMRipOggClass OGMRipOggClass;
+
+struct _OGMRipOgg
+{
+  OGMRipContainer parent_instance;
+};
+
+struct _OGMRipOggClass
+{
+  OGMRipContainerClass parent_class;
+};
+
+GType ogmrip_ogg_get_type (void);
 static gint ogmrip_ogg_run (OGMJobSpawn *spawn);
 
 static gdouble
@@ -254,11 +274,13 @@ ogmrip_ogg_merge_command (OGMRipContainer *ogg, const gchar *output)
     g_ptr_array_add (argv, g_strdup_printf ("TITLE=%s", label));
   }
 
-  video = ogmrip_container_get_video (ogg);
-  filename = ogmrip_codec_get_output (OGMRIP_CODEC (video));
+  if ((video = ogmrip_container_get_video (ogg)))
+  {
+    filename = ogmrip_codec_get_output (OGMRIP_CODEC (video));
 
-  g_ptr_array_add (argv, g_strdup ("--noaudio"));
-  g_ptr_array_add (argv, g_strdup (filename));
+    g_ptr_array_add (argv, g_strdup ("--noaudio"));
+    g_ptr_array_add (argv, g_strdup (filename));
+  }
 
   ogmrip_container_foreach_audio (ogg, 
       (OGMRipContainerCodecFunc) ogmrip_ogg_merge_foreach_audio, argv);
@@ -375,7 +397,7 @@ ogmrip_ogg_run (OGMJobSpawn *spawn)
     ogmjob_container_remove (OGMJOB_CONTAINER (spawn), child);
   }
 
-  if (tnumber > 1 && result == OGMJOB_RESULT_COMPLETED)
+  if (tnumber > 1 && result == OGMJOB_RESULT_SUCCESS)
   {
     argv = ogmrip_ogg_split_command (OGMRIP_CONTAINER (spawn), file);
     if (argv)
@@ -403,28 +425,13 @@ ogmrip_ogg_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_ogg_new:
- * @output: The output file
- *
- * Creates a new #OGMRipOgg.
- *
- * Returns: The new #OGMRipOgg
- */
-OGMJobSpawn *
-ogmrip_ogg_new (const gchar *output)
-{
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_OGG, "output", output, NULL);
-}
-
 static OGMRipContainerPlugin ogg_plugin =
 {
   NULL,
   G_TYPE_NONE,
   "ogm",
   N_("Ogg Media (OGM)"),
+  FALSE,
   TRUE,
   G_MAXINT,
   G_MAXINT,
@@ -445,23 +452,34 @@ static gint formats[] =
 };
 
 OGMRipContainerPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  gboolean have_ogmmerge, have_ogmsplit;
   gchar *fullname;
 
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
   fullname = g_find_program_in_path ("ogmmerge");
-  if (!fullname)
-    return NULL;
+  have_ogmmerge = fullname != NULL;
   g_free (fullname);
 
   fullname = g_find_program_in_path ("ogmsplit");
-  if (!fullname)
-    return NULL;
+  have_ogmsplit = fullname != NULL;
   g_free (fullname);
 
   ogg_plugin.type = OGMRIP_TYPE_OGG;
   ogg_plugin.formats = formats;
 
-  return &ogg_plugin;
+  if (have_ogmmerge && have_ogmsplit)
+    return &ogg_plugin;
+
+  if (!have_ogmmerge && !have_ogmsplit)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("ogmmerge and ogmsplit are missing"));
+  else if (!have_ogmmerge)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("ogmmerge is missing"));
+  else if (!have_ogmsplit)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("ogmsplit is missing"));
+
+  return NULL;
 }
 
