@@ -64,6 +64,7 @@ typedef struct
 
   gulong signal_handler;
   gulong notify_handler;
+  gboolean blocked;
 } OGMRipBinding;
 
 static OGMRipSettings *default_settings;
@@ -81,35 +82,41 @@ ogmrip_binding_disconnect_cb (OGMRipBinding *binding)
 static void
 ogmrip_binding_property_notify_cb (OGMRipBinding *binding)
 {
-  GValue value = {0};
+  if (!binding->blocked)
+  {
+    GValue value = {0};
 
-  g_value_init (&value, binding->type);
-  (* binding->get_func) (binding->object, binding->property, &value, binding->data);
-  ogmrip_settings_set_value (binding->settings, binding->section, binding->key, &value);
-  g_value_unset (&value);
+    g_value_init (&value, binding->type);
+    (* binding->get_func) (binding->object, binding->property, &value, binding->data);
+    ogmrip_settings_set_value (binding->settings, binding->section, binding->key, &value);
+    g_value_unset (&value);
+  }
 }
 
 static void
 ogmrip_binding_key_notify_cb (OGMRipSettings *settings, const gchar *section, const gchar *key,
     const GValue *value, OGMRipBinding *binding)
 {
-  g_signal_handlers_block_by_func (binding->object, ogmrip_binding_property_notify_cb, binding);
-
-  if (value && G_IS_VALUE (value))
-    (* binding->set_func) (binding->object, binding->property, value, binding->data);
-  else
+  if (!binding->blocked)
   {
-    GValue val = {0};
+    g_signal_handlers_block_by_func (binding->object, ogmrip_binding_property_notify_cb, binding);
 
-    ogmrip_settings_get_value (binding->settings, binding->section, binding->key, &val);
-    if (G_IS_VALUE (&val))
+    if (value && G_IS_VALUE (value))
+      (* binding->set_func) (binding->object, binding->property, value, binding->data);
+    else
     {
-      (* binding->set_func) (binding->object, binding->property, &val, binding->data);
-      g_value_unset (&val);
-    }
-  }
+      GValue val = {0};
 
-  g_signal_handlers_unblock_by_func (binding->object, ogmrip_binding_property_notify_cb, binding);
+      ogmrip_settings_get_value (binding->settings, binding->section, binding->key, &val);
+      if (G_IS_VALUE (&val))
+      {
+        (* binding->set_func) (binding->object, binding->property, &val, binding->data);
+        g_value_unset (&val);
+      }
+    }
+
+    g_signal_handlers_unblock_by_func (binding->object, ogmrip_binding_property_notify_cb, binding);
+  }
 }
 
 static void
@@ -861,6 +868,7 @@ ogmrip_settings_get_subsections (OGMRipSettings *settings, const gchar *section)
 GSList *
 ogmrip_settings_get_keys (OGMRipSettings *settings, const gchar *section, gboolean recursive)
 {
+  GSList *list;
   OGMRipSettingsIface *iface;
 
   g_return_val_if_fail (OGMRIP_IS_SETTINGS (settings), NULL);
@@ -870,7 +878,10 @@ ogmrip_settings_get_keys (OGMRipSettings *settings, const gchar *section, gboole
   if (!iface->get_keys)
     return NULL;
 
-  return (* iface->get_keys) (settings, section, recursive);;
+  list = (* iface->get_keys) (settings, section, recursive);;
+  list = g_slist_sort (list, (GCompareFunc) strcmp);
+
+  return list;
 }
 
 /**
@@ -1200,6 +1211,82 @@ ogmrip_settings_unbind (OGMRipSettings *settings, GObject *object)
   }
 }
 
+/**
+ * ogmrip_settings_block:
+ * @settings: an #OGMRipSettings
+ * @section: the section
+ * @key: the key
+ *
+ * Blocks all notifications related to @key in @section. If @section is NULL, notifications
+ * related to @key from all sections are blocked.
+ */
+void
+ogmrip_settings_block (OGMRipSettings *settings, const gchar *section, const gchar *key)
+{
+  OGMRipSettingsIface *iface;
+  OGMRipSettingsPriv *priv;
+  OGMRipBinding *binding;
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_SETTINGS (settings));
+  g_return_if_fail (key != NULL);
+
+  iface = OGMRIP_SETTINGS_GET_IFACE (settings);
+
+  priv = ogmrip_settings_get_priv (settings);
+
+  link = priv->bindings;
+  while (link)
+  {
+    binding = link->data;
+    link = link->next;
+
+    if ((!section || g_str_equal (section, binding->section)) && g_str_equal (key, binding->key))
+    {
+      binding->blocked = TRUE;
+      break;
+    }
+  }
+}
+
+/**
+ * ogmrip_settings_unblock:
+ * @settings: an #OGMRipSettings
+ * @section: the section
+ * @key: the key
+ *
+ * Unblocks all notifications related to @key in @section. If @section is NULL, notifications
+ * related to @key from all sections are unblocked.
+ */
+void
+ogmrip_settings_unblock (OGMRipSettings *settings, const gchar *section, const gchar *key)
+{
+  OGMRipSettingsIface *iface;
+  OGMRipSettingsPriv *priv;
+  OGMRipBinding *binding;
+  GSList *link;
+
+  g_return_if_fail (OGMRIP_IS_SETTINGS (settings));
+  g_return_if_fail (key != NULL);
+
+  iface = OGMRIP_SETTINGS_GET_IFACE (settings);
+
+  priv = ogmrip_settings_get_priv (settings);
+
+  link = priv->bindings;
+  while (link)
+  {
+    binding = link->data;
+    link = link->next;
+
+    if ((!section || g_str_equal (section, binding->section)) && g_str_equal (key, binding->key))
+    {
+      binding->blocked = FALSE;
+      break;
+    }
+  }
+}
+
 /**
  * ogmrip_settings_install_key_from_property:
  * @settings: An #OGMRipSettings
