@@ -21,9 +21,9 @@
 #endif
 
 #include "ogmrip-fs.h"
-#include "ogmrip-srt.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-subp-codec.h"
 #include "ogmrip-version.h"
 
 #include "ogmjob-queue.h"
@@ -34,15 +34,33 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
-#define OGMRIP_SRT_GET_PRIVATE(o) \
-    (G_TYPE_INSTANCE_GET_PRIVATE ((o), OGMRIP_TYPE_SRT, OGMRipSrtPriv))
+G_BEGIN_DECLS
 
-struct _OGMRipSrtPriv
+#define OGMRIP_TYPE_SRT          (ogmrip_srt_get_type ())
+#define OGMRIP_SRT(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_SRT, OGMRipSrt))
+#define OGMRIP_SRT_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_SRT, OGMRipSrtClass))
+#define OGMRIP_IS_SRT(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_SRT))
+#define OGMRIP_IS_SRT_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_SRT))
+
+typedef struct _OGMRipSrt      OGMRipSrt;
+typedef struct _OGMRipSrtClass OGMRipSrtClass;
+
+struct _OGMRipSrt
 {
+  OGMRipSubpCodec parent_instance;
+
   guint files;
   guint index;
+
+  gboolean is_valid_lang;
 };
 
+struct _OGMRipSrtClass
+{
+  OGMRipSubpCodecClass parent_class;
+};
+
+GType ogmrip_srt_get_type (void);
 static gint ogmrip_srt_run (OGMJobSpawn *spawn);
 
 static gboolean use_gocr      = FALSE;
@@ -56,8 +74,8 @@ ogmrip_subp2pgm_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 
   if (sscanf (buffer, "%u files generated", &files) == 1)
   {
-    srt->priv->files = files;
-    srt->priv->index = 0;
+    srt->files = files;
+    srt->index = 0;
   }
 
   return -1.0;
@@ -68,9 +86,9 @@ ogmrip_gocr_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 {
   if (strncmp (buffer, "Elapsed time:", 13) == 0)
   {
-    srt->priv->index ++;
+    srt->index ++;
 
-    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
+    return 0.98 + 0.02 * (srt->index + 1) / (gdouble) srt->files;
   }
 
   return -1.0;
@@ -81,9 +99,9 @@ ogmrip_ocrad_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 {
   if (strncmp (buffer, "number of text blocks =", 23) == 0)
   {
-    srt->priv->index ++;
+    srt->index ++;
 
-    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
+    return 0.98 + 0.02 * (srt->index + 1) / (gdouble) srt->files;
   }
 
   return -1.0;
@@ -94,9 +112,9 @@ ogmrip_tesseract_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 {
   if (strncmp (buffer, "Tesseract Open Source OCR Engine", 32) == 0)
   {
-    srt->priv->index ++;
+    srt->index ++;
 
-    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
+    return 0.98 + 0.02 * (srt->index + 1) / (gdouble) srt->files;
   }
 
   return -1.0;
@@ -214,7 +232,7 @@ ogmrip_tesseract_command (OGMRipSubpCodec *subp, const gchar *input, gboolean la
   g_ptr_array_add (argv, g_strdup (input));
   g_ptr_array_add (argv, g_strdup (input));
 
-  if (lang)
+  if (lang && OGMRIP_SRT (subp)->is_valid_lang)
   {
     OGMDvdSubpStream *stream;
     const gchar *language;
@@ -222,13 +240,18 @@ ogmrip_tesseract_command (OGMRipSubpCodec *subp, const gchar *input, gboolean la
     stream = ogmrip_subp_codec_get_dvd_subp_stream (subp);
     language = ogmdvd_get_language_iso639_2 (ogmdvd_subp_stream_get_language (stream));
 
-    if (g_str_equal (language, "fre"))
-      language = "fra";
-    else if (g_str_equal (language, "ger"))
-      language = "deu";
+    if (g_str_equal (language, "und"))
+      OGMRIP_SRT (subp)->is_valid_lang = FALSE;
+    else
+    {
+      if (g_str_equal (language, "fre"))
+        language = "fra";
+      else if (g_str_equal (language, "ger"))
+        language = "deu";
 
-    g_ptr_array_add (argv, g_strdup ("-l"));
-    g_ptr_array_add (argv, g_strdup (language));
+      g_ptr_array_add (argv, g_strdup ("-l"));
+      g_ptr_array_add (argv, g_strdup (language));
+    }
   }
 
   g_ptr_array_add (argv, NULL);
@@ -254,13 +277,25 @@ ogmrip_srt_command (OGMRipSubpCodec *subp, const gchar *input, const gchar *outp
 
   g_ptr_array_add (argv, g_strdup ("-t"));
   g_ptr_array_add (argv, g_strdup ("srt"));
-/*
-  if (ogmrip_subp_codec_get_eol_style (OGMRIP_SUBP_CODEC (subp)))
+
+  switch (ogmrip_subp_codec_get_newline (OGMRIP_SUBP_CODEC (subp)))
   {
-    g_ptr_array_add (argv, g_strdup ("-f"));
-    g_ptr_array_add (argv, g_strdup ("dos"));
+    case OGMRIP_NEWLINE_LF:
+      g_ptr_array_add (argv, g_strdup ("-n"));
+      g_ptr_array_add (argv, g_strdup ("lf"));
+      break;
+    case OGMRIP_NEWLINE_CR_LF:
+      g_ptr_array_add (argv, g_strdup ("-n"));
+      g_ptr_array_add (argv, g_strdup ("cr+lf"));
+      break;
+    case OGMRIP_NEWLINE_CR:
+      g_ptr_array_add (argv, g_strdup ("-n"));
+      g_ptr_array_add (argv, g_strdup ("cr"));
+      break;
+    default:
+      break;
   }
-*/
+
   g_ptr_array_add (argv, g_strdup ("-i"));
   g_ptr_array_add (argv, g_strdup (input));
   g_ptr_array_add (argv, g_strdup ("-o"));
@@ -322,14 +357,12 @@ ogmrip_srt_class_init (OGMRipSrtClass *klass)
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
 
   spawn_class->run = ogmrip_srt_run;
-
-  g_type_class_add_private (klass, sizeof (OGMRipSrtPriv));
 }
 
 static void
 ogmrip_srt_init (OGMRipSrt *srt)
 {
-  srt->priv = OGMRIP_SRT_GET_PRIVATE (srt);
+  srt->is_valid_lang = TRUE;
 }
 
 static gint
@@ -367,7 +400,7 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
     ogmjob_container_remove (OGMJOB_CONTAINER (spawn), child);
   }
 
-  if (result == OGMJOB_RESULT_COMPLETED)
+  if (result == OGMJOB_RESULT_SUCCESS)
   {
     result = OGMJOB_RESULT_ERROR;
 
@@ -381,7 +414,7 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
     }
   }
 
-  if (result == OGMJOB_RESULT_COMPLETED)
+  if (result == OGMJOB_RESULT_SUCCESS)
   {
     dir = g_dir_open (ogmrip_fs_get_tmp_dir (), 0, NULL);
     if (dir)
@@ -407,17 +440,19 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
             result = ogmjob_spawn_run (child, NULL);
             g_object_unref (child);
 
-            if (result != OGMJOB_RESULT_COMPLETED)
+            if (result != OGMJOB_RESULT_SUCCESS)
             {
-              if (!use_tesseract)
+              if (!use_tesseract || !OGMRIP_SRT (spawn)->is_valid_lang)
                 break;
 
+              OGMRIP_SRT (spawn)->is_valid_lang = FALSE;
+
               if ((child = ogmrip_srt_ocr (spawn, str, FALSE)))
               {
                 result = ogmjob_spawn_run (child, NULL);
                 g_object_unref (child);
 
-                if (result != OGMJOB_RESULT_COMPLETED)
+                if (result != OGMJOB_RESULT_SUCCESS)
                   break;
               }
             }
@@ -434,7 +469,7 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
     }
   }
 
-  if (result == OGMJOB_RESULT_COMPLETED)
+  if (result == OGMJOB_RESULT_SUCCESS)
   {
     if (have_sub_files && g_file_test (xml_file, G_FILE_TEST_EXISTS))
     {
@@ -497,24 +532,6 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_srt_new:
- * @subp: An #OGMDvdSubpStream
- * @output: The output file
- *
- * Creates a new #OGMRipSrt.
- *
- * Returns: The new #OGMRipSrt
- */
-OGMJobSpawn *
-ogmrip_srt_new (OGMDvdSubpStream *subp, const gchar *output)
-{
-  g_return_val_if_fail (subp != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_SRT, "stream", subp, "output", output, NULL);
-}
-
 static OGMRipSubpPlugin srt_plugin =
 {
   NULL,
@@ -526,14 +543,19 @@ static OGMRipSubpPlugin srt_plugin =
 };
 
 OGMRipSubpPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
 #if defined(HAVE_GOCR_SUPPORT) || defined(HAVE_OCRAD_SUPPORT) || defined(HAVE_TESSERACT_SUPPORT)
   gchar *fullname;
 #endif
 
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
   if (!ogmrip_check_mencoder ())
+  {
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MEncoder is missing"));
     return NULL;
+  }
 
 #ifdef HAVE_TESSERACT_SUPPORT
   fullname = g_find_program_in_path ("tesseract");
@@ -567,7 +589,10 @@ ogmrip_init_plugin (void)
 #endif
 
   if (!use_gocr && !use_ocrad && !use_tesseract)
+  {
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("GOCR, Ocrad and Tesseract are missing"));
     return NULL;
+  }
 
   srt_plugin.type = OGMRIP_TYPE_SRT;
 
