@@ -33,8 +33,10 @@ struct _OGMRipSubpCodecPriv
   OGMDvdSubpStream *stream;
   gboolean forced_only;
 
+  gchar *label;
+
   OGMRipCharset charset;
-  OGMRipEolStyle eol;
+  OGMRipNewline newline;
 };
 
 enum 
@@ -43,10 +45,11 @@ enum
   PROP_STREAM,
   PROP_FORCED_ONLY,
   PROP_CHARSET,
-  PROP_EOL
+  PROP_NEWLINE
 };
 
 static void ogmrip_subp_codec_dispose      (GObject      *gobject);
+static void ogmrip_subp_codec_finalize     (GObject      *gobject);
 static void ogmrip_subp_codec_set_property (GObject      *gobject,
                                             guint        property_id,
                                             const GValue *value,
@@ -66,6 +69,7 @@ ogmrip_subp_codec_class_init (OGMRipSubpCodecClass *klass)
   gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->dispose = ogmrip_subp_codec_dispose;
+  gobject_class->finalize = ogmrip_subp_codec_finalize;
   gobject_class->set_property = ogmrip_subp_codec_set_property;
   gobject_class->get_property = ogmrip_subp_codec_get_property;
 
@@ -81,9 +85,9 @@ ogmrip_subp_codec_class_init (OGMRipSubpCodecClass *klass)
       g_param_spec_uint ("charset", "Charset property", "Set charset",
         0, OGMRIP_CHARSET_ASCII, 0, G_PARAM_READWRITE));
 
-  g_object_class_install_property (gobject_class, PROP_EOL,
-      g_param_spec_uint ("eol", "End of line property", "Set end of line style",
-        0, OGMRIP_EOL_CR_LF, 0, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_NEWLINE,
+      g_param_spec_uint ("newline", "Newline property", "Set newline",
+        0, OGMRIP_NEWLINE_CR_LF, 0, G_PARAM_READWRITE));
 
   g_type_class_add_private (klass, sizeof (OGMRipSubpCodecPriv));
 }
@@ -101,12 +105,29 @@ ogmrip_subp_codec_dispose (GObject *gobject)
 
   subp = OGMRIP_SUBP_CODEC (gobject);
   if (subp->priv->stream)
+  {
     ogmdvd_stream_unref (OGMDVD_STREAM (subp->priv->stream));
-  subp->priv->stream = NULL;
+    subp->priv->stream = NULL;
+  }
 
   G_OBJECT_CLASS (ogmrip_subp_codec_parent_class)->dispose (gobject);
 }
 
+static void
+ogmrip_subp_codec_finalize (GObject *gobject)
+{
+  OGMRipSubpCodec *subp;
+
+  subp = OGMRIP_SUBP_CODEC (gobject);
+  if (subp->priv->label)
+  {
+    g_free (subp->priv->label);
+    subp->priv->label = NULL;
+  }
+
+  G_OBJECT_CLASS (ogmrip_subp_codec_parent_class)->finalize (gobject);
+}
+
 static void
 ogmrip_subp_codec_set_property (GObject *gobject, guint property_id, const GValue *value, GParamSpec *pspec)
 {
@@ -125,8 +146,8 @@ ogmrip_subp_codec_set_property (GObject *gobject, guint property_id, const GValu
     case PROP_CHARSET:
       subp->priv->charset = g_value_get_uint (value);
       break;
-    case PROP_EOL: 
-      subp->priv->eol = g_value_get_uint (value);
+    case PROP_NEWLINE: 
+      subp->priv->newline = g_value_get_uint (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
@@ -152,8 +173,8 @@ ogmrip_subp_codec_get_property (GObject *gobject, guint property_id, GValue *val
     case PROP_CHARSET:
       g_value_set_uint (value, subp->priv->charset);
       break;
-    case PROP_EOL:
-      g_value_set_uint (value, subp->priv->eol);
+    case PROP_NEWLINE:
+      g_value_set_uint (value, subp->priv->newline);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
@@ -266,33 +287,71 @@ ogmrip_subp_codec_get_charset (OGMRipSubpCodec *subp)
 } 
     
 /**
- * ogmrip_subp_codec_set_eol_style:
+ * ogmrip_subp_codec_set_newline:
  * @subp: an #OGMRipSubpCodec
- * @eol: the #OGMRipEolStyle
+ * @newline: the #OGMRipNewline
  *
  * Sets the end-of-line characters of text subtitles
  */
 void
-ogmrip_subp_codec_set_eol_style (OGMRipSubpCodec *subp, OGMRipEolStyle eol)
+ogmrip_subp_codec_set_newline (OGMRipSubpCodec *subp, OGMRipNewline newline)
 { 
   g_return_if_fail (OGMRIP_IS_SUBP_CODEC (subp));
 
-  subp->priv->eol = eol;
+  subp->priv->newline = newline;
 }
 
 /**
- * ogmrip_subp_codec_get_eol_style:
+ * ogmrip_subp_codec_get_newline:
  * @subp: an #OGMRipSubpCodec
  *
  * Gets the end-of-line characters of text subtitles
  *
- * Returns: the #OGMRipEolStyle, or -1
+ * Returns: the #OGMRipNewline, or -1
  */
 gint
-ogmrip_subp_codec_get_eol_style (OGMRipSubpCodec *subp) 
+ogmrip_subp_codec_get_newline (OGMRipSubpCodec *subp) 
 {
   g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), -1);
 
-  return subp->priv->eol;
+  return subp->priv->newline;
+}
+
+/**
+ * ogmrip_subp_codec_set_label:
+ * @subp: an #OGMRipSubpCodec
+ * @label: the track name
+ *
+ * Sets the name of the track.
+ */
+void
+ogmrip_subp_codec_set_label (OGMRipSubpCodec *subp, const gchar *label)
+{
+  g_return_if_fail (OGMRIP_IS_SUBP_CODEC (subp));
+
+  if (subp->priv->label)
+  {
+    g_free (subp->priv->label);
+    subp->priv->label = NULL;
+  }
+
+  if (label)
+    subp->priv->label = g_strdup (label);
+}
+
+/**
+ * ogmrip_subp_codec_get_label:
+ * @subp: an #OGMRipSubpCodec
+ *
+ * Gets the name of the track.
+ *
+ * Returns: the track name
+ */
+G_CONST_RETURN gchar *
+ogmrip_subp_codec_get_label (OGMRipSubpCodec *subp)
+{
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
+
+  return subp->priv->label;
 }
 
