@@ -51,18 +51,19 @@ GType              ogmrip_subp_codec_get_type            (void);
 void               ogmrip_subp_codec_set_dvd_subp_stream (OGMRipSubpCodec  *subp, 
                                                           OGMDvdSubpStream *stream);
 OGMDvdSubpStream * ogmrip_subp_codec_get_dvd_subp_stream (OGMRipSubpCodec  *subp);
-
 void               ogmrip_subp_codec_set_forced_only     (OGMRipSubpCodec  *subp,
                                                           gboolean         forced_only);
 gboolean           ogmrip_subp_codec_get_forced_only     (OGMRipSubpCodec  *subp);
-
 void               ogmrip_subp_codec_set_charset         (OGMRipSubpCodec  *subp,
                                                           OGMRipCharset    charset);
 gint               ogmrip_subp_codec_get_charset         (OGMRipSubpCodec  *subp);
-
-void               ogmrip_subp_codec_set_eol_style       (OGMRipSubpCodec  *subp,
-                                                          OGMRipEolStyle   eol);
-gint               ogmrip_subp_codec_get_eol_style       (OGMRipSubpCodec  *subp);
+void               ogmrip_subp_codec_set_newline         (OGMRipSubpCodec  *subp,
+                                                          OGMRipNewline    newline);
+gint               ogmrip_subp_codec_get_newline         (OGMRipSubpCodec  *subp);
+void               ogmrip_subp_codec_set_label           (OGMRipSubpCodec  *subp,
+                                                          const gchar      *label);
+G_CONST_RETURN
+gchar *            ogmrip_subp_codec_get_label           (OGMRipSubpCodec  *subp);
 
 G_END_DECLS
 
