@@ -20,12 +20,12 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-theora.h"
-#include "ogmrip-version.h"
-#include "ogmrip-mplayer.h"
-#include "ogmrip-plugin.h"
 #include "ogmrip-file.h"
 #include "ogmrip-fs.h"
+#include "ogmrip-mplayer.h"
+#include "ogmrip-plugin.h"
+#include "ogmrip-version.h"
+#include "ogmrip-video-codec.h"
 
 #include "ogmjob-pipeline.h"
 #include "ogmjob-exec.h"
@@ -36,6 +36,26 @@
 
 #define PROGRAM "theoraenc"
 
+#define OGMRIP_TYPE_THEORA          (ogmrip_theora_get_type ())
+#define OGMRIP_THEORA(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_THEORA, OGMRipTheora))
+#define OGMRIP_THEORA_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_THEORA, OGMRipTheoraClass))
+#define OGMRIP_IS_THEORA(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_THEORA))
+#define OGMRIP_IS_THEORA_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_THEORA))
+
+typedef struct _OGMRipTheora      OGMRipTheora;
+typedef struct _OGMRipTheoraClass OGMRipTheoraClass;
+
+struct _OGMRipTheora
+{
+  OGMRipVideoCodec parent_instance;
+};
+
+struct _OGMRipTheoraClass
+{
+  OGMRipVideoCodecClass parent_class;
+};
+
+GType ogmrip_theora_get_type (void);
 static gint ogmrip_theora_run (OGMJobSpawn *spawn);
 
 static gchar **
@@ -187,24 +207,6 @@ ogmrip_theora_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_theora_new:
- * @title: An #OGMDvdTitle
- * @output: The output file
- *
- * Creates a new #OGMRipTheora.
- *
- * Returns: The new #OGMRipTheora
- */
-OGMJobSpawn *
-ogmrip_theora_new (OGMDvdTitle *title, const gchar *output)
-{
-  g_return_val_if_fail (title != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_THEORA, "input", title, "output", output, NULL);
-}
-
 static OGMRipVideoPlugin theora_plugin =
 {
   NULL,
@@ -217,20 +219,32 @@ static OGMRipVideoPlugin theora_plugin =
 };
 
 OGMRipVideoPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  gboolean have_mplayer, have_theoraenc;
   gchar *fullname;
 
-  if (!ogmrip_check_mplayer ())
-    return NULL;
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  have_mplayer = ogmrip_check_mplayer ();
 
   fullname = g_find_program_in_path (PROGRAM);
-  if (!fullname)
-    return NULL;
+  have_theoraenc = fullname != NULL;
   g_free (fullname);
 
   theora_plugin.type = OGMRIP_TYPE_THEORA;
 
-  return &theora_plugin;
+  if (have_mplayer && have_theoraenc)
+    return &theora_plugin;
+
+  if (!have_mplayer && !have_theoraenc)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, ("MPlayer and theoraenc are missing"));
+  else if (!have_mplayer)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, ("MPlayer is missing"));
+  else if (!have_theoraenc)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, ("theoraenc is missing"));
+
+  return NULL;
+
 }
 
