@@ -57,6 +57,8 @@ struct _OGMRipVideoCodecPriv
   guint scale_height;
   guint max_width;
   guint max_height;
+  guint min_width;
+  guint min_height;
   guint aspect_num;
   guint aspect_denom;
   guint max_b_frames;
@@ -581,6 +583,10 @@ ogmrip_video_codec_dispose (GObject *gobject)
     ogmdvd_stream_unref (OGMDVD_STREAM (video->priv->astream));
   video->priv->astream = NULL;
 
+  if (video->priv->sstream)
+    ogmdvd_stream_unref (OGMDVD_STREAM (video->priv->sstream));
+  video->priv->sstream = NULL;
+
   G_OBJECT_CLASS (ogmrip_video_codec_parent_class)->dispose (gobject);
 }
 
@@ -714,14 +720,16 @@ static void
 ogmrip_video_codec_autosize (OGMRipVideoCodec *video)
 {
   guint max_width, max_height;
+  guint min_width, min_height;
   gboolean expand;
 
-  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand))
+  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) ||
+      ogmrip_video_codec_get_min_size (video, &min_width, &min_height))
   {
     guint scale_width, scale_height;
 
     if (ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height) &&
-        (scale_width > max_width || scale_height > max_height))
+        (scale_width > max_width || scale_height > max_height || scale_width < min_width || scale_height < min_height))
     {
       gdouble ratio = scale_width / (gdouble) scale_height;
 
@@ -737,6 +745,18 @@ ogmrip_video_codec_autosize (OGMRipVideoCodec *video)
         scale_width = FLOOR (scale_height * ratio);
       }
 
+      if (scale_width > min_width)
+      {
+        scale_width = min_width;
+        scale_height = ROUND (scale_width / ratio);
+      }
+
+      if (scale_height > min_height)
+      {
+        scale_height = min_height;
+        scale_width = ROUND (scale_height * ratio);
+      }
+
       video->priv->scale_width = scale_width;
       video->priv->scale_height = scale_height;
     }
@@ -1646,6 +1666,50 @@ ogmrip_video_codec_set_max_size (OGMRipVideoCodec *video, guint width, guint hei
   ogmrip_video_codec_autosize (video);
 }
 
+/**
+ * ogmrip_video_codec_get_min_size:
+ * @video: an #OGMRipVideoCodec
+ * @width: a pointer to store the minimum width
+ * @height: a pointer to store the minimum height
+ *
+ * Gets wether the video has a minimum size and the minimum size.
+ *
+ * Returns: %TRUE if the video has a minimum size
+ */
+gboolean
+ogmrip_video_codec_get_min_size (OGMRipVideoCodec *video, guint *width, guint *height)
+{
+  g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), FALSE);
+
+  if (width)
+    *width = video->priv->min_width;
+
+  if (height)
+    *height = video->priv->min_height;
+
+  return video->priv->min_width && video->priv->min_height;
+}
+
+/**
+ * ogmrip_video_codec_set_min_size:
+ * @video: an #OGMRipVideoCodec
+ * @width: the minimum width
+ * @height: the minimum height
+ *
+ * Sets the minimum size of the movie.
+ */
+void
+ogmrip_video_codec_set_min_size (OGMRipVideoCodec *video, guint width, guint height)
+{
+  g_return_if_fail (OGMRIP_IS_VIDEO_CODEC (video));
+  g_return_if_fail (width >= 0 && height >= 0);
+
+  video->priv->min_width = width;
+  video->priv->min_height = height;
+
+  ogmrip_video_codec_autosize (video);
+}
+
 /**
  * ogmrip_video_codec_get_aspect_ratio:
  * @video: an #OGMRipVideoCodec
@@ -1721,7 +1785,7 @@ ogmrip_video_codec_autoscale (OGMRipVideoCodec *video)
 
   ogmdvd_title_get_framerate (title, &rnumerator, &rdenominator);
 
-  ratio = (crop_width * raw_height * anumerator) / (gdouble) (crop_height * raw_width * adenominator);
+  ratio = crop_width / (gdouble) crop_height * raw_height / raw_width * anumerator / adenominator;
 
   if (video->priv->bitrate > 0)
   {
