@@ -20,9 +20,9 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-vobsub.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-subp-codec.h"
 #include "ogmrip-version.h"
 
 #include "ogmjob-queue.h"
@@ -36,6 +36,25 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define OGMRIP_TYPE_VOBSUB          (ogmrip_vobsub_get_type ())
+#define OGMRIP_VOBSUB(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_VOBSUB, OGMRipVobSub))
+#define OGMRIP_VOBSUB_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_VOBSUB, OGMRipVobSubClass))
+#define OGMRIP_IS_VOBSUB(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_VOBSUB))
+#define OGMRIP_IS_VOBSUB_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_VOBSUB))
+
+typedef struct _OGMRipVobSub      OGMRipVobSub;
+typedef struct _OGMRipVobSubClass OGMRipVobSubClass;
+
+struct _OGMRipVobSub
+{
+  OGMRipSubpCodec parent_instance;
+};
+
+struct _OGMRipVobSubClass
+{
+  OGMRipSubpCodecClass parent_class;
+};
+
 static gint ogmrip_vobsub_run      (OGMJobSpawn *spawn);
 static void ogmrip_vobsub_finalize (GObject     *gobject);
 
@@ -150,8 +169,6 @@ ogmrip_vobsub_set_forced (OGMJobSpawn *spawn, const gchar *filename)
   {
     gint fd, i, w, len;
 
-  g_message ("Set forced !");
-
     fd = g_open (filename, O_WRONLY);
     if (fd < 0)
     {
@@ -164,8 +181,6 @@ ogmrip_vobsub_set_forced (OGMJobSpawn *spawn, const gchar *filename)
 
     for (i = 0; vline[i]; i++)
     {
-      g_message (">>%s<<\n", vline[i]);
-
       if (g_ascii_strncasecmp (vline[i], "forced subs:", 12) == 0)
       {
         len = strlen (FORCED_SUBS_LINE);
@@ -215,7 +230,7 @@ ogmrip_vobsub_run (OGMJobSpawn *spawn)
   g_object_unref (child);
 
   result = OGMJOB_SPAWN_CLASS (ogmrip_vobsub_parent_class)->run (spawn);
-  if (result == OGMJOB_RESULT_COMPLETED)
+  if (result == OGMJOB_RESULT_SUCCESS)
   {
     struct stat buf; 
     const gchar *basename;
@@ -247,24 +262,6 @@ ogmrip_vobsub_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_vobsub_new:
- * @subp: An #OGMDvdSubpStream
- * @output: The output file
- *
- * Creates a new #OGMRipVobSub.
- *
- * Returns: The new #OGMRipVobSub
- */
-OGMJobSpawn *
-ogmrip_vobsub_new (OGMDvdSubpStream *subp, const gchar *output)
-{
-  g_return_val_if_fail (subp != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_VOBSUB, "stream", subp, "output", output, NULL);
-}
-
 static OGMRipSubpPlugin vobsub_plugin =
 {
   NULL,
@@ -276,10 +273,15 @@ static OGMRipSubpPlugin vobsub_plugin =
 };
 
 OGMRipSubpPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
   if (!ogmrip_check_mencoder ())
+  {
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MEncoder is missing"));
     return NULL;
+  }
 
   vobsub_plugin.type = OGMRIP_TYPE_VOBSUB;
 
