@@ -20,11 +20,11 @@
 #include "config.h"
 #endif
 
+#include "ogmrip-audio-codec.h"
 #include "ogmrip-fs.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-version.h"
-#include "ogmrip-vorbis.h"
 
 #include "ogmjob-pipeline.h"
 #include "ogmjob-exec.h"
@@ -35,6 +35,26 @@
 
 #define PROGRAM "oggenc"
 
+#define OGMRIP_TYPE_VORBIS          (ogmrip_vorbis_get_type ())
+#define OGMRIP_VORBIS(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_VORBIS, OGMRipVorbis))
+#define OGMRIP_VORBIS_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_VORBIS, OGMRipVorbisClass))
+#define OGMRIP_IS_VORBIS(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_VORBIS))
+#define OGMRIP_IS_VORBIS_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_VORBIS))
+
+typedef struct _OGMRipVorbis      OGMRipVorbis;
+typedef struct _OGMRipVorbisClass OGMRipVorbisClass;
+
+struct _OGMRipVorbis
+{
+  OGMRipAudioCodec parent_instance;
+};
+
+struct _OGMRipVorbisClass
+{
+  OGMRipAudioCodecClass parent_class;
+};
+
+GType ogmrip_vorbis_get_type (void);
 static gint ogmrip_vorbis_run (OGMJobSpawn *spawn);
 
 gchar **
@@ -125,7 +145,7 @@ ogmrip_vorbis_run (OGMJobSpawn *spawn)
   ogmjob_container_add (OGMJOB_CONTAINER (spawn), pipeline);
   g_object_unref (pipeline);
 
-  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, NULL, fifo);
+  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), FALSE, NULL, fifo);
   if (argv)
   {
     child = ogmjob_exec_newv (argv);
@@ -133,7 +153,7 @@ ogmrip_vorbis_run (OGMJobSpawn *spawn)
     ogmjob_container_add (OGMJOB_CONTAINER (pipeline), child);
     g_object_unref (child);
 
-    argv = ogmrip_vorbis_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, fifo, NULL);
+    argv = ogmrip_vorbis_command (OGMRIP_AUDIO_CODEC (spawn), FALSE, fifo, NULL);
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
@@ -153,24 +173,6 @@ ogmrip_vorbis_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_vorbis_new:
- * @audio: An #OGMDvdAudioStream
- * @output: The output file
- *
- * Creates a new #OGMRipVorbis.
- *
- * Returns: The new #OGMRipVorbis
- */
-OGMJobSpawn *
-ogmrip_vorbis_new (OGMDvdAudioStream *audio, const gchar *output)
-{
-  g_return_val_if_fail (audio != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_VORBIS, "stream", audio, "output", output, NULL);
-}
-
 static OGMRipAudioPlugin vorbis_plugin =
 {
   NULL,
@@ -181,20 +183,31 @@ static OGMRipAudioPlugin vorbis_plugin =
 };
 
 OGMRipAudioPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  gboolean have_mplayer, have_oggenc;
   gchar *fullname;
 
-  if (!ogmrip_check_mplayer ())
-    return NULL;
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  have_mplayer = ogmrip_check_mplayer ();
 
   fullname = g_find_program_in_path (PROGRAM);
-  if (!fullname)
-    return NULL;
+  have_oggenc = fullname != NULL;
   g_free (fullname);
 
   vorbis_plugin.type = OGMRIP_TYPE_VORBIS;
 
-  return &vorbis_plugin;
+  if (have_mplayer && have_oggenc)
+    return &vorbis_plugin;
+
+  if (!have_mplayer && !have_oggenc)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer and OggEnc are missing"));
+  else if (!have_mplayer)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer is missing"));
+  else if (!have_oggenc)
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("OggEnc is missing"));
+
+  return NULL;
 }
 
