@@ -20,24 +20,37 @@
 #include "config.h"
 #endif
 
+#include "ogmrip-audio-codec.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-version.h"
-#include "ogmrip-wav.h"
 
 #include "ogmjob-exec.h"
 
 #include <stdio.h>
 #include <glib/gi18n-lib.h>
 
-#define OGMRIP_WAV_GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), OGMRIP_TYPE_WAV, OGMRipWavPriv))
+#define OGMRIP_TYPE_WAV          (ogmrip_wav_get_type ())
+#define OGMRIP_WAV(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_WAV, OGMRipWav))
+#define OGMRIP_WAV_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_WAV, OGMRipWavClass))
+#define OGMRIP_IS_WAV(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_WAV))
+#define OGMRIP_IS_WAV_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_WAV))
 
-struct _OGMRipWavPriv
+typedef struct _OGMRipWav      OGMRipWav;
+typedef struct _OGMRipWavClass OGMRipWavClass;
+
+struct _OGMRipWav
 {
+  OGMRipAudioCodec parent_instance;
+
   gboolean header;
 };
 
+struct _OGMRipWavClass
+{
+  OGMRipAudioCodecClass parent_class;
+};
+
 static gint ogmrip_wav_run (OGMJobSpawn *spawn);
 
 G_DEFINE_TYPE (OGMRipWav, ogmrip_wav, OGMRIP_TYPE_AUDIO_CODEC)
@@ -47,7 +60,7 @@ ogmrip_wav_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input
 {
   GPtrArray *argv;
 
-  argv = ogmrip_mplayer_wav_command (audio, FALSE, output);
+  argv = ogmrip_mplayer_wav_command (audio, TRUE, output);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
@@ -60,15 +73,12 @@ ogmrip_wav_class_init (OGMRipWavClass *klass)
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
 
   spawn_class->run = ogmrip_wav_run;
-
-  g_type_class_add_private (klass, sizeof (OGMRipWavPriv));
 }
 
 static void
 ogmrip_wav_init (OGMRipWav *wav)
 {
-  wav->priv = OGMRIP_WAV_GET_PRIVATE (wav);
-  wav->priv->header = TRUE;
+  wav->header = TRUE;
 }
 
 static gint
@@ -79,7 +89,7 @@ ogmrip_wav_run (OGMJobSpawn *spawn)
   gint result;
 
   argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), 
-      OGMRIP_WAV (spawn)->priv->header, NULL, NULL);
+      OGMRIP_WAV (spawn)->header, NULL, NULL);
   if (!argv)
     return OGMJOB_RESULT_ERROR;
 
@@ -95,55 +105,6 @@ ogmrip_wav_run (OGMJobSpawn *spawn)
   return result;
 }
 
-/**
- * ogmrip_wav_new:
- * @audio: An #OGMDvdAudioStream
- * @output: The output file
- *
- * Creates a new #OGMRipWav
- *
- * Returns: The new #OGMRipWav
- */
-OGMJobSpawn *
-ogmrip_wav_new (OGMDvdAudioStream *audio, const gchar *output)
-{
-  g_return_val_if_fail (audio != NULL, NULL);
-  g_return_val_if_fail (output && *output, NULL);
-
-  return g_object_new (OGMRIP_TYPE_WAV, "stream", audio, "output", output, NULL);
-}
-
-/**
- * ogmrip_wav_set_header:
- * @wav: An #OGMRipWav
- * @header: %TRUE to have the header
- *
- * Sets whether to include the wave header.
- */
-void
-ogmrip_wav_set_header (OGMRipWav *wav, gboolean header)
-{
-  g_return_if_fail (OGMRIP_IS_WAV (wav));
-
-  wav->priv->header = header;
-}
-
-/**
- * ogmrip_wav_get_header:
- * @wav: An #OGMRipWav
- *
- * Gets whether to include the wave header.
- *
- * Returns: %TRUE to include the header
- */
-gboolean
-ogmrip_wav_get_header (OGMRipWav *wav)
-{
-  g_return_val_if_fail (OGMRIP_IS_WAV (wav), FALSE);
-
-  return wav->priv->header;
-}
-
 static OGMRipAudioPlugin wav_plugin =
 {
   NULL,
@@ -154,10 +115,15 @@ static OGMRipAudioPlugin wav_plugin =
 };
 
 OGMRipAudioPlugin *
-ogmrip_init_plugin (void)
+ogmrip_init_plugin (GError **error)
 {
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
   if (!ogmrip_check_mplayer ())
+  {
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("MPlayer is missing"));
     return NULL;
+  }
 
   wav_plugin.type = OGMRIP_TYPE_WAV;
 
