@@ -50,24 +50,27 @@ struct _OGMRipX264
 {
   OGMRipVideoCodec parent_instance;
 
+  guint b_pyramid;
+  guint cqm;
+  guint direct;
   guint frameref;
+  guint keyint;
   guint level_idc;
   guint me;
   guint merange;
+  guint rc_lookahead;
   guint subq;
   guint vbv_bufsize;
   guint vbv_maxrate;
-  guint rc_lookahead;
-  guint direct;
+  guint weight_p;
+  gboolean aud;
   gboolean b_adapt;
-  gboolean b_pyramid;
   gboolean brdo;
   gboolean cabac;
+  gboolean global_header;
   gboolean mixed_refs;
   gboolean weight_b;
   gboolean x88dct;
-  gboolean global_header;
-  gboolean aud;
   gdouble psy_rd;
   gdouble psy_trellis;
 };
@@ -86,9 +89,11 @@ enum
   PROP_B_PYRAMID,
   PROP_BRDO,
   PROP_CABAC,
+  PROP_CQM,
   PROP_DIRECT,
   PROP_FRAMEREF,
   PROP_GLOBAL_HEADER,
+  PROP_KEYINT,
   PROP_LEVEL_IDC,
   PROP_ME,
   PROP_MERANGE,
@@ -99,7 +104,8 @@ enum
   PROP_SUBQ,
   PROP_VBV_BUFSIZE,
   PROP_VBV_MAXRATE,
-  PROP_WEIGHT_B
+  PROP_WEIGHT_B,
+  PROP_WEIGHT_P
 };
 
 enum
@@ -120,6 +126,13 @@ enum
   DIRECT_AUTO
 };
 
+enum
+{
+  B_PYRAMID_NONE,
+  B_PYRAMID_STRICT,
+  B_PYRAMID_NORMAL
+};
+
 static void ogmrip_x264_get_property    (GObject           *gobject,
                                          guint             property_id,
                                          GValue            *value,
@@ -138,22 +151,30 @@ static void ogmrip_x264_set_options     (OGMRipCodec       *codec,
 static const gchar * const properties[] =
 {
   OGMRIP_X264_PROP_8X8DCT,
-  OGMRIP_X264_PROP_BFRAMES,
+  OGMRIP_X264_PROP_AUD,
   OGMRIP_X264_PROP_B_ADAPT,
   OGMRIP_X264_PROP_B_PYRAMID,
+  OGMRIP_X264_PROP_BFRAMES,
+  OGMRIP_X264_PROP_BRDO,
   OGMRIP_X264_PROP_CABAC,
+  OGMRIP_X264_PROP_CQM,
   OGMRIP_X264_PROP_DIRECT,
   OGMRIP_X264_PROP_FRAMEREF,
   OGMRIP_X264_PROP_GLOBAL_HEADER,
+  OGMRIP_X264_PROP_KEYINT,
   OGMRIP_X264_PROP_LEVEL_IDC,
   OGMRIP_X264_PROP_ME,
   OGMRIP_X264_PROP_MERANGE,
   OGMRIP_X264_PROP_MIXED_REFS,
+  OGMRIP_X264_PROP_PARTITIONS,
+  OGMRIP_X264_PROP_PSY_RD,
+  OGMRIP_X264_PROP_PSY_TRELLIS,
   OGMRIP_X264_PROP_RC_LOOKAHEAD,
   OGMRIP_X264_PROP_SUBQ,
   OGMRIP_X264_PROP_VBV_BUFSIZE,
   OGMRIP_X264_PROP_VBV_MAXRATE,
   OGMRIP_X264_PROP_WEIGHT_B,
+  OGMRIP_X264_PROP_WEIGHT_P,
   NULL
 };
 
@@ -167,12 +188,29 @@ static const gchar *direct_name[] =
   "none", "spatial", "temporal", "auto"
 };
 
-gboolean x264_have_brdo      = FALSE;
-gboolean x264_have_bime      = FALSE;
-gboolean x264_have_psy       = FALSE;
-gboolean x264_have_aud       = FALSE;
-gboolean x264_have_lookahead = FALSE;
-gboolean x264_have_me_tesa   = FALSE;
+static const gchar *b_pyramid_name[] =
+{
+  "none", "strict", "normal"
+};
+
+static const gchar *cqm_name[] =
+{
+  "flat", "jvm"
+};
+
+gboolean x264_have_8x8dct     = FALSE;
+gboolean x264_have_aud        = FALSE;
+gboolean x264_have_bime       = FALSE;
+gboolean x264_have_b_pyramid  = FALSE;
+gboolean x264_have_brdo       = FALSE;
+gboolean x264_have_lookahead  = FALSE;
+gboolean x264_have_me         = FALSE;
+gboolean x264_have_me_tesa    = FALSE;
+gboolean x264_have_mixed_refs = FALSE;
+gboolean x264_have_partitions = FALSE;
+gboolean x264_have_psy        = FALSE;
+gboolean x264_have_turbo      = FALSE;
+gboolean x264_have_weight_p  = FALSE;
 
 static gint
 ogmrip_x264_get_crf (OGMRipVideoCodec *video, gdouble quantizer)
@@ -198,7 +236,6 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   const gchar *output;
   gint quality, bitrate, vid, threads, bframes;
   gboolean trellis, cartoon;
-  guint subq;
 
   g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
 
@@ -220,31 +257,19 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("x264"));
 
-  subq = x264_have_brdo ? CLAMP (x264->subq, 1, 6) : x264->subq;
-  subq = passes > 1 && pass == 1 ? MIN (2, subq) : subq;
-
   options = g_string_new (cartoon ? "deblock=1,1:aq_strength=0.6" : "deblock=-1,-1");
   g_string_append_printf (options, ":subq=%u:direct_pred=%s",
-      subq, direct_name[CLAMP (x264->direct, DIRECT_NONE, DIRECT_AUTO)]);
-
-  if (passes > 1 && pass == 1)
-    g_string_append (options, ":frameref=1");
-  else
-    g_string_append_printf (options, ":frameref=%u", cartoon ? x264->frameref * 2 : x264->frameref);
-
+      x264_have_brdo ? CLAMP (x264->subq, 1, 6) : x264->subq,
+      direct_name[CLAMP (x264->direct, DIRECT_NONE, DIRECT_AUTO)]);
+  g_string_append_printf (options, ":frameref=%u", cartoon ? x264->frameref * 2 : x264->frameref);
   g_string_append_printf (options, ":b_adapt=%u", x264->b_adapt);
-  g_string_append (options, x264->b_pyramid ? ":b_pyramid" : ":nob_pyramid");
-  g_string_append (options, x264->weight_b ? ":weight_b" : ":noweight_b");
-  g_string_append (options, x264->global_header ? ":global_header" : ":noglobal_header");
 
-  if (MPLAYER_CHECK_VERSION (1,0,1,0))
+  if (passes > 1)
+    g_string_append (options, ":nombtree");
+
+  if (x264_have_me)
   {
-    if (x264_have_brdo)
-      g_string_append (options, x264->brdo ? ":brdo" : ":nobrdo");
-
-    g_string_append (options, x264->x88dct && (passes == 1 || pass != 1) ? ":8x8dct" : ":no8x8dct");
-    g_string_append (options, x264->mixed_refs ? ":mixed_refs" : ":nomixed_refs");
-    g_string_append_printf (options, ":me=%s", me_name[passes > 1 && pass == 1 ? ME_DIA : CLAMP (x264->me, ME_DIA, ME_TESA)]);
+    g_string_append_printf (options, ":me=%s", me_name[CLAMP (x264->me, ME_DIA, ME_TESA)]);
 
     if (x264->me <= ME_HEX)
       g_string_append_printf (options, ":merange=%u", CLAMP (x264->merange, 4, 16));
@@ -254,16 +279,16 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   else
     g_string_append_printf (options, ":me=%u", x264->me);
 
-  if (x264->vbv_maxrate > 0 && x264->vbv_bufsize > 0)
-    g_string_append_printf (options, ":vbv_maxrate=%d:vbv_bufsize=%d",
-        x264->vbv_maxrate, x264->vbv_bufsize);
+  if (x264_have_brdo)
+    g_string_append (options, x264->brdo ? ":brdo" : ":nobrdo");
 
-  if (x264->level_idc > 0)
-    g_string_append_printf (options, ":level_idc=%d", CLAMP (x264->level_idc, 10, 51));
+  if (x264_have_lookahead)
+    g_string_append_printf (options, ":rc_lookahead=%u", x264->rc_lookahead);
 
-  g_string_append (options, x264->cabac ? ":cabac" : ":nocabac");
+  bframes = ogmrip_video_codec_get_max_b_frames (video);
+  g_string_append_printf (options, ":bframes=%d", cartoon ? bframes + 2 : bframes);
 
-  if (MPLAYER_CHECK_VERSION (1,0,0,8) && pass != passes)
+  if (x264_have_turbo && pass != passes)
   {
     if (ogmrip_video_codec_get_turbo (video))
       g_string_append (options, ":turbo=2");
@@ -271,52 +296,68 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
       g_string_append (options, ":turbo=1");
   }
 
-  if (ogmrip_video_codec_get_4mv (video))
-  {
-    if (MPLAYER_CHECK_VERSION (1,0,1,0))
-      g_string_append (options, passes > 1 && pass == 1 ? ":partitions=i4x4" : ":partitions=all");
-    else
-      g_string_append (options, ":4x4mv");
-  }
-
   trellis = ogmrip_video_codec_get_trellis (video);
   if (trellis)
-  {
-    if (passes > 1 && pass == 1)
-      g_string_append (options, ":trellis=0");
-    else if (quality == OGMRIP_QUALITY_EXTREME)
-      g_string_append (options, ":trellis=2");
-    else
-      g_string_append (options, ":trellis=1");
-  }
+    g_string_append (options, quality == OGMRIP_QUALITY_EXTREME ? ":trellis=2" : ":trellis=1");
   else
     g_string_append (options, ":trellis=0");
 
-  bframes = ogmrip_video_codec_get_max_b_frames (video);
-  g_string_append_printf (options, ":bframes=%d", cartoon ? bframes + 2 : bframes);
-
-  if (x264_have_bime && bframes > 0)
-    g_string_append (options, ":bime");
-
-  if (x264_have_psy && x264->subq >= 6)
+  quality = ogmrip_video_codec_get_quality (video);
+  if (quality == OGMRIP_QUALITY_USER)
   {
-    gchar psy_rd[G_ASCII_DTOSTR_BUF_SIZE], psy_trellis[G_ASCII_DTOSTR_BUF_SIZE];
+    g_string_append_printf (options, ":keyint=%u", x264->keyint);
+    g_string_append_printf (options, ":cqm=%s", cqm_name[CLAMP (x264->cqm, 0, 1)]);
 
-    g_ascii_formatd (psy_rd, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", cartoon ? 0.4 : x264->psy_rd);
-    g_ascii_formatd (psy_trellis, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", cartoon ? 0 : x264->psy_trellis);
+    g_string_append (options, x264->weight_b ? ":weight_b" : ":noweight_b");
+    g_string_append (options, x264->global_header ? ":global_header" : ":noglobal_header");
+    g_string_append (options, x264->cabac ? ":cabac" : ":nocabac");
 
-    if (trellis)
-      g_string_append_printf (options, ":psy-rd=%s,%s", psy_rd, psy_trellis);
+    if (x264_have_weight_p)
+      g_string_append_printf (options, ":weightp=%d", CLAMP (x264->weight_p, 0, 2));
+
+    if (x264_have_8x8dct)
+      g_string_append (options, x264->x88dct ? ":8x8dct" : ":no8x8dct");
+
+    if (x264_have_mixed_refs)
+      g_string_append (options, x264->mixed_refs ? ":mixed_refs" : ":nomixed_refs");
+
+    if (x264->level_idc > 0)
+      g_string_append_printf (options, ":level_idc=%d", CLAMP (x264->level_idc, 10, 51));
+
+    if (x264_have_b_pyramid)
+      g_string_append_printf (options, ":b_pyramid=%s", b_pyramid_name[CLAMP (x264->b_pyramid, B_PYRAMID_NONE, B_PYRAMID_NORMAL)]);
     else
-      g_string_append_printf (options, ":psy-rd=%s", psy_rd);
+      g_string_append (options, x264->b_pyramid ? ":b_pyramid" : ":nob_pyramid");
+
+    if (x264->vbv_maxrate > 0 && x264->vbv_bufsize > 0)
+      g_string_append_printf (options, ":vbv_maxrate=%d:vbv_bufsize=%d",
+          x264->vbv_maxrate, x264->vbv_bufsize);
+
+    if (ogmrip_video_codec_get_4mv (video))
+      g_string_append (options, x264_have_partitions ? ":partitions=all" : ":4x4mv");
+    else if (x264_have_partitions)
+      g_string_append (options, ":partitions=none");
+
+    if (x264_have_bime && bframes > 0)
+      g_string_append (options, ":bime");
+
+    if (x264_have_psy && x264->subq >= 6)
+    {
+      gchar psy_rd[G_ASCII_DTOSTR_BUF_SIZE], psy_trellis[G_ASCII_DTOSTR_BUF_SIZE];
+
+      g_ascii_formatd (psy_rd, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", cartoon ? 0.4 : x264->psy_rd);
+      g_ascii_formatd (psy_trellis, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", cartoon ? 0 : x264->psy_trellis);
+
+      if (trellis)
+        g_string_append_printf (options, ":psy-rd=%s,%s", psy_rd, psy_trellis);
+      else
+        g_string_append_printf (options, ":psy-rd=%s", psy_rd);
+    }
+
+    if (x264_have_aud && x264->aud)
+      g_string_append (options, ":aud");
   }
 
-  if (x264_have_aud && x264->aud)
-    g_string_append (options, ":aud");
-
-  if (x264_have_lookahead)
-    g_string_append_printf (options, ":rc_lookahead=%u", x264->rc_lookahead);
-
   bitrate = ogmrip_video_codec_get_bitrate (video);
   if (bitrate > 0)
     g_string_append_printf (options, ":bitrate=%u", bitrate / 1000);
@@ -391,28 +432,35 @@ ogmrip_x264_class_init (OGMRipX264Class *klass)
       g_param_spec_boolean (OGMRIP_X264_PROP_8X8DCT,
         "8x8 dct property", "Set 8x8 dct", OGMRIP_X264_DEFAULT_8X8DCT, G_PARAM_READWRITE));
 
-  if (x264_have_aud)
-    g_object_class_install_property (gobject_class, PROP_AUD,
-        g_param_spec_boolean (OGMRIP_X264_PROP_AUD,
-          "Aud property", "Set aud", OGMRIP_X264_DEFAULT_AUD, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_AUD,
+      g_param_spec_boolean (OGMRIP_X264_PROP_AUD,
+        "Aud property", "Set aud", OGMRIP_X264_DEFAULT_AUD, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_B_ADAPT,
       g_param_spec_uint (OGMRIP_X264_PROP_B_ADAPT,
         "B adapt", "Set b adapt", 0, 2, OGMRIP_X264_DEFAULT_B_ADAPT, G_PARAM_READWRITE));
 
-  g_object_class_install_property (gobject_class, PROP_B_PYRAMID,
-      g_param_spec_boolean (OGMRIP_X264_PROP_B_PYRAMID,
-        "B pyramid property", "Set b pyramid", OGMRIP_X264_DEFAULT_B_PYRAMID, G_PARAM_READWRITE));
+  if (x264_have_b_pyramid)
+    g_object_class_install_property (gobject_class, PROP_B_PYRAMID,
+        g_param_spec_uint (OGMRIP_X264_PROP_B_PYRAMID,
+          "B pyramid property", "Set b pyramid", B_PYRAMID_NONE, B_PYRAMID_NORMAL, OGMRIP_X264_DEFAULT_B_PYRAMID, G_PARAM_READWRITE));
+  else
+    g_object_class_install_property (gobject_class, PROP_B_PYRAMID,
+        g_param_spec_uint (OGMRIP_X264_PROP_B_PYRAMID,
+          "B pyramid property", "Set b pyramid", B_PYRAMID_NONE, B_PYRAMID_STRICT, x264_have_b_pyramid ? OGMRIP_X264_DEFAULT_B_PYRAMID : TRUE, G_PARAM_READWRITE));
 
-  if (x264_have_brdo)
-    g_object_class_install_property (gobject_class, PROP_BRDO,
-        g_param_spec_boolean (OGMRIP_X264_PROP_BRDO,
-          "Brdo property", "Set brdo", OGMRIP_X264_DEFAULT_BRDO, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_BRDO,
+      g_param_spec_boolean (OGMRIP_X264_PROP_BRDO,
+        "Brdo property", "Set brdo", OGMRIP_X264_DEFAULT_BRDO, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_CABAC,
       g_param_spec_boolean (OGMRIP_X264_PROP_CABAC,
         "Cabac property", "Set cabac", OGMRIP_X264_DEFAULT_CABAC, G_PARAM_READWRITE));
 
+  g_object_class_install_property (gobject_class, PROP_CQM,
+      g_param_spec_uint (OGMRIP_X264_PROP_CQM,
+        "Cqm property", "Set cqm", 0, 1, OGMRIP_X264_DEFAULT_CQM, G_PARAM_READWRITE));
+
   g_object_class_install_property (gobject_class, PROP_DIRECT,
       g_param_spec_uint (OGMRIP_X264_PROP_DIRECT,
         "Direct property", "Set direct", DIRECT_NONE, DIRECT_AUTO, OGMRIP_X264_DEFAULT_DIRECT, G_PARAM_READWRITE));
@@ -425,13 +473,18 @@ ogmrip_x264_class_init (OGMRipX264Class *klass)
       g_param_spec_boolean (OGMRIP_X264_PROP_GLOBAL_HEADER,
         "global header property", "Set global header", OGMRIP_X264_DEFAULT_GLOBAL_HEADER, G_PARAM_READWRITE));
 
+  g_object_class_install_property (gobject_class, PROP_KEYINT,
+      g_param_spec_uint (OGMRIP_X264_PROP_KEYINT,
+        "Keyint property", "Set keyint", 0, G_MAXUINT, OGMRIP_X264_DEFAULT_KEYINT, G_PARAM_READWRITE));
+
   g_object_class_install_property (gobject_class, PROP_LEVEL_IDC,
       g_param_spec_uint (OGMRIP_X264_PROP_LEVEL_IDC,
         "Level IDC property", "Set level IDC", 0, 51, OGMRIP_X264_DEFAULT_LEVEL_IDC, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_ME,
       g_param_spec_uint (OGMRIP_X264_PROP_ME,
-        "Motion estimation property", "Set motion estimation", ME_DIA, x264_have_me_tesa ? ME_TESA : ME_ESA, OGMRIP_X264_DEFAULT_ME, G_PARAM_READWRITE));
+        "Motion estimation property", "Set motion estimation", ME_DIA,
+        x264_have_me_tesa ? ME_TESA : ME_ESA, OGMRIP_X264_DEFAULT_ME, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MERANGE,
       g_param_spec_uint (OGMRIP_X264_PROP_MERANGE,
@@ -441,16 +494,13 @@ ogmrip_x264_class_init (OGMRipX264Class *klass)
       g_param_spec_boolean (OGMRIP_X264_PROP_MIXED_REFS,
         "Mixed refs property", "Set mixed refs", OGMRIP_X264_DEFAULT_MIXED_REFS, G_PARAM_READWRITE));
 
-  if (x264_have_psy)
-  {
-    g_object_class_install_property (gobject_class, PROP_PSY_RD,
-        g_param_spec_double (OGMRIP_X264_PROP_PSY_RD,
-          "Psy RD property", "Set psy-rd", 0.0, G_MAXDOUBLE, OGMRIP_X264_DEFAULT_PSY_RD, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_PSY_RD,
+      g_param_spec_double (OGMRIP_X264_PROP_PSY_RD,
+        "Psy RD property", "Set psy-rd", 0.0, G_MAXDOUBLE, OGMRIP_X264_DEFAULT_PSY_RD, G_PARAM_READWRITE));
 
-    g_object_class_install_property (gobject_class, PROP_PSY_TRELLIS,
-        g_param_spec_double (OGMRIP_X264_PROP_PSY_TRELLIS,
-          "Psy trellis property", "Set psy-trellis", 0.0, G_MAXDOUBLE, OGMRIP_X264_DEFAULT_PSY_TRELLIS, G_PARAM_READWRITE));
-  }
+  g_object_class_install_property (gobject_class, PROP_PSY_TRELLIS,
+      g_param_spec_double (OGMRIP_X264_PROP_PSY_TRELLIS,
+        "Psy trellis property", "Set psy-trellis", 0.0, G_MAXDOUBLE, OGMRIP_X264_DEFAULT_PSY_TRELLIS, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_RC_LOOKAHEAD,
       g_param_spec_uint (OGMRIP_X264_PROP_RC_LOOKAHEAD,
@@ -471,6 +521,10 @@ ogmrip_x264_class_init (OGMRipX264Class *klass)
   g_object_class_install_property (gobject_class, PROP_WEIGHT_B,
       g_param_spec_boolean (OGMRIP_X264_PROP_WEIGHT_B,
         "Weight B property", "Set weight B", OGMRIP_X264_DEFAULT_WEIGHT_B, G_PARAM_READWRITE));
+
+  g_object_class_install_property (gobject_class, PROP_WEIGHT_P,
+      g_param_spec_uint (OGMRIP_X264_PROP_WEIGHT_P,
+        "Weight P property", "Set weight P", 0, 2, OGMRIP_X264_DEFAULT_WEIGHT_P, G_PARAM_READWRITE));
 }
 
 static void
@@ -481,9 +535,11 @@ ogmrip_x264_init (OGMRipX264 *x264)
   x264->b_pyramid = OGMRIP_X264_DEFAULT_B_PYRAMID;
   x264->brdo = OGMRIP_X264_DEFAULT_BRDO;
   x264->cabac = OGMRIP_X264_DEFAULT_CABAC;
+  x264->cqm = OGMRIP_X264_DEFAULT_CQM;
   x264->direct = OGMRIP_X264_DEFAULT_DIRECT;
   x264->frameref = OGMRIP_X264_DEFAULT_FRAMEREF;
   x264->global_header = OGMRIP_X264_DEFAULT_GLOBAL_HEADER;
+  x264->keyint = OGMRIP_X264_DEFAULT_KEYINT;
   x264->level_idc = OGMRIP_X264_DEFAULT_LEVEL_IDC;
   x264->me = OGMRIP_X264_DEFAULT_ME;
   x264->merange = OGMRIP_X264_DEFAULT_MERANGE;
@@ -495,6 +551,7 @@ ogmrip_x264_init (OGMRipX264 *x264)
   x264->vbv_bufsize = OGMRIP_X264_DEFAULT_VBV_BUFSIZE;
   x264->vbv_maxrate = OGMRIP_X264_DEFAULT_VBV_MAXRATE;
   x264->weight_b = OGMRIP_X264_DEFAULT_WEIGHT_B;
+  x264->weight_p = OGMRIP_X264_DEFAULT_WEIGHT_P;
   x264->x88dct = OGMRIP_X264_DEFAULT_8X8DCT;
 }
 
@@ -517,7 +574,7 @@ ogmrip_x264_get_property (GObject *gobject, guint property_id, GValue *value, GP
       g_value_set_uint (value, x264->b_adapt);
       break;
     case PROP_B_PYRAMID:
-      g_value_set_boolean (value, x264->b_pyramid);
+      g_value_set_uint (value, x264->b_pyramid);
       break;
     case PROP_BRDO:
       g_value_set_boolean (value, x264->brdo);
@@ -525,6 +582,9 @@ ogmrip_x264_get_property (GObject *gobject, guint property_id, GValue *value, GP
     case PROP_CABAC:
       g_value_set_boolean (value, x264->cabac);
       break;
+    case PROP_CQM:
+      g_value_set_uint (value, x264->cqm);
+      break;
     case PROP_DIRECT:
       g_value_set_uint (value, x264->direct);
       break;
@@ -534,6 +594,9 @@ ogmrip_x264_get_property (GObject *gobject, guint property_id, GValue *value, GP
     case PROP_GLOBAL_HEADER:
       g_value_set_boolean (value, x264->global_header);
       break;
+    case PROP_KEYINT:
+      g_value_set_uint (value, x264->keyint);
+      break;
     case PROP_LEVEL_IDC:
       g_value_set_uint (value, x264->level_idc);
       break;
@@ -567,6 +630,9 @@ ogmrip_x264_get_property (GObject *gobject, guint property_id, GValue *value, GP
     case PROP_WEIGHT_B:
       g_value_set_boolean (value, x264->weight_b);
       break;
+    case PROP_WEIGHT_P:
+      g_value_set_uint (value, x264->weight_p);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
@@ -592,7 +658,7 @@ ogmrip_x264_set_property (GObject *gobject, guint property_id, const GValue *val
       x264->b_adapt = g_value_get_uint (value);
       break;
     case PROP_B_PYRAMID:
-      x264->b_pyramid = g_value_get_boolean (value);
+      x264->b_pyramid = g_value_get_uint (value);
       break;
     case PROP_BRDO:
       x264->brdo = g_value_get_boolean (value);
@@ -600,6 +666,9 @@ ogmrip_x264_set_property (GObject *gobject, guint property_id, const GValue *val
     case PROP_CABAC:
       x264->cabac = g_value_get_boolean (value);
       break;
+    case PROP_CQM:
+      x264->cqm = g_value_get_uint (value);
+      break;
     case PROP_DIRECT:
       x264->direct = g_value_get_uint (value);
       break;
@@ -609,6 +678,9 @@ ogmrip_x264_set_property (GObject *gobject, guint property_id, const GValue *val
     case PROP_GLOBAL_HEADER:
       x264->global_header = g_value_get_boolean (value);
       break;
+    case PROP_KEYINT:
+      x264->keyint = g_value_get_uint (value);
+      break;
     case PROP_LEVEL_IDC:
       x264->level_idc = g_value_get_uint (value);
       break;
@@ -642,6 +714,9 @@ ogmrip_x264_set_property (GObject *gobject, guint property_id, const GValue *val
     case PROP_WEIGHT_B:
       x264->weight_b = g_value_get_boolean (value);
       break;
+    case PROP_WEIGHT_P:
+      x264->weight_p = g_value_get_uint (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
@@ -652,7 +727,7 @@ static gint
 ogmrip_x264_run (OGMJobSpawn *spawn)
 {
   OGMJobSpawn *queue, *child;
-  gchar **argv, *log_file;
+  gchar **argv, *log_file, *mbtree_file;
   gint pass, passes, result;
 
   queue = ogmjob_queue_new ();
@@ -681,6 +756,11 @@ ogmrip_x264_run (OGMJobSpawn *spawn)
 
   ogmjob_container_remove (OGMJOB_CONTAINER (spawn), queue);
 
+  mbtree_file = g_strconcat (log_file, ".mbtree", NULL);
+  if (g_file_test (mbtree_file, G_FILE_TEST_EXISTS))
+    g_unlink (mbtree_file);
+  g_free (mbtree_file);
+
   g_unlink (log_file);
   g_free (log_file);
 
@@ -755,27 +835,31 @@ static gboolean
 ogmrip_x264_check_option (const gchar *option)
 {
   GPtrArray *argv;
-  gint status = 1;
+  gchar *options;
+  gint status;
 
   argv = g_ptr_array_new ();
 
-  g_ptr_array_add (argv, g_strdup ("mencoder"));
-  g_ptr_array_add (argv, g_strdup ("-nocache"));
-  g_ptr_array_add (argv, g_strdup ("-nosound"));
-  g_ptr_array_add (argv, g_strdup ("-really-quiet"));
-  g_ptr_array_add (argv, g_strdup ("-frames"));
-  g_ptr_array_add (argv, g_strdup ("0"));
-  g_ptr_array_add (argv, g_strdup ("-rawvideo"));
-  g_ptr_array_add (argv, g_strdup ("pal:fps=25"));
-  g_ptr_array_add (argv, g_strdup ("-demuxer"));
-  g_ptr_array_add (argv, g_strdup ("rawvideo"));
-  g_ptr_array_add (argv, g_strdup ("-o"));
-  g_ptr_array_add (argv, g_strdup ("/dev/null"));
-  g_ptr_array_add (argv, g_strdup ("-ovc"));
-  g_ptr_array_add (argv, g_strdup ("x264"));
-  g_ptr_array_add (argv, g_strdup ("-x264encopts"));
-  g_ptr_array_add (argv, g_strdup_printf ("%s:bitrate=800:threads=1", option));
-  g_ptr_array_add (argv, g_strdup ("/dev/zero"));
+  g_ptr_array_add (argv, "mencoder");
+  g_ptr_array_add (argv, "-nocache");
+  g_ptr_array_add (argv, "-nosound");
+  g_ptr_array_add (argv, "-really-quiet");
+  g_ptr_array_add (argv, "-frames");
+  g_ptr_array_add (argv, "0");
+  g_ptr_array_add (argv, "-rawvideo");
+  g_ptr_array_add (argv, "pal:fps=25");
+  g_ptr_array_add (argv, "-demuxer");
+  g_ptr_array_add (argv, "rawvideo");
+  g_ptr_array_add (argv, "-o");
+  g_ptr_array_add (argv, "/dev/null");
+  g_ptr_array_add (argv, "-ovc");
+  g_ptr_array_add (argv, "x264");
+  g_ptr_array_add (argv, "-x264encopts");
+
+  options = g_strdup_printf ("%s:bitrate=800:threads=1", option);
+  g_ptr_array_add (argv, options);
+
+  g_ptr_array_add (argv, "/dev/zero");
   g_ptr_array_add (argv, NULL);
 
   g_spawn_sync (NULL, (gchar **) argv->pdata, NULL,
@@ -784,8 +868,9 @@ ogmrip_x264_check_option (const gchar *option)
   
   g_ptr_array_free (argv, TRUE);
 
-  return status == 0;
+  g_free (options);
 
+  return status == 0;
 }
 
 static void
@@ -805,31 +890,6 @@ ogmrip_x264_set_options (OGMRipCodec *codec, const gchar *section)
       ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), properties[i], section, key);
       g_free (key);
     }
-
-    if (x264_have_brdo)
-    {
-      key = ogmrip_settings_build_section (settings, OGMRIP_X264_SECTION, OGMRIP_X264_PROP_BRDO, NULL);
-      ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), OGMRIP_X264_PROP_BRDO, section, key);
-      g_free (key);
-    }
-
-    if (x264_have_psy)
-    {
-      key = ogmrip_settings_build_section (settings, OGMRIP_X264_SECTION, OGMRIP_X264_PROP_PSY_RD, NULL);
-      ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), OGMRIP_X264_PROP_PSY_RD, section, key);
-      g_free (key);
-
-      key = ogmrip_settings_build_section (settings, OGMRIP_X264_SECTION, OGMRIP_X264_PROP_PSY_TRELLIS, NULL);
-      ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), OGMRIP_X264_PROP_PSY_TRELLIS, section, key);
-      g_free (key);
-    }
-
-    if (x264_have_aud)
-    {
-      key = ogmrip_settings_build_section (settings, OGMRIP_X264_SECTION, OGMRIP_X264_PROP_AUD, NULL);
-      ogmrip_settings_set_property_from_key (settings, G_OBJECT (codec), OGMRIP_X264_PROP_AUD, section, key);
-      g_free (key);
-    }
   }
 }
 
@@ -861,12 +921,19 @@ ogmrip_init_plugin (GError **error)
     return NULL;
   }
 
-  x264_have_brdo      = ogmrip_x264_check_option ("brdo");
-  x264_have_bime      = ogmrip_x264_check_option ("bime");
-  x264_have_psy       = ogmrip_x264_check_option ("psy-rd=1,1");
-  x264_have_aud       = ogmrip_x264_check_option ("aud");
-  x264_have_lookahead = ogmrip_x264_check_option ("rc_lookahead=40");
-  x264_have_me_tesa   = ogmrip_x264_check_option ("me=tesa");
+  x264_have_8x8dct     = ogmrip_x264_check_option ("8x8dct");
+  x264_have_aud        = ogmrip_x264_check_option ("aud");
+  x264_have_bime       = ogmrip_x264_check_option ("bime");
+  x264_have_b_pyramid  = ogmrip_x264_check_option ("b_pyramid=none");
+  x264_have_brdo       = ogmrip_x264_check_option ("brdo");
+  x264_have_lookahead  = ogmrip_x264_check_option ("rc_lookahead=40");
+  x264_have_me         = ogmrip_x264_check_option ("me=hex");
+  x264_have_me_tesa    = ogmrip_x264_check_option ("me=tesa");
+  x264_have_mixed_refs = ogmrip_x264_check_option ("mixed_refs");
+  x264_have_partitions = ogmrip_x264_check_option ("partitions=all");
+  x264_have_psy        = ogmrip_x264_check_option ("psy-rd=1,1");
+  x264_have_turbo      = ogmrip_x264_check_option ("turbo=2");
+  x264_have_weight_p   = ogmrip_x264_check_option ("weightp=2");
 
   settings = ogmrip_settings_get_default ();
   if (settings)
@@ -880,15 +947,6 @@ ogmrip_init_plugin (GError **error)
       ogmrip_settings_install_key_from_property (settings, klass,
           OGMRIP_X264_SECTION, properties[i], properties[i]);
 
-    ogmrip_settings_install_key_from_property (settings, klass,
-        OGMRIP_X264_SECTION, OGMRIP_X264_PROP_BRDO, OGMRIP_X264_PROP_BRDO);
-    ogmrip_settings_install_key_from_property (settings, klass,
-        OGMRIP_X264_SECTION, OGMRIP_X264_PROP_PSY_RD, OGMRIP_X264_PROP_PSY_RD);
-    ogmrip_settings_install_key_from_property (settings, klass,
-        OGMRIP_X264_SECTION, OGMRIP_X264_PROP_PSY_TRELLIS, OGMRIP_X264_PROP_PSY_TRELLIS);
-    ogmrip_settings_install_key_from_property (settings, klass,
-        OGMRIP_X264_SECTION, OGMRIP_X264_PROP_AUD, OGMRIP_X264_PROP_AUD);
-
     g_type_class_unref (klass);
   }
 
