@@ -47,31 +47,31 @@ struct _OGMRipXvid
 {
   OGMRipVideoCodec parent_instance;
   
-  gint profile;
-  gint quant_type;
+  gboolean b_adapt;
+  gboolean chroma_me;
+  gboolean chroma_opt;
+  gboolean closed_gop;
   gboolean gmc;
   gboolean interlacing;
-  gboolean b_adapt;
-  gint min_iquant;
-  gint max_iquant;
-  gint min_pquant;
-  gint max_pquant;
-  gint min_bquant;
-  gint max_bquant;
-  gboolean chroma_opt;
-  gboolean chroma_me;
-  gint me_quality;
-  gint vhq;
-  gint bvhq;
-  gboolean cartoon;
-  gint frame_drop_ratio;
   gboolean packed;
-  gboolean closed_gop;
-  gint bquant_ratio;
   gint bquant_offset;
+  gint bquant_ratio;
+  gint bvhq;
+  gint frame_drop_ratio;
+  gint max_bquant;
+  gint max_iquant;
+  gint max_pquant;
+  gint me_quality;
+  gint min_bquant;
+  gint min_iquant;
+  gint min_pquant;
+  gint max_keyint;
   gint par;
-  gint par_width;
   gint par_height;
+  gint par_width;
+  gint profile;
+  gint quant_type;
+  gint vhq;
 };
 
 struct _OGMRipXvidClass
@@ -82,31 +82,31 @@ struct _OGMRipXvidClass
 enum
 {
   PROP_0,
-  PROP_PROFILE,
-  PROP_QUANT_TYPE,
+  PROP_B_ADAPT,
+  PROP_BQUANT_OFFSET,
+  PROP_BQUANT_RATIO,
+  PROP_BVHQ,
+  PROP_CHROMA_ME,
+  PROP_CHROMA_OPT,
+  PROP_CLOSED_GOP,
+  PROP_FRAME_DROP_RATIO,
   PROP_GMC,
   PROP_INTERLACING,
-  PROP_B_ADAPT,
-  PROP_MIN_IQUANT,
-  PROP_MAX_IQUANT,
-  PROP_MIN_PQUANT,
-  PROP_MAX_PQUANT,
-  PROP_MIN_BQUANT,
   PROP_MAX_BQUANT,
-  PROP_CHROMA_OPT,
-  PROP_CHROMA_ME,
+  PROP_MAX_IQUANT,
+  PROP_MAX_PQUANT,
   PROP_ME_QUALITY,
-  PROP_VHQ,
-  PROP_BVHQ,
-  PROP_CARTOON,
-  PROP_FRAME_DROP_RATIO,
+  PROP_MIN_BQUANT,
+  PROP_MIN_IQUANT,
+  PROP_MIN_PQUANT,
+  PROP_MAX_KEYINT,
   PROP_PACKED,
-  PROP_CLOSED_GOP,
-  PROP_BQUANT_RATIO,
-  PROP_BQUANT_OFFSET,
   PROP_PAR,
+  PROP_PAR_HEIGHT,
   PROP_PAR_WIDTH,
-  PROP_PAR_HEIGHT
+  PROP_PROFILE,
+  PROP_QUANT_TYPE,
+  PROP_VHQ
 };
 
 static gint ogmrip_xvid_run             (OGMJobSpawn       *spawn);
@@ -125,32 +125,37 @@ static void ogmrip_xvid_set_options     (OGMRipCodec       *codec,
 
 static const gchar * const properties[] =
 {
-  OGMRIP_XVID_PROP_PROFILE,
-  OGMRIP_XVID_PROP_QUANT_TYPE,
-  OGMRIP_XVID_PROP_ME_QUALITY,
-  OGMRIP_XVID_PROP_VHQ,
-  OGMRIP_XVID_PROP_PAR,
+  OGMRIP_XVID_PROP_B_ADAPT,
+  OGMRIP_XVID_PROP_BFRAMES,
+  OGMRIP_XVID_PROP_BQUANT_OFFSET,
+  OGMRIP_XVID_PROP_BQUANT_RATIO,
+  OGMRIP_XVID_PROP_BVHQ,
+  OGMRIP_XVID_PROP_CHROMA_ME,
+  OGMRIP_XVID_PROP_CHROMA_OPT,
+  OGMRIP_XVID_PROP_CLOSED_GOP,
+  OGMRIP_XVID_PROP_FRAME_DROP_RATIO,
   OGMRIP_XVID_PROP_GMC,
   OGMRIP_XVID_PROP_INTERLACING,
-  OGMRIP_XVID_PROP_B_ADAPT,
-  OGMRIP_XVID_PROP_CARTOON,
-  OGMRIP_XVID_PROP_PACKED,
-  OGMRIP_XVID_PROP_CLOSED_GOP,
-  OGMRIP_XVID_PROP_MIN_IQUANT,
-  OGMRIP_XVID_PROP_MAX_IQUANT,
-  OGMRIP_XVID_PROP_MIN_PQUANT,
-  OGMRIP_XVID_PROP_MAX_PQUANT,
-  OGMRIP_XVID_PROP_MIN_BQUANT,
   OGMRIP_XVID_PROP_MAX_BQUANT,
-  OGMRIP_XVID_PROP_FRAME_DROP_RATIO,
-  OGMRIP_XVID_PROP_BQUANT_RATIO,
-  OGMRIP_XVID_PROP_BQUANT_OFFSET,
-  OGMRIP_XVID_PROP_PAR_WIDTH,
+  OGMRIP_XVID_PROP_MAX_IQUANT,
+  OGMRIP_XVID_PROP_MAX_PQUANT,
+  OGMRIP_XVID_PROP_ME_QUALITY,
+  OGMRIP_XVID_PROP_MIN_BQUANT,
+  OGMRIP_XVID_PROP_MIN_IQUANT,
+  OGMRIP_XVID_PROP_MIN_PQUANT,
+  OGMRIP_XVID_PROP_MAX_KEYINT,
+  OGMRIP_XVID_PROP_PACKED,
+  OGMRIP_XVID_PROP_PAR,
   OGMRIP_XVID_PROP_PAR_HEIGHT,
-  OGMRIP_XVID_PROP_BFRAMES,
+  OGMRIP_XVID_PROP_PAR_WIDTH,
+  OGMRIP_XVID_PROP_PROFILE,
+  OGMRIP_XVID_PROP_QUANT_TYPE,
+  OGMRIP_XVID_PROP_VHQ,
   NULL
 };
 
+gboolean xvid_have_b_adapt = FALSE;
+
 static gdouble
 ogmrip_xvid_get_quantizer (OGMRipVideoCodec *video)
 {
@@ -251,15 +256,19 @@ ogmrip_xvid_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
       g_string_append (options, ":interlacing");
     else
       g_string_append (options, ":nointerlacing");
-/*
-    if (xvid->b_adapt)
-      g_string_append (options, ":b_adapt");
-    else
-      g_string_append (options, ":nob_adapt");
-*/
+
+    if (xvid_have_b_adapt)
+    {
+      if (xvid->b_adapt)
+        g_string_append (options, ":b_adapt");
+      else
+        g_string_append (options, ":nob_adapt");
+    }
+
     g_string_append_printf (options, ":min_iquant=%u:max_iquant=%u", xvid->min_iquant, xvid->max_iquant);
     g_string_append_printf (options, ":min_pquant=%u:max_pquant=%u", xvid->min_pquant, xvid->max_pquant);
     g_string_append_printf (options, ":min_bquant=%u:max_bquant=%u", xvid->min_bquant, xvid->max_bquant);
+    g_string_append_printf (options, ":max_key_interval=%u", xvid->max_keyint);
 
     if (xvid->chroma_me)
       g_string_append (options, ":chroma_me");
@@ -298,7 +307,7 @@ ogmrip_xvid_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
         g_string_append_printf (options, ":par_width=%d:par_height=%d", xvid->par_width, xvid->par_height);
     }
 
-    if (!xvid->b_adapt)
+    if (!xvid_have_b_adapt || !xvid->b_adapt)
       g_string_append_printf (options, ":max_bframes=%d", bframes);
 
     if (bframes == 0)
@@ -398,108 +407,133 @@ ogmrip_xvid_class_init (OGMRipXvidClass *klass)
 
   g_object_class_install_property (gobject_class, PROP_PROFILE,
       g_param_spec_int (OGMRIP_XVID_PROP_PROFILE,
-        "Profile property", "Set profile", 0, 16, 0, G_PARAM_READWRITE));
+        "Profile property", "Set profile", 0, 16, OGMRIP_XVID_DEFAULT_PROFILE, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_QUANT_TYPE,
       g_param_spec_int (OGMRIP_XVID_PROP_QUANT_TYPE,
-        NULL, NULL, 0, 1, 0, G_PARAM_READWRITE));
+        NULL, NULL, 0, 1, OGMRIP_XVID_DEFAULT_QUANT_TYPE, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_ME_QUALITY,
       g_param_spec_int (OGMRIP_XVID_PROP_ME_QUALITY,
-        NULL, NULL, 0, 6, 6, G_PARAM_READWRITE));
+        NULL, NULL, 0, 6, OGMRIP_XVID_DEFAULT_ME_QUALITY, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_VHQ,
       g_param_spec_int (OGMRIP_XVID_PROP_VHQ,
-        NULL, NULL, 0, 4, 1, G_PARAM_READWRITE));
+        NULL, NULL, 0, 4, OGMRIP_XVID_DEFAULT_VHQ, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_BVHQ,
       g_param_spec_int (OGMRIP_XVID_PROP_BVHQ,
-        NULL, NULL, 0, 1, 1, G_PARAM_READWRITE));
+        NULL, NULL, 0, 1, OGMRIP_XVID_DEFAULT_BVHQ, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_PAR,
       g_param_spec_int (OGMRIP_XVID_PROP_PAR,
-        NULL, NULL, 0, 6, 0, G_PARAM_READWRITE));
+        NULL, NULL, 0, 6, OGMRIP_XVID_DEFAULT_PAR, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MIN_IQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MIN_IQUANT,
-        NULL, NULL, 0, 31, 2, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MIN_IQUANT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MAX_IQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MAX_IQUANT,
-        NULL, NULL, 0, 31, 31, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MAX_IQUANT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MIN_PQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MIN_PQUANT,
-        NULL, NULL, 0, 31, 2, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MIN_PQUANT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MAX_PQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MAX_PQUANT,
-        NULL, NULL, 0, 31, 31, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MAX_PQUANT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MIN_BQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MIN_BQUANT,
-        NULL, NULL, 0, 31, 2, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MIN_BQUANT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_MAX_BQUANT,
       g_param_spec_int (OGMRIP_XVID_PROP_MAX_BQUANT,
-        NULL, NULL, 0, 31, 31, G_PARAM_READWRITE));
+        NULL, NULL, 0, 31, OGMRIP_XVID_DEFAULT_MAX_BQUANT, G_PARAM_READWRITE));
+
+    g_object_class_install_property (gobject_class, PROP_MAX_KEYINT,
+        g_param_spec_int (OGMRIP_XVID_PROP_MAX_KEYINT,
+          NULL, NULL, 0, G_MAXINT, OGMRIP_XVID_DEFAULT_MAX_KEYINT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_FRAME_DROP_RATIO,
       g_param_spec_int (OGMRIP_XVID_PROP_FRAME_DROP_RATIO,
-        NULL, NULL, 0, 100, 0, G_PARAM_READWRITE));
+        NULL, NULL, 0, 100, OGMRIP_XVID_DEFAULT_FRAME_DROP_RATIO, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_BQUANT_RATIO,
       g_param_spec_int (OGMRIP_XVID_PROP_BQUANT_RATIO,
-        NULL, NULL, 0, 1000, 150, G_PARAM_READWRITE));
+        NULL, NULL, 0, 1000, OGMRIP_XVID_DEFAULT_BQUANT_RATIO, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_BQUANT_OFFSET,
       g_param_spec_int (OGMRIP_XVID_PROP_BQUANT_OFFSET,
-        NULL, NULL, -1000, 1000, 100, G_PARAM_READWRITE));
+        NULL, NULL, -1000, 1000, OGMRIP_XVID_DEFAULT_BQUANT_OFFSET, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_PAR_WIDTH,
       g_param_spec_int (OGMRIP_XVID_PROP_PAR_WIDTH,
-        NULL, NULL, 1, 255, 1, G_PARAM_READWRITE));
+        NULL, NULL, 1, 255, OGMRIP_XVID_DEFAULT_PAR_WIDTH, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_PAR_HEIGHT,
       g_param_spec_int (OGMRIP_XVID_PROP_PAR_HEIGHT,
-        NULL, NULL, 1, 255, 1, G_PARAM_READWRITE));
+        NULL, NULL, 1, 255, OGMRIP_XVID_DEFAULT_PAR_HEIGHT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_GMC,
       g_param_spec_boolean (OGMRIP_XVID_PROP_GMC,
-        NULL, NULL, FALSE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_GMC, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_INTERLACING,
       g_param_spec_boolean (OGMRIP_XVID_PROP_INTERLACING,
-        NULL, NULL, FALSE, G_PARAM_READWRITE));
-
-  g_object_class_install_property (gobject_class, PROP_B_ADAPT,
-      g_param_spec_boolean (OGMRIP_XVID_PROP_B_ADAPT,
-        NULL, NULL, TRUE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_INTERLACING, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_CHROMA_ME,
       g_param_spec_boolean (OGMRIP_XVID_PROP_CHROMA_ME,
-        NULL, NULL, TRUE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_CHROMA_ME, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_CHROMA_OPT,
       g_param_spec_boolean (OGMRIP_XVID_PROP_CHROMA_OPT,
-        NULL, NULL, TRUE, G_PARAM_READWRITE));
-
-  g_object_class_install_property (gobject_class, PROP_CARTOON,
-      g_param_spec_boolean (OGMRIP_XVID_PROP_CARTOON,
-        NULL, NULL, FALSE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_CHROMA_OPT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_PACKED,
       g_param_spec_boolean (OGMRIP_XVID_PROP_PACKED,
-        NULL, NULL, FALSE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_PACKED, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_CLOSED_GOP,
       g_param_spec_boolean (OGMRIP_XVID_PROP_CLOSED_GOP,
-        NULL, NULL, TRUE, G_PARAM_READWRITE));
+        NULL, NULL, OGMRIP_XVID_DEFAULT_CLOSED_GOP, G_PARAM_READWRITE));
+
+  g_object_class_install_property (gobject_class, PROP_B_ADAPT,
+      g_param_spec_boolean (OGMRIP_XVID_PROP_B_ADAPT,
+        NULL, NULL, OGMRIP_XVID_DEFAULT_B_ADAPT, G_PARAM_READWRITE));
 }
 
 static void
 ogmrip_xvid_init (OGMRipXvid *xvid)
 {
+  xvid->b_adapt = OGMRIP_XVID_DEFAULT_B_ADAPT;
+  xvid->chroma_me = OGMRIP_XVID_DEFAULT_CHROMA_ME;
+  xvid->chroma_opt = OGMRIP_XVID_DEFAULT_CHROMA_OPT;
+  xvid->closed_gop = OGMRIP_XVID_DEFAULT_CLOSED_GOP;
+  xvid->gmc = OGMRIP_XVID_DEFAULT_GMC;
+  xvid->interlacing = OGMRIP_XVID_DEFAULT_INTERLACING;
+  xvid->packed = OGMRIP_XVID_DEFAULT_PACKED;
+  xvid->bquant_offset = OGMRIP_XVID_DEFAULT_BQUANT_OFFSET;
+  xvid->bquant_ratio = OGMRIP_XVID_DEFAULT_BQUANT_RATIO;
+  xvid->bvhq = OGMRIP_XVID_DEFAULT_BVHQ;
+  xvid->frame_drop_ratio = OGMRIP_XVID_DEFAULT_FRAME_DROP_RATIO;
+  xvid->max_bquant = OGMRIP_XVID_DEFAULT_MAX_BQUANT;
+  xvid->max_iquant = OGMRIP_XVID_DEFAULT_MAX_IQUANT;
+  xvid->max_pquant = OGMRIP_XVID_DEFAULT_MAX_PQUANT;
+  xvid->me_quality = OGMRIP_XVID_DEFAULT_ME_QUALITY;
+  xvid->min_bquant = OGMRIP_XVID_DEFAULT_MIN_BQUANT;
+  xvid->min_iquant = OGMRIP_XVID_DEFAULT_MIN_IQUANT;
+  xvid->min_pquant = OGMRIP_XVID_DEFAULT_MIN_PQUANT;
+  xvid->max_keyint = OGMRIP_XVID_DEFAULT_MAX_KEYINT;
+  xvid->par = OGMRIP_XVID_DEFAULT_PAR;
+  xvid->par_height = OGMRIP_XVID_DEFAULT_PAR_HEIGHT;
+  xvid->par_width = OGMRIP_XVID_DEFAULT_PAR_WIDTH;
+  xvid->profile = OGMRIP_XVID_DEFAULT_PROFILE;
+  xvid->quant_type = OGMRIP_XVID_DEFAULT_QUANT_TYPE;
+  xvid->vhq = OGMRIP_XVID_DEFAULT_VHQ;
 }
 
 static void
@@ -544,6 +578,9 @@ ogmrip_xvid_get_property (GObject *gobject, guint property_id, GValue *value, GP
     case PROP_MAX_BQUANT:
       g_value_set_int (value, xvid->min_bquant);
       break;
+    case PROP_MAX_KEYINT:
+      g_value_set_int (value, xvid->max_keyint);
+      break;
     case PROP_CHROMA_ME:
       g_value_set_boolean (value, xvid->chroma_me);
       break;
@@ -559,9 +596,6 @@ ogmrip_xvid_get_property (GObject *gobject, guint property_id, GValue *value, GP
     case PROP_BVHQ:
       g_value_set_int (value, xvid->bvhq);
       break;
-    case PROP_CARTOON:
-      g_value_set_boolean (value, xvid->cartoon);
-      break;
     case PROP_FRAME_DROP_RATIO:
       g_value_set_int (value, xvid->frame_drop_ratio);
       break;
@@ -634,6 +668,9 @@ ogmrip_xvid_set_property (GObject *gobject, guint property_id, const GValue *val
     case PROP_MAX_BQUANT:
       xvid->max_bquant = g_value_get_int (value);
       break;
+    case PROP_MAX_KEYINT:
+      xvid->max_keyint = g_value_get_int (value);
+      break;
     case PROP_CHROMA_ME:
       xvid->chroma_me = g_value_get_boolean (value);
       break;
@@ -649,9 +686,6 @@ ogmrip_xvid_set_property (GObject *gobject, guint property_id, const GValue *val
     case PROP_BVHQ:
       xvid->bvhq = g_value_get_int (value);
       break;
-    case PROP_CARTOON:
-      xvid->cartoon = g_value_get_boolean (value);
-      break;
     case PROP_FRAME_DROP_RATIO:
       xvid->frame_drop_ratio = g_value_get_int (value);
       break;
@@ -750,12 +784,23 @@ ogmrip_xvid_run (OGMJobSpawn *spawn)
   return result;
 }
 
+static void
+ogmrip_xvid_set_default_values (OGMRipXvid *xvid)
+{
+  ogmrip_xvid_init (xvid);
+
+  ogmrip_video_codec_set_trellis (OGMRIP_VIDEO_CODEC (xvid), OGMRIP_XVID_DEFAULT_TRELLIS);
+  ogmrip_video_codec_set_max_b_frames (OGMRIP_VIDEO_CODEC (xvid), OGMRIP_XVID_DEFAULT_BFRAMES);
+  ogmrip_video_codec_set_4mv (OGMRIP_VIDEO_CODEC (xvid), OGMRIP_XVID_DEFAULT_4MV);
+}
+
 static void
 ogmrip_xvid_set_quality (OGMRipVideoCodec *video, OGMRipQualityType quality)
 {
   OGMRipXvid *xvid;
 
   xvid = OGMRIP_XVID (video);
+  ogmrip_xvid_set_default_values (xvid);
 
   switch (quality)
   {
@@ -767,7 +812,7 @@ ogmrip_xvid_set_quality (OGMRipVideoCodec *video, OGMRipQualityType quality)
       break;
     case OGMRIP_QUALITY_HIGH:
       xvid->chroma_opt = TRUE;
-      xvid->quant_type = 1;
+      xvid->quant_type = 0;
       xvid->bvhq = 1;
       xvid->vhq = 2;
       break;
@@ -777,7 +822,7 @@ ogmrip_xvid_set_quality (OGMRipVideoCodec *video, OGMRipQualityType quality)
       xvid->bvhq = 0;
       xvid->vhq = 0;
       break;
-    case OGMRIP_QUALITY_USER:
+    default:
       break;
   }
 }
@@ -802,6 +847,48 @@ ogmrip_xvid_set_options (OGMRipCodec *codec, const gchar *section)
   }
 }
 
+static gboolean
+ogmrip_xvid_check_option (const gchar *option)
+{
+  GPtrArray *argv;
+  gchar *options;
+  gint status;
+
+  argv = g_ptr_array_new ();
+
+  g_ptr_array_add (argv, "mencoder");
+  g_ptr_array_add (argv, "-nocache");
+  g_ptr_array_add (argv, "-nosound");
+  g_ptr_array_add (argv, "-really-quiet");
+  g_ptr_array_add (argv, "-frames");
+  g_ptr_array_add (argv, "0");
+  g_ptr_array_add (argv, "-rawvideo");
+  g_ptr_array_add (argv, "pal:fps=25");
+  g_ptr_array_add (argv, "-demuxer");
+  g_ptr_array_add (argv, "rawvideo");
+  g_ptr_array_add (argv, "-o");
+  g_ptr_array_add (argv, "/dev/null");
+  g_ptr_array_add (argv, "-ovc");
+  g_ptr_array_add (argv, "xvid");
+  g_ptr_array_add (argv, "-xvidencopts");
+
+  options = g_strdup_printf ("%s:bitrate=800:threads=1", option);
+  g_ptr_array_add (argv, options);
+
+  g_ptr_array_add (argv, "/dev/zero");
+  g_ptr_array_add (argv, NULL);
+
+  g_spawn_sync (NULL, (gchar **) argv->pdata, NULL,
+      G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+      NULL, NULL, NULL, NULL, &status, NULL);
+
+  g_ptr_array_free (argv, TRUE);
+
+  g_free (options);
+
+  return status == 0;
+}
+
 static OGMRipVideoPlugin xvid_plugin =
 {
   NULL,
@@ -841,6 +928,8 @@ ogmrip_init_plugin (GError **error)
     return NULL;
   }
 
+  xvid_have_b_adapt  = ogmrip_xvid_check_option ("b_adapt");
+
   settings = ogmrip_settings_get_default ();
   if (settings)
   {
