@@ -24,9 +24,14 @@
 #include <ogmrip-container.h>
 #include <ogmrip-dvdcpy.h>
 #include <ogmrip-edl.h>
+#include <ogmrip-encoding.h>
+#include <ogmrip-encoding-manager.h>
 #include <ogmrip-enums.h>
 #include <ogmrip-file.h>
 #include <ogmrip-fs.h>
+#include <ogmrip-hardsub.h>
+#include <ogmrip-keyfile-settings.h>
+#include <ogmrip-player.h>
 #include <ogmrip-plugin.h>
 #include <ogmrip-subp-codec.h>
 #include <ogmrip-version.h>
