@@ -21,6 +21,8 @@
 
 #include <gtk/gtk.h>
 
+#include <ogmrip-encoding.h>
+
 G_BEGIN_DECLS
 
 #define OGMRIP_TYPE_AUDIO_OPTIONS_DIALOG            (ogmrip_audio_options_dialog_get_type ())
@@ -45,32 +47,13 @@ struct _OGMRipAudioOptionsDialogClass
   GtkDialogClass parent_class;
 };
 
-GType       ogmrip_audio_options_dialog_get_type      (void);
-GtkWidget * ogmrip_audio_options_dialog_new           (void);
+GType       ogmrip_audio_options_dialog_get_type    (void);
+GtkWidget * ogmrip_audio_options_dialog_new         (void);
 
-void        ogmrip_audio_options_dialog_set_use_defaults (OGMRipAudioOptionsDialog *dialog,
-                                                          gboolean                 use_defaults);
-gboolean    ogmrip_audio_options_dialog_get_use_defaults (OGMRipAudioOptionsDialog *dialog);
-
-void        ogmrip_audio_options_dialog_set_codec        (OGMRipAudioOptionsDialog *dialog,
-                                                          GType                    codec);
-GType       ogmrip_audio_options_dialog_get_codec        (OGMRipAudioOptionsDialog *dialog);
-
-void        ogmrip_audio_options_dialog_set_quality      (OGMRipAudioOptionsDialog *dialog,
-                                                          guint                    quality);
-gint        ogmrip_audio_options_dialog_get_quality      (OGMRipAudioOptionsDialog *dialog);
-
-void        ogmrip_audio_options_dialog_set_srate        (OGMRipAudioOptionsDialog *dialog,
-                                                          guint                    srate);
-gint        ogmrip_audio_options_dialog_get_srate        (OGMRipAudioOptionsDialog *dialog);
-
-void        ogmrip_audio_options_dialog_set_channels     (OGMRipAudioOptionsDialog *dialog,
-                                                          guint                    channels);
-gint        ogmrip_audio_options_dialog_get_channels     (OGMRipAudioOptionsDialog *dialog);
-
-void        ogmrip_audio_options_dialog_set_normalize    (OGMRipAudioOptionsDialog *dialog,
-                                                          gboolean                 normalize);
-gint        ogmrip_audio_options_dialog_get_normalize    (OGMRipAudioOptionsDialog *dialog);
+void        ogmrip_audio_options_dialog_set_options (OGMRipAudioOptionsDialog *dialog,
+                                                     OGMRipAudioOptions       *options);
+void        ogmrip_audio_options_dialog_get_options (OGMRipAudioOptionsDialog *dialog,
+                                                     OGMRipAudioOptions       *options);
 
 G_END_DECLS
 
