@@ -198,6 +198,10 @@ ogmrip_gconf_init (void)
       g_param_spec_int (OGMRIP_GCONF_VIDEO_MAX_WIDTH, NULL, NULL, 0, G_MAXINT, OGMRIP_DEFAULT_VIDEO_MAX_WIDTH, G_PARAM_READWRITE));
   ogmrip_settings_install_key (settings,
       g_param_spec_int (OGMRIP_GCONF_VIDEO_MAX_HEIGHT, NULL, NULL, 0, G_MAXINT, OGMRIP_DEFAULT_VIDEO_MAX_HEIGHT, G_PARAM_READWRITE));
+  ogmrip_settings_install_key (settings,
+      g_param_spec_int (OGMRIP_GCONF_VIDEO_MIN_WIDTH, NULL, NULL, 0, G_MAXINT, OGMRIP_DEFAULT_VIDEO_MIN_WIDTH, G_PARAM_READWRITE));
+  ogmrip_settings_install_key (settings,
+      g_param_spec_int (OGMRIP_GCONF_VIDEO_MIN_HEIGHT, NULL, NULL, 0, G_MAXINT, OGMRIP_DEFAULT_VIDEO_MIN_HEIGHT, G_PARAM_READWRITE));
 
   /*
    * Audio
