@@ -85,6 +85,8 @@ G_BEGIN_DECLS
 
 #define OGMRIP_GCONF_VIDEO_CAN_CROP          OGMRIP_GCONF_VIDEO "/can_crop"
 #define OGMRIP_GCONF_VIDEO_CAN_SCALE         OGMRIP_GCONF_VIDEO "/can_scale"
+#define OGMRIP_GCONF_VIDEO_MIN_WIDTH         OGMRIP_GCONF_VIDEO "/min_width"
+#define OGMRIP_GCONF_VIDEO_MIN_HEIGHT        OGMRIP_GCONF_VIDEO "/min_height"
 #define OGMRIP_GCONF_VIDEO_MAX_WIDTH         OGMRIP_GCONF_VIDEO "/max_width"
 #define OGMRIP_GCONF_VIDEO_MAX_HEIGHT        OGMRIP_GCONF_VIDEO "/max_height"
 #define OGMRIP_GCONF_VIDEO_EXPAND            OGMRIP_GCONF_VIDEO "/expand"
@@ -149,6 +151,8 @@ G_BEGIN_DECLS
 
 #define OGMRIP_DEFAULT_VIDEO_CAN_CROP        TRUE
 #define OGMRIP_DEFAULT_VIDEO_CAN_SCALE       TRUE
+#define OGMRIP_DEFAULT_VIDEO_MIN_WIDTH       0
+#define OGMRIP_DEFAULT_VIDEO_MIN_HEIGHT      0
 #define OGMRIP_DEFAULT_VIDEO_MAX_WIDTH       0
 #define OGMRIP_DEFAULT_VIDEO_MAX_HEIGHT      0
 #define OGMRIP_DEFAULT_VIDEO_EXPAND          FALSE
