@@ -372,8 +372,9 @@ ogmrip_options_dialog_scale (guint size, gdouble aspect, guint *width, guint *he
 static gdouble
 ogmrip_options_dialog_get_aspect (OGMRipOptionsDialog *dialog, guint crop_width, guint crop_height)
 {
-  return (crop_width * dialog->priv->raw_height * dialog->priv->aspect_num) /
-    (gdouble) (crop_height * dialog->priv->raw_width * dialog->priv->aspect_denom);
+  return crop_width / (gdouble) crop_height *
+    dialog->priv->raw_height / dialog->priv->raw_width *
+    dialog->priv->aspect_num / dialog->priv->aspect_denom;
 }
 
 static void
@@ -448,7 +449,7 @@ ogmrip_options_dialog_autoscale_button_clicked (OGMRipOptionsDialog *dialog)
 
   codec = ogmrip_plugin_get_nth_video_codec (0);
   if (codec == G_TYPE_NONE)
-    ogmrip_message_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_ERROR, "<b>%s</b>\n\n%s",
+    ogmrip_message_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_ERROR, "<big><b>%s</b></big>\n\n%s",
         _("Could not detect scaling parameters"), _("There is no video codec available"));
   else
   {
@@ -460,9 +461,7 @@ ogmrip_options_dialog_autoscale_button_clicked (OGMRipOptionsDialog *dialog)
       guint scale_width, scale_height;
 
       title = ogmrip_encoding_get_title (dialog->priv->encoding);
-
       spawn = g_object_new (codec, "input", title, NULL);
-      // ogmdvd_title_unref (title);
 
       ogmrip_options_dialog_get_crop (dialog, &crop_x, &crop_y, &crop_width, &crop_height);
       ogmrip_video_codec_set_crop_size (OGMRIP_VIDEO_CODEC (spawn), crop_x, crop_y, crop_width, crop_height);
@@ -551,7 +550,7 @@ ogmrip_options_dialog_autocrop_button_clicked (OGMRipOptionsDialog *options)
   codec = ogmrip_gconf_get_video_codec_type (profile, NULL);
 
   if (codec == G_TYPE_NONE)
-    ogmrip_message_dialog (GTK_WINDOW (options), GTK_MESSAGE_ERROR, "<b>%s</b>\n\n%s",
+    ogmrip_message_dialog (GTK_WINDOW (options), GTK_MESSAGE_ERROR, "<big><b>%s</b></big>\n\n%s",
         _("Could not detect cropping parameters"), _("There is no video codec available"));
   else
   {
@@ -588,7 +587,6 @@ ogmrip_options_dialog_autocrop_button_clicked (OGMRipOptionsDialog *options)
       gtk_widget_show (dialog);
 
       spawn = g_object_new (codec, "input", title, NULL);
-      // ogmdvd_title_unref (title);
 
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (options->priv->deint_check)))
         ogmrip_video_codec_set_deinterlacer (OGMRIP_VIDEO_CODEC (spawn), OGMRIP_DEINT_YADIF);
@@ -726,17 +724,20 @@ ogmrip_options_dialog_profile_notified (OGMRipSettings *settings, const gchar *s
    * TODO how do can_scale and can_crop interact with the rest ?
    */
 
-  gtk_widget_set_sensitive (dialog->priv->test_check, codec != G_TYPE_NONE);
-  gtk_widget_set_sensitive (dialog->priv->test_button, codec != G_TYPE_NONE && encoding != OGMRIP_ENCODING_QUANTIZER);
-
   gtk_widget_set_sensitive (dialog->priv->scale_check, codec!= G_TYPE_NONE && can_scale);
   if (!can_scale)
+  {
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->scale_check), TRUE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->test_check), TRUE);
+  }
 
   gtk_widget_set_sensitive (dialog->priv->crop_check, codec!= G_TYPE_NONE && can_crop);
   if (!can_crop)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->crop_check), TRUE);
 
+  gtk_widget_set_sensitive (dialog->priv->test_check, codec != G_TYPE_NONE && can_scale);
+  gtk_widget_set_sensitive (dialog->priv->test_button, codec != G_TYPE_NONE && can_scale && encoding != OGMRIP_ENCODING_QUANTIZER);
+
   gtk_widget_set_sensitive (dialog->priv->cartoon_check, codec != G_TYPE_NONE);
   gtk_widget_set_sensitive (dialog->priv->deint_check, codec != G_TYPE_NONE);
 
@@ -746,19 +747,25 @@ ogmrip_options_dialog_profile_notified (OGMRipSettings *settings, const gchar *s
 static void
 ogmrip_options_dialog_scale_changed (OGMRipOptionsDialog *dialog)
 {
-  guint t, w, h;
+  if (dialog->priv->encoding)
+  {
+    guint t, w, h;
 
-  t = ogmrip_options_dialog_get_scale (dialog, &w, &h);
-  ogmrip_encoding_set_scale (dialog->priv->encoding, t, w, h);
+    t = ogmrip_options_dialog_get_scale (dialog, &w, &h);
+    ogmrip_encoding_set_scale (dialog->priv->encoding, t, w, h);
+  }
 }
 
 static void
 ogmrip_options_dialog_crop_changed (OGMRipOptionsDialog *dialog)
 {
-  guint t, x, y, w, h;
+  if (dialog->priv->encoding)
+  {
+    guint t, x, y, w, h;
 
-  t = ogmrip_options_dialog_get_crop (dialog, &x, &y, &w, &h);
-  ogmrip_encoding_set_crop (dialog->priv->encoding, t, x, y, w, h);
+    t = ogmrip_options_dialog_get_crop (dialog, &x, &y, &w, &h);
+    ogmrip_encoding_set_crop (dialog->priv->encoding, t, x, y, w, h);
+  }
 }
 
 G_DEFINE_TYPE (OGMRipOptionsDialog, ogmrip_options_dialog, GTK_TYPE_DIALOG)
@@ -1285,8 +1292,12 @@ ogmrip_options_dialog_get_test (OGMRipOptionsDialog *dialog)
 {
   g_return_val_if_fail (OGMRIP_IS_OPTIONS_DIALOG (dialog), FALSE);
 
-  return GTK_WIDGET_IS_SENSITIVE (dialog->priv->test_check) &&
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->test_check));
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->test_check)) &&
+#if GTK_CHECK_VERSION(2,18,0)
+    gtk_widget_get_sensitive (dialog->priv->test_check);
+#else
+    GTK_WIDGET_IS_SENSITIVE (dialog->priv->test_check);
+#endif
 }
 
 void
