@@ -72,8 +72,6 @@ struct _OGMRipProfileEditorDialogPriv
   GtkWidget *passes_spin;
   GtkWidget *passes_hbox;
 
-  GtkWidget *threads_spin;
-
   GtkWidget *video_options_label;
   GtkWidget *video_options_vbox;
 
@@ -301,14 +299,6 @@ ogmrip_profile_editor_dialog_check_video_codec (OGMRipSettings *settings,
     gtk_spin_button_set_range (GTK_SPIN_BUTTON (dialog->priv->passes_spin), 1.0,
         MIN (100, ogmrip_plugin_get_video_codec_passes (codec)));
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->passes_spin), value);
-
-    if (dialog->priv->threads_spin)
-    {
-      value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->priv->threads_spin));
-      gtk_spin_button_set_range (GTK_SPIN_BUTTON (dialog->priv->threads_spin), 1.0,
-          MIN (100, ogmrip_plugin_get_video_codec_threads (codec)));
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->threads_spin), value);
-    }
   }
 
   gtk_widget_set_sensitive (dialog->priv->video_expander, codec != G_TYPE_NONE);
@@ -525,7 +515,7 @@ ogmrip_profile_editor_dialog_container_options_button_clicked (OGMRipProfileEdit
     gtk_window_set_parent (GTK_WINDOW (plugin_dialog), GTK_WINDOW (dialog));
     g_signal_connect (plugin_dialog, "delete-event", G_CALLBACK (gtk_true), NULL);
     g_signal_connect (plugin_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-    gtk_widget_show_all (plugin_dialog);
+    gtk_window_present (GTK_WINDOW (plugin_dialog));
   }
 }
 
@@ -542,7 +532,7 @@ ogmrip_profile_editor_dialog_video_options_button_clicked (OGMRipProfileEditorDi
     gtk_window_set_parent (GTK_WINDOW (plugin_dialog), GTK_WINDOW (dialog));
     g_signal_connect (plugin_dialog, "delete-event", G_CALLBACK (gtk_true), NULL);
     g_signal_connect (plugin_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-    gtk_widget_show_all (plugin_dialog);
+    gtk_window_present (GTK_WINDOW (plugin_dialog));
   }
 }
 
@@ -592,7 +582,7 @@ ogmrip_profile_editor_dialog_audio_options_button_clicked (OGMRipProfileEditorDi
     gtk_window_set_parent (GTK_WINDOW (plugin_dialog), GTK_WINDOW (dialog));
     g_signal_connect (plugin_dialog, "delete-event", G_CALLBACK (gtk_true), NULL);
     g_signal_connect (plugin_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-    gtk_widget_show_all (plugin_dialog);
+    gtk_window_present (GTK_WINDOW (plugin_dialog));
   }
 }
 
@@ -713,7 +703,7 @@ ogmrip_profile_editor_dialog_subp_options_button_clicked (OGMRipProfileEditorDia
     gtk_window_set_parent (GTK_WINDOW (plugin_dialog), GTK_WINDOW (dialog));
     g_signal_connect (plugin_dialog, "delete-event", G_CALLBACK (gtk_true), NULL);
     g_signal_connect (plugin_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-    gtk_widget_show_all (plugin_dialog);
+    gtk_window_present (GTK_WINDOW (plugin_dialog));
   }
 }
 
@@ -918,6 +908,14 @@ ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
       ogmrip_profile_editor_dialog_max_height_spin_set_value,
       dialog);
 
+  widget = glade_xml_get_widget (xml, "min-width-spin");
+  ogmrip_settings_bind (settings, dialog->priv->profile_section,
+      OGMRIP_GCONF_VIDEO_MIN_WIDTH, G_OBJECT (widget), "value");
+
+  widget = glade_xml_get_widget (xml, "min-height-spin");
+  ogmrip_settings_bind (settings, dialog->priv->profile_section,
+      OGMRIP_GCONF_VIDEO_MIN_HEIGHT, G_OBJECT (widget), "value");
+
   /*
    * Audio
    */
