@@ -46,7 +46,7 @@ struct _OGMRipProfileEditorDialogClass
 };
 
 GType       ogmrip_profile_editor_dialog_get_type (void);
-GtkWidget * ogmrip_profile_editor_dialog_new      (const gchar *key);
+GtkWidget * ogmrip_profile_editor_dialog_new      (const gchar *profile);
 
 G_END_DECLS
 
