@@ -724,7 +724,7 @@ ogmrip_queue_dialog_add_encoding (OGMRipQueueDialog *dialog, OGMRipEncoding *enc
 
       transient = gtk_window_get_transient_for (GTK_WINDOW (dialog));
 
-      if (ogmrip_message_dialog (transient, GTK_MESSAGE_QUESTION, "%s\n\n%s",
+      if (ogmrip_message_dialog (transient, GTK_MESSAGE_QUESTION, "<big><b>%s</b></big>\n\n%s",
             _("This encoding will have the same output file name as another one."),
             _("Do you want to enqueue it anyway ?")) != GTK_RESPONSE_YES)
         return;
@@ -736,7 +736,7 @@ ogmrip_queue_dialog_add_encoding (OGMRipQueueDialog *dialog, OGMRipEncoding *enc
 
       transient = gtk_window_get_transient_for (GTK_WINDOW (dialog));
 
-      if (ogmrip_message_dialog (transient, GTK_MESSAGE_QUESTION, "%s\n\n%s",
+      if (ogmrip_message_dialog (transient, GTK_MESSAGE_QUESTION, "<big><b>%s</b></big>\n\n%s",
             _("A file with the same name as the output file of the encoding already exists."),
             _("Do you want to enqueue it anyway ?")) != GTK_RESPONSE_YES)
         return;
