@@ -21,6 +21,8 @@
 
 #include <gtk/gtk.h>
 
+#include <ogmrip-encoding.h>
+
 G_BEGIN_DECLS
 
 #define OGMRIP_TYPE_SUBP_OPTIONS_DIALOG            (ogmrip_subp_options_dialog_get_type ())
@@ -45,32 +47,13 @@ struct _OGMRipSubpOptionsDialogClass
   GtkDialogClass parent_class;
 };
 
-GType       ogmrip_subp_options_dialog_get_type      (void);
-GtkWidget * ogmrip_subp_options_dialog_new           (void);
+GType       ogmrip_subp_options_dialog_get_type    (void);
+GtkWidget * ogmrip_subp_options_dialog_new         (void);
 
-void        ogmrip_subp_options_dialog_set_use_defaults (OGMRipSubpOptionsDialog *dialog,
-                                                         gboolean                use_defaults);
-gboolean    ogmrip_subp_options_dialog_get_use_defaults (OGMRipSubpOptionsDialog *dialog);
-
-void        ogmrip_subp_options_dialog_set_codec        (OGMRipSubpOptionsDialog *dialog,
-                                                         GType                   codec);
-GType       ogmrip_subp_options_dialog_get_codec        (OGMRipSubpOptionsDialog *dialog);
-
-void        ogmrip_subp_options_dialog_set_charset      (OGMRipSubpOptionsDialog *dialog,
-                                                         guint                   charset);
-gint        ogmrip_subp_options_dialog_get_charset      (OGMRipSubpOptionsDialog *dialog);
-
-void        ogmrip_subp_options_dialog_set_eol          (OGMRipSubpOptionsDialog *dialog,
-                                                         guint                   eol);
-gint        ogmrip_subp_options_dialog_get_eol          (OGMRipSubpOptionsDialog *dialog);
-
-void        ogmrip_subp_options_dialog_set_spell        (OGMRipSubpOptionsDialog *dialog,
-                                                         gboolean                spell);
-gboolean    ogmrip_subp_options_dialog_get_spell        (OGMRipSubpOptionsDialog *dialog);
-
-void        ogmrip_subp_options_dialog_set_forced_only  (OGMRipSubpOptionsDialog *dialog,
-                                                         gboolean                forced_only);
-gboolean    ogmrip_subp_options_dialog_get_forced_only  (OGMRipSubpOptionsDialog *dialog);
+void        ogmrip_subp_options_dialog_set_options (OGMRipSubpOptionsDialog *dialog,
+                                                    OGMRipSubpOptions       *options);
+void        ogmrip_subp_options_dialog_get_options (OGMRipSubpOptionsDialog *dialog,
+                                                    OGMRipSubpOptions       *options);
 
 G_END_DECLS
 
