@@ -41,6 +41,9 @@
 
 #define MAX_TEXT_LEN 4096
 
+#define CR "\x0d"
+#define LF "\x0a"
+
 enum
 {
   FORMAT_SUBP,
@@ -70,7 +73,7 @@ typedef struct
   int (* header) (FILE       *file);
   int (* footer) (FILE       *file);
   int (* tag)    (FILE       *file,
-                        subp_tag_t *tag);
+                  subp_tag_t *tag);
 } subp_writer_t;
 
 static unsigned int verbose;
@@ -88,6 +91,8 @@ static double factor = 1.0;
 static unsigned int first_tag_number = 1;
 static unsigned int last_tag_number = ~0;
 
+static const char *newline = LF;
+
 static subp_time_t adjustment;
 
 static unsigned int
@@ -180,6 +185,30 @@ parse_convert (const char *value)
   return convert;
 }
 
+static int
+parse_newline (const char *value)
+{
+  if (strcmp (value, "cr") == 0 || strcmp (value, "CR") == 0)
+  {
+    newline = CR;
+    return 0;
+  }
+
+  if (strcmp (value, "lf") == 0 || strcmp (value, "LF") == 0)
+  {
+    newline = LF;
+    return 0;
+  }
+
+  if (strcmp (value, "cr+lf") == 0 || strcmp (value, "CR+LF") == 0)
+  {
+    newline = CR LF;
+    return 0;
+  }
+
+  return -1;
+}
+
 static int
 xml_read (xmlTextReader *reader, const char *name, xmlElementType type)
 {
@@ -274,7 +303,7 @@ read_subp_tag (xmlTextReader *reader, subp_tag_t *tag)
     return -1;
 
   if (sscanf (value, "%u:%u:%u.%u",
-	&tag->start_time.hour, &tag->start_time.min, &tag->start_time.sec, &tag->start_time.msec) != 4)
+        &tag->start_time.hour, &tag->start_time.min, &tag->start_time.sec, &tag->start_time.msec) != 4)
     return -1;
 
   free (value);
@@ -407,7 +436,7 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
 
   if (tag->image)
   {
-    /* write out the filanem */
+    /* write out the filename */
     if (fprintf (file, "    <image>%s</image>\n", tag->image) < 0)
       return -1;
   }
@@ -424,15 +453,15 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
 static int
 write_srt_tag (FILE *file, subp_tag_t *tag)
 {
-  if (fprintf (file, "%d\n", tag->number) < 0)
+  if (fprintf (file, "%d%s", tag->number, newline) < 0)
   {
     fprintf (stderr, "Cannot write tag number (%s)\n", strerror (errno));
     return -1;
   }
 
-  if (fprintf (file, "%02u:%02u:%02u,%03u --> %02u:%02u:%02u,%03u\n",
+  if (fprintf (file, "%02u:%02u:%02u,%03u --> %02u:%02u:%02u,%03u%s",
         tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
-        tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec) < 0)
+        tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec, newline) < 0)
   {
     fprintf (stderr, "Cannot write time stamp (%s)\n", strerror (errno));
     return -1;
@@ -444,7 +473,7 @@ write_srt_tag (FILE *file, subp_tag_t *tag)
     return -1;
   }
 
-  if (fprintf (file, "%s\n\n", tag->text) < 0)
+  if (fprintf (file, "%s%s%s", tag->text, newline, newline) < 0)
   {
     fprintf (stderr, "Cannot write text (%s)\n", strerror (errno));
     return -1;
@@ -578,7 +607,7 @@ get_file_content (int fd)
   while (bytes_read < stat_buf.st_size)
   {
     ssize_t rc;
-	
+
     rc = read (fd, buf + bytes_read, stat_buf.st_size - bytes_read);
 
     if (rc < 0)
@@ -666,12 +695,13 @@ usage (const char *name)
   fprintf (stdout, "  -e, --expand=<seconds>         Expand the subtitle hour by <seconds>\n");
   fprintf (stdout, "  -t, --convert=<format>         Convert the subtitle in the given format (srt,\n");
   fprintf (stdout, "                                 spumux)\n");
+  fprintf (stdout, "  -n, --newline=<cr|lf|cr+lf>    Specifies the newline sequence (default: %s)\n", newline);
   fprintf (stdout, "  -i, --input=<filename>         Use filename for input (default: stdin)\n");
   fprintf (stdout, "  -o, --output=<filename>        Use filename for output (default: stdout)\n");
   fprintf (stdout, "\n");
 }
 
-static const char *shortopts = "hvrswd:c:a:e:t:i:o:";
+static const char *shortopts = "hvrswd:c:a:e:t:i:o:n:";
 static const struct option longopts[] =
 {
   { "help",     no_argument,       NULL, 'h' },
@@ -686,6 +716,7 @@ static const struct option longopts[] =
   { "convert",  required_argument, NULL, 't' },
   { "input",    required_argument, NULL, 'i' },
   { "output",   required_argument, NULL, 'o' },
+  { "newline",  required_argument, NULL, 'n' },
   { NULL,       0,                 NULL, 0   }
 };
 
@@ -726,24 +757,28 @@ main (int argc, char *argv[])
         break;
       case 'd':
         if (parse_shift (optarg) < 0)
-	  return EXIT_FAILURE;
+          return EXIT_FAILURE;
         break;
       case 'c':
         if (parse_cut (optarg) < 0)
-	  return EXIT_FAILURE;
+          return EXIT_FAILURE;
         break;
       case 'a':
         if (parse_adjust (optarg) < 0)
-	  return EXIT_FAILURE;
+          return EXIT_FAILURE;
         break;
       case 'e':
         if (parse_expand (optarg) < 0)
-	  return EXIT_FAILURE;
+          return EXIT_FAILURE;
         break;
       case 't':
-	if (parse_convert (optarg) < 0)
-	  return EXIT_FAILURE;
-	break;
+        if (parse_convert (optarg) < 0)
+          return EXIT_FAILURE;
+        break;
+      case 'n':
+        if (parse_newline (optarg) < 0)
+          return EXIT_FAILURE;
+        break;
       case 'i':
         strncpy (input_file, optarg, FILENAME_MAX);
         break;
