@@ -569,8 +569,16 @@ main (int argc, char *argv[])
     fprintf (stderr, "Internal Ogg library error.\n");
     return EXIT_FAILURE;
   }
-  fwrite (og.header, 1, og.header_len, outfile);
-  fwrite (og.body, 1, og.body_len, outfile);
+  if (fwrite (og.header, 1, og.header_len, outfile) != og.header_len)
+  {
+    fprintf (stderr, "Cannot write Ogg header\n");
+    return EXIT_FAILURE;
+  }
+  if (fwrite (og.body, 1, og.body_len, outfile) != og.body_len)
+  {
+    fprintf (stderr, "Cannot write Ogg body\n");
+    return EXIT_FAILURE;
+  }
 
   /*
    * create the remaining theora headers 
@@ -599,8 +607,16 @@ main (int argc, char *argv[])
     }
     if (result == 0)
       break;
-    fwrite (og.header, 1, og.header_len, outfile);
-    fwrite (og.body, 1, og.body_len, outfile);
+    if (fwrite (og.header, 1, og.header_len, outfile) != og.header_len)
+    {
+      fprintf (stderr, "Cannot write Ogg header\n");
+      return EXIT_FAILURE;
+    }
+    if (fwrite (og.body, 1, og.body_len, outfile) != og.body_len)
+    {
+      fprintf (stderr, "Cannot write Ogg body\n");
+      return EXIT_FAILURE;
+    }
   }
 
   /*
